@@ -1,6 +1,3 @@
-
-/*	$Id: tixDItem.c,v 1.1.1.1 2000/05/17 11:08:38 idiscovery Exp $	*/
-
 /*
  * tixDItem.c --
  *
@@ -23,7 +20,8 @@
  *
  */
 
-#include <tixPort.h>
+#include <tkPort.h>
+#include <tkInt.h>
 #include <tixInt.h>
 
 
@@ -135,9 +133,7 @@ void Tix_DItemFree(iPtr)
 {
     iPtr->base.diTypePtr->freeProc(iPtr);
 
-    /*
-     * When it comes to here, iPtr is no longer a valid pointer!
-     */
+    /* when it comes to here, iPtr is no longer a valid pointer! */
 }
 
 void Tix_DItemCalculateSize(iPtr)
@@ -247,6 +243,8 @@ Tix_SplitConfig(interp, tkwin, specsList, numLists, argc, argv, argListPtr)
 	}
     }
 
+    code = TCL_OK;
+
   done:
     if (code == TCL_ERROR) {
 	Tix_FreeArgumentList(argListPtr);
