@@ -1,6 +1,3 @@
-
-/*	$Id: tixDiImg.c,v 1.1.1.1 2000/05/17 11:08:38 idiscovery Exp $	*/
-
 /*
  * tixDiImgTxt.c --
  *
@@ -14,18 +11,19 @@
  *
  */
 
-#include <tixPort.h>
+#include <tkPort.h>
+#include <tkInt.h>
 #include <tixInt.h>
-#include <tixDef.h>
+#include "default.h"
 
 #define DEF_IMAGEITEM_BITMAP	""
-#define DEF_IMAGEITEM_IMAGE		""
-#define DEF_IMAGEITEM_TYPE		"image"
-#define DEF_IMAGEITEM_SHOWIMAGE		"1"
-#define DEF_IMAGEITEM_SHOWTEXT		"1"
-#define DEF_IMAGEITEM_STYLE		""
-#define DEF_IMAGEITEM_TEXT		""
-#define DEF_IMAGEITEM_UNDERLINE		"-1"
+#define DEF_IMAGEITEM_IMAGE	 	""
+#define DEF_IMAGEITEM_TYPE	 	"image"
+#define DEF_IMAGEITEM_SHOWIMAGE  	"1"
+#define DEF_IMAGEITEM_SHOWTEXT   	"1"
+#define DEF_IMAGEITEM_STYLE	 	""
+#define DEF_IMAGEITEM_TEXT	 	""
+#define DEF_IMAGEITEM_UNDERLINE  	"-1"
 
 static Tk_ConfigSpec imageItemConfigSpecs[] = {
 
@@ -47,7 +45,7 @@ static Tk_ConfigSpec imageItemConfigSpecs[] = {
 
 /*----------------------------------------------------------------------
  *
- *		Configuration options for Text Styles
+ * 		Configuration options for Text Styles
  *
  *----------------------------------------------------------------------
  */
@@ -76,9 +74,9 @@ static Tk_ConfigSpec imageItemConfigSpecs[] = {
 #define DEF_IMAGESTYLE_DISABLED_BG_COLOR	DISABLED_BG
 #define DEF_IMAGESTYLE_DISABLED_BG_MONO		WHITE
 
-#define DEF_IMAGESTYLE_PADX		"0"
-#define DEF_IMAGESTYLE_PADY		"0"
-#define DEF_IMAGESTYLE_ANCHOR		"w"
+#define DEF_IMAGESTYLE_PADX	 	"0"
+#define DEF_IMAGESTYLE_PADY	 	"0"
+#define DEF_IMAGESTYLE_ANCHOR 		"w"
 
 
 static Tk_ConfigSpec imageStyleConfigSpecs[] = {
@@ -175,23 +173,23 @@ static void		ImageProc _ANSI_ARGS_((ClientData clientData,
 			    int imgWidth, int imgHeight));
 static void		Tix_ImageItemCalculateSize  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
-static char *		Tix_ImageItemComponent	_ANSI_ARGS_((
+static char *		Tix_ImageItemComponent  _ANSI_ARGS_((
 			    Tix_DItem * iPtr, int x, int y));
-static int		Tix_ImageItemConfigure _ANSI_ARGS_((
+static int 		Tix_ImageItemConfigure _ANSI_ARGS_((
 			    Tix_DItem * iPtr, int argc, char ** argv,
 			    int flags));
-static Tix_DItem *	Tix_ImageItemCreate _ANSI_ARGS_((
+static Tix_DItem * 	Tix_ImageItemCreate _ANSI_ARGS_((
 			    Tix_DispData * ddPtr, Tix_DItemInfo * diTypePtr));
 static void		Tix_ImageItemDisplay  _ANSI_ARGS_((
 			    Pixmap pixmap, GC gc, Tix_DItem * iPtr,
 			    int x, int y, int width, int height, int flag));
 static void		Tix_ImageItemFree  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
-static void		Tix_ImageItemLostStyle	_ANSI_ARGS_((
+static void		Tix_ImageItemLostStyle  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
-static void		Tix_ImageItemStyleChanged  _ANSI_ARGS_((
+static void 		Tix_ImageItemStyleChanged  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
-static int		Tix_ImageStyleConfigure _ANSI_ARGS_((
+static int 		Tix_ImageStyleConfigure _ANSI_ARGS_((
 			    Tix_DItemStyle* style, int argc, char ** argv,
 			    int flags));
 static Tix_DItemStyle *	Tix_ImageStyleCreate _ANSI_ARGS_((
@@ -199,7 +197,7 @@ static Tix_DItemStyle *	Tix_ImageStyleCreate _ANSI_ARGS_((
 			    Tix_DItemInfo * diTypePtr, char * name));
 static void		Tix_ImageStyleFree _ANSI_ARGS_((
 			    Tix_DItemStyle* style));
-static void		Tix_ImageStyleSetTemplate _ANSI_ARGS_((
+static void 		Tix_ImageStyleSetTemplate _ANSI_ARGS_((
 			    Tix_DItemStyle* style,
 			    Tix_StyleTemplate * tmplPtr));
 
@@ -241,8 +239,8 @@ static Tix_DItem * Tix_ImageItemCreate(ddPtr, diTypePtr)
     itPtr = (TixImageItem*) ckalloc(sizeof(TixImageItem));
 
     itPtr->diTypePtr	= diTypePtr;
-    itPtr->ddPtr	= ddPtr;
-    itPtr->stylePtr	= NULL;
+    itPtr->ddPtr 	= ddPtr;
+    itPtr->stylePtr     = NULL;
     itPtr->clientData	= 0;
     itPtr->size[0]	= 0;
     itPtr->size[1]	= 0;
@@ -329,22 +327,15 @@ static void Tix_ImageItemDisplay(pixmap, gc, iPtr, x, y, width, height, flags)
 {
     TixImageItem *itPtr = (TixImageItem *)iPtr;
     GC foreGC, backGC;
-    TixpSubRegion subReg;
-
-    if ((width <= 0) || (height <= 0)) {
-	return;
-    }
 
     TixGetColorDItemGC(iPtr, &backGC, &foreGC, flags);
-    TixpStartSubRegionDraw(itPtr->ddPtr->display, pixmap, foreGC,
-	    &subReg, 0, 0, x, y, width, height,
-	    itPtr->size[0], itPtr->size[1]);
     TixDItemGetAnchor(itPtr->stylePtr->anchor, x, y, width, height,
 	itPtr->size[0], itPtr->size[1], &x, &y);
 
     if (backGC != None) {
-	TixpSubRegFillRectangle(itPtr->ddPtr->display, pixmap,
-		backGC, &subReg, x, y, width, height);
+	/* Draw the background */
+	XFillRectangle(itPtr->ddPtr->display, pixmap,
+	    backGC, x, y, width, height);
     }
 
     if (itPtr->image != NULL) {
@@ -357,14 +348,11 @@ static void Tix_ImageItemDisplay(pixmap, gc, iPtr, x, y, width, height, flags)
 	} else {
 	    bitY = 0;
 	}
-	TixpSubRegDrawImage(&subReg, itPtr->image, 0, 0, itPtr->imageW,
-		itPtr->imageH, pixmap,
-		x + itPtr->stylePtr->pad[0],
-		y + itPtr->stylePtr->pad[1] + bitY);
+	Tk_RedrawImage(itPtr->image, 0, 0, itPtr->imageW, itPtr->imageH,
+	    pixmap,
+	    x + itPtr->stylePtr->pad[0],
+	    y + itPtr->stylePtr->pad[1] + bitY);
     }
-
-    TixpEndSubRegionDraw(itPtr->ddPtr->display, pixmap, foreGC,
-	    &subReg);
 }
 
 static void Tix_ImageItemCalculateSize(iPtr)
@@ -391,9 +379,7 @@ static char * Tix_ImageItemComponent(iPtr, x, y)
     int x;
     int y;
 {
-#if 0
     TixImageItem *itPtr = (TixImageItem *)iPtr;
-#endif
     static char * body = "body";
 
     return body;
@@ -462,7 +448,7 @@ ImageProc(clientData, x, y, width, height, imgWidth, imgHeight)
 /*----------------------------------------------------------------------
  *
  *
- *			Display styles
+ *  			Display styles
  *
  *
  *----------------------------------------------------------------------
@@ -479,7 +465,7 @@ Tix_ImageStyleCreate(interp, tkwin, diTypePtr, name)
       (TixImageStyle *)ckalloc(sizeof(TixImageStyle));
 
     stylePtr->pad[0]	 = 0;
-    stylePtr->pad[1]	 = 0;
+    stylePtr->pad[1] 	 = 0;
     stylePtr->anchor	 = TK_ANCHOR_CENTER;
 
     for (i=0; i<4; i++) {
@@ -595,7 +581,7 @@ Tix_ImageStyleSetTemplate(style, tmplPtr)
 		Tk_FreeColor(stylePtr->colors[i].bg);
 	    }
 	    stylePtr->colors[i].bg = Tk_GetColor(
-		stylePtr->interp, stylePtr->tkwin,
+  	    	stylePtr->interp, stylePtr->tkwin,
 		Tk_NameOfColor(tmplPtr->colors[i].bg));
 	}
     }
@@ -605,7 +591,7 @@ Tix_ImageStyleSetTemplate(style, tmplPtr)
 		Tk_FreeColor(stylePtr->colors[i].fg);
 	    }
 	    stylePtr->colors[i].fg = Tk_GetColor(
-		stylePtr->interp, stylePtr->tkwin,
+  	    	stylePtr->interp, stylePtr->tkwin,
 		Tk_NameOfColor(tmplPtr->colors[i].fg));
 	}
     }
