@@ -1,7 +1,3 @@
-/* -*-mode: C; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*- */
-
-/*	$Id: tixDiStyle.c,v 1.2.2.1 2002/01/24 08:59:32 idiscovery Exp $	*/
-
 /*
  * tixDiStyle.c --
  *
@@ -15,22 +11,10 @@
  *
  */
 
-#include <tixPort.h>
+#include <tkPort.h>
+#include <tkInt.h>
 #include <tixInt.h>
 
-typedef struct StyleLink {
-    Tix_DItemInfo * diTypePtr;
-    Tix_DItemStyle* stylePtr;
-    struct StyleLink * next;
-} StyleLink;
-
-typedef struct StyleInfo {
-    Tix_StyleTemplate * tmplPtr;
-    Tix_StyleTemplate tmpl;
-    StyleLink * linkHead;
-} StyleInfo;
-
-
 static int   		DItemStyleParseProc _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, Tk_Window tkwin,
 			    char *value,char *widRec, int offset));
@@ -38,19 +22,19 @@ static char *		DItemStylePrintProc _ANSI_ARGS_((
 			    ClientData clientData, Tk_Window tkwin, 
 			    char *widRec, int offset,
 			    Tcl_FreeProc **freeProcPtr));
-static Tix_DItemStyle*	FindDefaultStyle _ANSI_ARGS_((
-			    Tix_DItemInfo * diTypePtr, Tk_Window tkwin));
 static Tix_DItemStyle*	FindStyle _ANSI_ARGS_((
-			    char *styleName, Tcl_Interp *interp));
+			    char *styleName));
 static Tix_DItemStyle* 	GetDItemStyle  _ANSI_ARGS_((
 			    Tix_DispData * ddPtr, Tix_DItemInfo * diTypePtr,
 			    char * styleName, int *isNew_ret));
-static void 		InitHashTables _ANSI_ARGS_((void));
+static void 		InitHashTables _ANSI_ARGS_((
+			    ));
 static void		ListAdd _ANSI_ARGS_((Tix_DItemStyle * stylePtr,
 			    Tix_DItem *iPtr));
 static void		ListDelete _ANSI_ARGS_((Tix_DItemStyle * stylePtr,
 			    Tix_DItem *iPtr));
-static void		ListDeleteAll _ANSI_ARGS_((Tix_DItemStyle * stylePtr));
+static void		ListDeleteAll _ANSI_ARGS_((Tix_DItemStyle * stylePtr
+			    ));
 static void		StyleCmdDeletedProc _ANSI_ARGS_((
 			    ClientData clientData));
 static int		StyleCmd _ANSI_ARGS_((ClientData clientData,
@@ -58,14 +42,12 @@ static int		StyleCmd _ANSI_ARGS_((ClientData clientData,
 static int		StyleConfigure _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tix_DItemStyle* stylePtr, int argc,
 			    char **argv, int flags));
-static void		StyleDestroy _ANSI_ARGS_((ClientData clientData));
-static void		DeleteStyle _ANSI_ARGS_((Tix_DItemStyle * stylePtr));
+static void		StyleDestroy _ANSI_ARGS_((
+			    ClientData clientData));	
+static void		DeleteStyle _ANSI_ARGS_((Tix_DItemStyle * stylePtr
+			    ));
 static void		DefWindowStructureProc _ANSI_ARGS_((
 			    ClientData clientData, XEvent *eventPtr));
-static void		RefWindowStructureProc _ANSI_ARGS_((
-			    ClientData clientData, XEvent *eventPtr));
-static void		SetDefaultStyle _ANSI_ARGS_((Tix_DItemInfo *diTypePtr,
-			    Tk_Window tkwin, Tix_DItemStyle * stylePtr));
 
 static TIX_DECLARE_SUBCMD(StyleConfigCmd);
 static TIX_DECLARE_SUBCMD(StyleCGetCmd);
@@ -147,11 +129,10 @@ Tix_ItemStyleCmd(clientData, interp, argc, argv)
 	return TCL_ERROR;
     }
     
-    /*
-     * Parse the -refwindow option: this tells the style to use this
-     * window to query the default values for background, foreground
-     * etc. Usually, you should set the -refwindow to the window that
-     * holds the display items which are controlled by this style.
+    /* Parse the -refwindow option: this tells the style to
+     * use this window to query the default values for background, foreground
+     * etc. Usually, you should set the -refwindow to the window that holds
+     * the display items which are controlled by this style.
      */
     if (argc > 2) {
 	size_t len;
@@ -170,7 +151,7 @@ Tix_ItemStyleCmd(clientData, interp, argc, argv)
 	    }
 	    if (strncmp(argv[i], "-stylename", len) == 0) {
 		styleName = argv[i+1];
-		if (FindStyle(styleName, interp) != NULL) {
+		if (FindStyle(styleName) != NULL) {
 		    Tcl_AppendResult(interp, "style \"", argv[i+1],
 			"\" already exist", NULL);
 		    return TCL_ERROR;
@@ -178,8 +159,9 @@ Tix_ItemStyleCmd(clientData, interp, argc, argv)
 		continue;
 	    }
 
+	  copy:
 	    if (n!=i) {
-		argv[n]   = argv[i];
+		argv[n] = argv[i];
 		argv[n+1] = argv[i+1];
 	    }
 	    n+=2;
@@ -188,17 +170,14 @@ Tix_ItemStyleCmd(clientData, interp, argc, argv)
     }
 
     if (styleName == NULL) {
-	/*
-	 * No name is given, we'll make a unique name by default
-	 * (ToDo: check if the name has already been used)
-	 */
-	sprintf(buff, "tixStyle%d", counter++);
+	/* let's make a unique name */
+	sprintf(buff, "style%d", counter++);
 	styleName = buff;
     }
 
-    dispData.interp  = interp;
+    dispData.interp = interp;
     dispData.display = Tk_Display(tkwin);
-    dispData.tkwin   = tkwin;
+    dispData.tkwin = tkwin;
 
     if ((stylePtr = GetDItemStyle(&dispData, diTypePtr,
 	 styleName, NULL)) == NULL) {
@@ -208,8 +187,6 @@ Tix_ItemStyleCmd(clientData, interp, argc, argv)
 	DeleteStyle(stylePtr);
 	return TCL_ERROR;
     }
-    Tk_CreateEventHandler(tkwin, StructureNotifyMask,
-	    RefWindowStructureProc, (ClientData)stylePtr);
 
     Tcl_ResetResult(interp);
     Tcl_AppendResult(interp, styleName, NULL);
@@ -331,12 +308,6 @@ StyleConfigure(interp, stylePtr, argc, argv, flags)
     return TCL_OK;
 }
 
-/*----------------------------------------------------------------------
- * StyleDestroy --
- *
- *	Destroy a display style.
- *----------------------------------------------------------------------
- */
 static void
 StyleDestroy(clientData)
     ClientData clientData;
@@ -345,33 +316,31 @@ StyleDestroy(clientData)
 
     if ((stylePtr->base.flags & TIX_STYLE_DEFAULT)) {
 	/*
-	 * If this is the default style for the display items, we
-	 * can't tell the display items that it has lost its style,
-	 * otherwise the ditem will just attempt to create the default
-	 * style again, and we will go into an infinite loop
+	 * If this is the default style for the display items, we can't
+	 * tell the display items that it has lost its style, otherwise
+	 * the ditem will just attempt to create the default style again,
+	 * and we will go into an infinite loop
 	 */
-	if (stylePtr->base.refCount != 0) {
-	    /*
-	     * If the refcount is not zero, this style will NOT be
-	     * destroyed.  The real destroy will be triggered if all
-	     * DItems associated with this style is destroyed (in the
-	     * ListDelete() function).
-	     *
-	     * If a widget is destroyed, it is the responsibility of the
-	     * widget writer to delete all DItems associated with this
-	     * widget. We can discover memory leak if the widget is
-	     * destroyed but some default styles associated with it still
-	     * exist
-	     */
-	    return;
+	if (stylePtr->base.refCount == 0) {
+	    ckfree((char*)stylePtr->base.name);
+	    stylePtr->base.diTypePtr->styleFreeProc(stylePtr);
 	}
+	/*
+	 * If the refcount is not zero, this style will NOT be destroyed.
+	 * The real destroy will be triggered if all DItems associated with
+	 * this style is destroyed (in the function ListDelete).
+	 *
+	 * If a widget is destroyed, it is the responsibility of the widget
+	 * writer to delete all DItems associated with this widget. We can
+	 * discover memory leak if the widget is destroyed but some default
+	 * styles associated with it still exist
+	 */
     } else {
+	ListDeleteAll(stylePtr);
 	stylePtr->base.refCount = 0;
+	ckfree((char*)stylePtr->base.name);
+	stylePtr->base.diTypePtr->styleFreeProc(stylePtr);
     }
-
-    Tcl_DeleteHashTable(&stylePtr->base.items);
-    ckfree((char*)stylePtr->base.name);
-    stylePtr->base.diTypePtr->styleFreeProc(stylePtr);
 }
 
 static void
@@ -382,8 +351,7 @@ StyleCmdDeletedProc(clientData)
 
     stylePtr->base.styleCmd = NULL;
     if (stylePtr->base.flags & TIX_STYLE_DEFAULT) {
-	/*
-	 * Don't do anything
+	/* Don't do anything
 	 * ToDo: maybe should give a background warning:
 	 */
     } else {
@@ -396,7 +364,6 @@ DeleteStyle(stylePtr)
     Tix_DItemStyle * stylePtr;
 {
     Tcl_HashEntry * hashPtr;
-    char *buff;
 
     if (!(stylePtr->base.flags & TIX_STYLE_DELETED)) {
 	stylePtr->base.flags |= TIX_STYLE_DELETED;
@@ -406,36 +373,28 @@ DeleteStyle(stylePtr)
 	        Tcl_GetCommandName(stylePtr->base.interp,
 	        stylePtr->base.styleCmd));
 	}
-        buff=(char *)malloc(strlen(stylePtr->base.name) + 64);
-	sprintf (buff, "%x.%s", stylePtr->base.interp, stylePtr->base.name);
-	hashPtr=Tcl_FindHashEntry(&styleTable, buff);
-        free(buff);
+	hashPtr=Tcl_FindHashEntry(&styleTable, stylePtr->base.name);
 	if (hashPtr != NULL) {
 	    Tcl_DeleteHashEntry(hashPtr);
 	}
-	ListDeleteAll(stylePtr);
 
 	Tk_EventuallyFree((ClientData)stylePtr, (Tix_FreeProc *)StyleDestroy);
     }
 }
-
-/*
- *----------------------------------------------------------------------
- * FindDefaultStyle --
- *
- *	Return the default style of the given type of ditem for the
- *	given tkwin, if such a default style exists.
- *
- * Results:
- *	Pointer to the default style or NULL.
- *
- * Side effects:
- *	None.
- *----------------------------------------------------------------------
- */
 
-static Tix_DItemStyle*
-FindDefaultStyle(diTypePtr, tkwin)
+typedef struct StyleLink {
+    Tix_DItemInfo * diTypePtr;
+    Tix_DItemStyle* stylePtr;
+    struct StyleLink * next;
+} StyleLink;
+
+typedef struct StyleInfo {
+    Tix_StyleTemplate * tmplPtr;
+    Tix_StyleTemplate tmpl;
+    StyleLink * linkHead;
+} StyleInfo;
+
+Tix_DItemStyle* FindDefaultStyle(diTypePtr, tkwin)
     Tix_DItemInfo * diTypePtr;
     Tk_Window tkwin;
 {
@@ -476,7 +435,7 @@ static void SetDefaultStyle(diTypePtr, tkwin, stylePtr)
     newPtr->diTypePtr = diTypePtr;
     newPtr->stylePtr  = stylePtr;
 
-    hashPtr = Tcl_CreateHashEntry(&defaultTable, (char*)tkwin, &isNew);
+    hashPtr=Tcl_CreateHashEntry(&defaultTable, (char*)tkwin, &isNew);
 
     if (!isNew) {
 	infoPtr = (StyleInfo *)Tcl_GetHashValue(hashPtr);
@@ -499,27 +458,11 @@ static void SetDefaultStyle(diTypePtr, tkwin, stylePtr)
     infoPtr->linkHead = newPtr;
 }
 
-/*
- *----------------------------------------------------------------------
- * TixGetDefaultDItemStyle --
- *
- *	Gets the default style for an item if the application doesn't
- *	explicitly give it an style with the -style switch.
- *
- * Results:
- *	The default style.
- *
- * Side effects:
- *	
- *----------------------------------------------------------------------
- */
-
-Tix_DItemStyle*
-TixGetDefaultDItemStyle(ddPtr, diTypePtr, iPtr, oldStylePtr)
-    Tix_DispData * ddPtr;		/* Info about the display. */
-    Tix_DItemInfo * diTypePtr;		/* Info about the DItem type. */
-    Tix_DItem *iPtr;			/* Get default style for this DItem. */
-    Tix_DItemStyle* oldStylePtr;	/* ?? */
+Tix_DItemStyle* TixGetDefaultDItemStyle(ddPtr, diTypePtr, iPtr, oldStylePtr)
+    Tix_DispData * ddPtr;
+    Tix_DItemInfo * diTypePtr;
+    Tix_DItem *iPtr;
+    Tix_DItemStyle* oldStylePtr;
 {
     Tcl_DString dString;
     Tix_DItemStyle* stylePtr;
@@ -529,8 +472,7 @@ TixGetDefaultDItemStyle(ddPtr, diTypePtr, iPtr, oldStylePtr)
 	InitHashTables();
     }
 
-    stylePtr = FindDefaultStyle(diTypePtr, ddPtr->tkwin);
-    if (stylePtr == NULL) {
+    if ((stylePtr = FindDefaultStyle(diTypePtr, ddPtr->tkwin)) == NULL) {
 	/*
 	 * Format default name for this style+window
 	 */
@@ -599,20 +541,6 @@ void Tix_SetDefaultStyleTemplate(tkwin, tmplPtr)
     }
 }
 
-/*
- *----------------------------------------------------------------------
- * GetDItemStyle --
- *
- *	Returns an ItemStyle with the given name.
- *
- * Results:
- *	Pointer to the given Tix_DItsmStyle.
- *
- * Side effects:
- *	If the style doesn't already exist, it is allocated.
- *----------------------------------------------------------------------
- */
-
 static Tix_DItemStyle*
 GetDItemStyle(ddPtr, diTypePtr, styleName, isNew_ret)
     Tix_DispData * ddPtr;
@@ -623,16 +551,12 @@ GetDItemStyle(ddPtr, diTypePtr, styleName, isNew_ret)
     Tcl_HashEntry *hashPtr;
     int isNew;
     Tix_DItemStyle * stylePtr;
-    char *buff;
 
     if (tableInited == 0) {
 	InitHashTables();
     }
 
-    buff=(char *)malloc(strlen(styleName) + 64);
-    sprintf (buff, "%x.%s", ddPtr->interp, styleName);
-    hashPtr = Tcl_CreateHashEntry(&styleTable, buff, &isNew);
-    free(buff);
+    hashPtr = Tcl_CreateHashEntry(&styleTable, styleName, &isNew);
     if (!isNew) {
 	stylePtr = (Tix_DItemStyle *)Tcl_GetHashValue(hashPtr);
     }
@@ -644,13 +568,13 @@ GetDItemStyle(ddPtr, diTypePtr, styleName, isNew_ret)
 	stylePtr->base.interp 	 = ddPtr->interp;
 	stylePtr->base.tkwin  	 = ddPtr->tkwin;
 	stylePtr->base.diTypePtr = diTypePtr;
-	stylePtr->base.name      = tixStrDup(styleName);
+	stylePtr->base.name      = (char*)strdup(styleName);
 	stylePtr->base.pad[0] 	 = 0;
 	stylePtr->base.pad[1] 	 = 0;
 	stylePtr->base.anchor 	 = TK_ANCHOR_CENTER;
+	stylePtr->base.items  	 = NULL;
 	stylePtr->base.refCount  = 0;
 	stylePtr->base.flags     = 0;
-	Tcl_InitHashTable(&stylePtr->base.items, TCL_ONE_WORD_KEYS);
 
 	Tcl_SetHashValue(hashPtr, (char*)stylePtr);
     }
@@ -661,120 +585,94 @@ GetDItemStyle(ddPtr, diTypePtr, styleName, isNew_ret)
     return stylePtr;
 }
 
-static Tix_DItemStyle* FindStyle(styleName, interp)
+static Tix_DItemStyle* FindStyle(styleName)
     char *styleName;
-    Tcl_Interp *interp;		/* Current interpreter. */
 {
     Tcl_HashEntry *hashPtr;
-    char *buff;
 
     if (tableInited == 0) {
 	InitHashTables();
     }
-    buff=(char *)malloc(strlen(styleName) + 64);
-    sprintf (buff, "%x.%s", interp, styleName);
-    hashPtr=Tcl_FindHashEntry(&styleTable, buff);
-    free(buff);
-    if (hashPtr == NULL) {
+    if ((hashPtr=Tcl_FindHashEntry(&styleTable, styleName)) == NULL) {
 	return NULL;
     }
 
     return (Tix_DItemStyle *)Tcl_GetHashValue(hashPtr);
 }
-
-/*----------------------------------------------------------------------
- * TixDItemStyleChanged --
- *
- *	Tell each Ditem that are affected by this style that the style
- *	has changed. The Ditems will respond by updating their
- *	attributes according to the new values of the style.
- *----------------------------------------------------------------------
- */
-
+    
 void TixDItemStyleChanged(diTypePtr, stylePtr)
     Tix_DItemInfo * diTypePtr;
     Tix_DItemStyle * stylePtr;
 {
-    Tcl_HashSearch hashSearch;
-    Tcl_HashEntry *hashPtr;
-    Tix_DItem * iPtr;
+    /* Tell all items that are associated with stylePtr that its style has
+     * changed
+     */
+    Tix_DItemLink * linkPtr;
 
-    for (hashPtr = Tcl_FirstHashEntry(&stylePtr->base.items, &hashSearch);
-	 hashPtr;
-	 hashPtr = Tcl_NextHashEntry(&hashSearch)) {
-
-	iPtr = (Tix_DItem *)Tcl_GetHashValue(hashPtr);
-	diTypePtr->styleChangedProc(iPtr);
+    for (linkPtr=stylePtr->base.items; linkPtr; linkPtr=linkPtr->next) {
+	if (diTypePtr->styleChangedProc != NULL) {
+	    diTypePtr->styleChangedProc(linkPtr->iPtr);
+	}
     }
 }
 
-/*----------------------------------------------------------------------
- * ListAdd --
- *
- *	Add an item to the list of items affected by a style.
- *----------------------------------------------------------------------
- */
-
-static void
-ListAdd(stylePtr, iPtr)
+static void ListAdd(stylePtr, iPtr)
     Tix_DItemStyle * stylePtr;
     Tix_DItem *iPtr;
 {
-    Tcl_HashEntry *hashPtr;
-    int isNew;
+    Tix_DItemLink * linkPtr = (Tix_DItemLink *)ckalloc(sizeof(Tix_DItemLink));
 
-    hashPtr = Tcl_CreateHashEntry(&stylePtr->base.items, (char*)iPtr, &isNew);
-    if (!isNew) {
-	panic("DItem is already associated with style");
-    } else {
-	Tcl_SetHashValue(hashPtr, (char*)iPtr);
-    }
+    linkPtr->iPtr = iPtr;
+    linkPtr->next = stylePtr->base.items;
+    stylePtr->base.items = linkPtr;
     ++ stylePtr->base.refCount;
 }
 
-static void
-ListDelete(stylePtr, iPtr)
+static void ListDelete(stylePtr, iPtr)
     Tix_DItemStyle * stylePtr;
     Tix_DItem *iPtr;
 {
-    Tcl_HashEntry *hashPtr;
+    Tix_DItemLink * linkPtr, *lastPtr;
 
-    hashPtr = Tcl_FindHashEntry(&stylePtr->base.items, (char*)iPtr);
-    if (hashPtr == NULL) {
-	panic("DItem is not associated with style");
+    for (lastPtr=linkPtr=stylePtr->base.items; linkPtr;
+	 lastPtr=linkPtr,linkPtr=linkPtr->next) {
+
+	if (linkPtr->iPtr == iPtr) {
+	    -- stylePtr->base.refCount;
+	    if (linkPtr==stylePtr->base.items) {
+		stylePtr->base.items = linkPtr->next;
+	    } else {
+		lastPtr->next = linkPtr->next;
+	    }
+
+	    ckfree((char *)linkPtr);
+	    break;
+	}
     }
-    Tcl_DeleteHashEntry(hashPtr);
-    stylePtr->base.refCount--;
-
-    if ((stylePtr->base.refCount == 0) &&
-            (stylePtr->base.flags & TIX_STYLE_DELETED) &&
-	    (stylePtr->base.flags & TIX_STYLE_DEFAULT)) {
+    if ((stylePtr->base.flags & TIX_STYLE_DELETED) &&
+	(stylePtr->base.flags & TIX_STYLE_DEFAULT) &&
+	stylePtr->base.refCount == 0) {
 	Tk_EventuallyFree((ClientData)stylePtr, (Tix_FreeProc *)StyleDestroy);
     }
 }
     
-static void
-ListDeleteAll(stylePtr)
+static void ListDeleteAll(stylePtr)
     Tix_DItemStyle * stylePtr;
 {
-    Tcl_HashSearch hashSearch;
-    Tcl_HashEntry *hashPtr;
-    Tix_DItem * iPtr;
+    Tix_DItemLink * linkPtr, *toFree;
 
-    for (hashPtr = Tcl_FirstHashEntry(&stylePtr->base.items, &hashSearch);
-	 hashPtr;
-	 hashPtr = Tcl_NextHashEntry(&hashSearch)) {
+    for (linkPtr=stylePtr->base.items; linkPtr;) {
+	toFree = linkPtr;
+	linkPtr = linkPtr->next;
 
-	iPtr = (Tix_DItem *)Tcl_GetHashValue(hashPtr);
 	if (stylePtr->base.diTypePtr->lostStyleProc != NULL) {
-	    stylePtr->base.diTypePtr->lostStyleProc(iPtr);
+	    stylePtr->base.diTypePtr->lostStyleProc(toFree->iPtr);
 	}
-	Tcl_DeleteHashEntry(hashPtr);
+	ckfree((char *)toFree);
     }
 }
 
-static void
-InitHashTables()
+static void InitHashTables()
 {
     if (tableInited == 0) {
 	Tcl_InitHashTable(&styleTable, TCL_STRING_KEYS);
@@ -799,7 +697,6 @@ InitHashTables()
  *
  *--------------------------------------------------------------
  */
-
 static void
 DefWindowStructureProc(clientData, eventPtr)
     ClientData clientData;	/* Pointer to record describing window item. */
@@ -832,39 +729,6 @@ DefWindowStructureProc(clientData, eventPtr)
     Tcl_DeleteHashEntry(hashPtr);
 }
 
-/*
- *--------------------------------------------------------------
- *
- * RefWindowStructureProc --
- *
- *	This procedure is invoked when the refwindow of a non-default
- *	style is deleted.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	The style is deleted.
- *
- *--------------------------------------------------------------
- */
-
-static void
-RefWindowStructureProc(clientData, eventPtr)
-    ClientData clientData;	/* Pointer to record describing window item. */
-    XEvent *eventPtr;		/* Describes what just happened. */
-{
-    Tix_DItemStyle * stylePtr = (Tix_DItemStyle *)clientData;
-
-    if (eventPtr->type == DestroyNotify) {
-	/*
-	 * If some DItems are still associated with this window, they
-	 * will receive a "LostStyle" notification.
-	 */
-	DeleteStyle(stylePtr);
-    } 
-}
-
 /*----------------------------------------------------------------------
  *
  *		 The Tix Customed Config Options
@@ -911,20 +775,9 @@ static int DItemStyleParseProc(clientData, interp, tkwin, value, widRec,offset)
 	 * User gives a NULL string -- meaning he wants the default
 	 * style
 	 */
-	if (oldPtr && oldPtr->base.flags & TIX_STYLE_DEFAULT) {
-	    /*
-	     * This ditem is already associated with a default style. Let's
-	     * keep it.
-	     */
-	    newPtr = oldPtr;
-	} else {
-	    if (oldPtr) {
-		ListDelete(oldPtr, iPtr);
-	    }
-	    newPtr = NULL;
-	}
+	newPtr = NULL;
     } else {
-	if ((newPtr = FindStyle(value, interp)) == NULL) {
+	if ((newPtr = FindStyle(value)) == NULL) {
 	    goto not_found;
 	}
 	if (newPtr->base.flags & TIX_STYLE_DELETED) {
@@ -936,10 +789,23 @@ static int DItemStyleParseProc(clientData, interp, tkwin, value, widRec,offset)
 	        newPtr->base.diTypePtr->name, " style", NULL);
 	    return TCL_ERROR;
 	}
-	if (oldPtr != newPtr) {
-	    if (oldPtr != NULL) {
-		ListDelete(oldPtr, iPtr);
+    }
+
+    if (oldPtr != newPtr) {
+	if (oldPtr != NULL) {
+	    /*
+	     * Release the old style
+	     */
+	    if (FindStyle(oldPtr->base.name) == NULL) {
+		/* Old style was deleted: some error */
+		panic("old stylePtr was already deleted!");
 	    }
+	    ListDelete(oldPtr, iPtr);
+	}
+	if (newPtr != NULL) {
+	    /*
+	     * Attach to the new style
+	     */
 	    ListAdd(newPtr, iPtr);
 	}
     }
@@ -947,7 +813,7 @@ static int DItemStyleParseProc(clientData, interp, tkwin, value, widRec,offset)
     *ptr = newPtr;
     return TCL_OK;
 
-not_found:
+  not_found:
     Tcl_AppendResult(interp, "Display style \"", value,
 	"\" not found", NULL);
     return TCL_ERROR;
@@ -968,4 +834,3 @@ static char *DItemStylePrintProc(clientData, tkwin, widRec,offset, freeProcPtr)
 	return 0;
     }
 }
-
