@@ -1,6 +1,3 @@
-
-/*	$Id: tixDiText.c,v 1.2 2000/10/12 02:52:19 idiscovery Exp $	*/
-
 /*
  * tixDiText.c --
  *
@@ -13,21 +10,20 @@
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
  */
-
-#include <tixPort.h>
+#include <tkPort.h>
+#include <tkInt.h>
 #include <tixInt.h>
-#include <tixDef.h>
+#include "tixDef.h"
 
 /*----------------------------------------------------------------------
  *
- *		Configuration options for Text Items
+ * 		Configuration options for Text Items
  *
  *----------------------------------------------------------------------
  */
-
 #define DEF_TEXTITEM_STYLE	 ""
 #define DEF_TEXTITEM_TEXT	 ""
-#define DEF_TEXTITEM_UNDERLINE	 "-1"
+#define DEF_TEXTITEM_UNDERLINE   "-1"
 #define DEF_TEXTITEM_TYPE	 "text"
 
 static Tk_ConfigSpec textItemConfigSpecs[] = {
@@ -48,7 +44,7 @@ static Tk_ConfigSpec textItemConfigSpecs[] = {
 
 /*----------------------------------------------------------------------
  *
- *		Configuration options for Text Styles
+ * 		Configuration options for Text Styles
  *
  *----------------------------------------------------------------------
  */
@@ -76,12 +72,12 @@ static Tk_ConfigSpec textItemConfigSpecs[] = {
 #define DEF_TEXTSTYLE_DISABLED_BG_COLOR		DISABLED_BG
 #define DEF_TEXTSTYLE_DISABLED_BG_MONO		WHITE
 
-#define DEF_TEXTSTYLE_PADX			"2"
-#define DEF_TEXTSTYLE_PADY			"2"
-#define DEF_TEXTSTYLE_FONT	     "-Adobe-Helvetica-Bold-R-Normal--*-120-*"
-#define DEF_TEXTSTYLE_JUSTIFY			"left"
-#define DEF_TEXTSTYLE_WLENGTH			"0"
-#define DEF_TEXTSTYLE_ANCHOR			"w"
+#define DEF_TEXTSTYLE_PADX	 		"2"
+#define DEF_TEXTSTYLE_PADY	 		"2"
+#define DEF_TEXTSTYLE_FONT           "-Adobe-Helvetica-Bold-R-Normal--*-120-*"
+#define DEF_TEXTSTYLE_JUSTIFY	 		"left"
+#define DEF_TEXTSTYLE_WLENGTH	 		"0"
+#define DEF_TEXTSTYLE_ANCHOR 			"w"
 
 #if 0
     /* %bordercolor not used */
@@ -111,7 +107,7 @@ static Tk_ConfigSpec textStyleConfigSpecs[] = {
        (char *) NULL, 0, 0},
 
     {TK_CONFIG_FONT, "-font", "font", "Font",
-       DEF_TEXTSTYLE_FONT, Tk_Offset(TixTextStyle, font), 0},
+       DEF_TEXTSTYLE_FONT, Tk_Offset(TixTextStyle, fontPtr), 0},
 
     {TK_CONFIG_JUSTIFY, "-justify", "justify", "Justyfy",
        DEF_TEXTSTYLE_JUSTIFY, Tk_Offset(TixTextStyle, justify),
@@ -205,10 +201,10 @@ static void		Tix_TextItemCalculateSize  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
 static char *		Tix_TextItemComponent  _ANSI_ARGS_((
 			    Tix_DItem * iPtr, int x, int y));
-static int		Tix_TextItemConfigure _ANSI_ARGS_((
+static int 		Tix_TextItemConfigure _ANSI_ARGS_((
 			    Tix_DItem * iPtr, int argc, char ** argv,
 			    int flags));
-static Tix_DItem *	Tix_TextItemCreate _ANSI_ARGS_((
+static Tix_DItem * 	Tix_TextItemCreate _ANSI_ARGS_((
 			    Tix_DispData * ddPtr, Tix_DItemInfo * diTypePtr));
 static void		Tix_TextItemDisplay  _ANSI_ARGS_((
 			    Pixmap pixmap, GC gc, Tix_DItem * iPtr,
@@ -217,9 +213,9 @@ static void		Tix_TextItemFree  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
 static void		Tix_TextItemLostStyle  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
-static void		Tix_TextItemStyleChanged  _ANSI_ARGS_((
+static void 		Tix_TextItemStyleChanged  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
-static int		Tix_TextStyleConfigure _ANSI_ARGS_((
+static int 		Tix_TextStyleConfigure _ANSI_ARGS_((
 			    Tix_DItemStyle* style, int argc, char ** argv,
 			    int flags));
 static Tix_DItemStyle *	Tix_TextStyleCreate _ANSI_ARGS_((
@@ -227,7 +223,7 @@ static Tix_DItemStyle *	Tix_TextStyleCreate _ANSI_ARGS_((
 			    Tix_DItemInfo * diTypePtr, char * name));
 static void		Tix_TextStyleFree _ANSI_ARGS_((
 			    Tix_DItemStyle* style));
-static void		Tix_TextStyleSetTemplate _ANSI_ARGS_((
+static void 		Tix_TextStyleSetTemplate _ANSI_ARGS_((
 			    Tix_DItemStyle* style,
 			    Tix_StyleTemplate * tmplPtr));
 
@@ -268,7 +264,7 @@ static Tix_DItem * Tix_TextItemCreate(ddPtr, diTypePtr)
     itPtr = (TixTextItem*) ckalloc(sizeof(TixTextItem));
 
     itPtr->diTypePtr	= &tix_TextItemType;
-    itPtr->ddPtr	= ddPtr;
+    itPtr->ddPtr 	= ddPtr;
 #if 1
     itPtr->stylePtr	= (TixTextStyle*)TixGetDefaultDItemStyle(
 	    itPtr->ddPtr, &tix_TextItemType, (Tix_DItem*)itPtr, NULL);
@@ -283,7 +279,7 @@ static Tix_DItem * Tix_TextItemCreate(ddPtr, diTypePtr)
     itPtr->text		= NULL;
     itPtr->textW	= 0;
     itPtr->textH	= 0;
-    itPtr->underline	= -1;
+    itPtr->underline 	= -1;
 
     return (Tix_DItem *)itPtr;
 }
@@ -332,6 +328,54 @@ static int Tix_TextItemConfigure(iPtr, argc, argv, flags)
     return TCL_OK;
 }
 
+#if 0
+    /* %bordercolor not used */
+static void DrawBorder(pixmap, gc, iPtr, x, y, width, height, flags)
+    Pixmap pixmap;
+    GC gc;
+    Tix_DItem * iPtr;
+    int x;
+    int y;
+    int width;
+    int height;
+    int flags;
+{
+    int x1, y1, x2, y2, i;
+
+    TixTextItem *itPtr = (TixTextItem *)iPtr;
+    if (itPtr->stylePtr->borderWidth <= 0) {
+	return;
+    }
+    if (itPtr->stylePtr->relief == TIX_RELIEF_SOLID) {
+	if (!(flags & TIX_DITEM_BOTTOM)) {
+	    x1 = x;
+	    x2 = x + width-1;
+	    y1 = y2 = y + height - 1;
+	    
+	    for (i=0; i<itPtr->stylePtr->borderWidth; i++) {
+		XDrawLine(itPtr->ddPtr->display, pixmap,
+		    itPtr->stylePtr->borderGC, x1, y1, x2, y2);
+		--y1;
+		--y2;
+	    }
+	}
+	if (!(flags & TIX_DITEM_RIGHT)) {
+	    y1 = y;
+	    y2 = y + height -1;
+	    x1 = x2 = x + width - 1;
+	    
+	    for (i=0; i<itPtr->stylePtr->borderWidth; i++) {
+		XDrawLine(itPtr->ddPtr->display, pixmap,
+		    itPtr->stylePtr->borderGC, x1, y1, x2, y2);
+		--x1;
+		--x2;
+	    }
+	}
+
+    }
+}
+#endif
+
 static void Tix_TextItemDisplay(pixmap, gc, iPtr, x, y, width, height, flags)
     Pixmap pixmap;
     GC gc;
@@ -344,38 +388,35 @@ static void Tix_TextItemDisplay(pixmap, gc, iPtr, x, y, width, height, flags)
 {
     TixTextItem *itPtr = (TixTextItem *)iPtr;
     GC foreGC, backGC;
-    TixpSubRegion subReg;
-
-    if ((width <= 0) || (height <= 0)) {
-	return;
-    }
 
     TixGetColorDItemGC(iPtr, &backGC, &foreGC, flags);
 
-    TixpStartSubRegionDraw(itPtr->ddPtr->display, pixmap, foreGC,
-	    &subReg, 0, 0, x, y, width, height,
-	    itPtr->size[0], itPtr->size[1]);
-
     if (backGC != None) {
-	TixpSubRegFillRectangle(itPtr->ddPtr->display, pixmap, backGC,
-		&subReg, x, y, width, height);
+	/* Draw the background */
+	XFillRectangle(itPtr->ddPtr->display, pixmap,
+	    backGC,
+	    x, y, width, height);
     }
+#if 0
+    /* %bordercolor not used */
+    DrawBorder(pixmap, gc, iPtr, x, y, width, height, flags);
+#endif
 
     TixDItemGetAnchor(itPtr->stylePtr->anchor, x, y, width, height,
-	    itPtr->size[0], itPtr->size[1], &x, &y);
+	itPtr->size[0], itPtr->size[1], &x, &y);
 
     if (foreGC != None && itPtr->text != NULL) {
 	x += itPtr->stylePtr->pad[0];
 	y += itPtr->stylePtr->pad[1];
-
-	TixpSubRegDisplayText(itPtr->ddPtr->display, pixmap, foreGC,
-		&subReg, itPtr->stylePtr->font, itPtr->text,
-		itPtr->numChars, x, y, itPtr->textW, itPtr->stylePtr->justify,
-		itPtr->underline);
+	
+	TkDisplayText(itPtr->ddPtr->display, pixmap, itPtr->stylePtr->fontPtr,
+       	    itPtr->text, itPtr->numChars,
+	    x, y,
+	    itPtr->textW,
+	    itPtr->stylePtr->justify,
+	    itPtr->underline,
+	    foreGC);
     }
-
-    TixpEndSubRegionDraw(itPtr->ddPtr->display, pixmap, foreGC,
-	    &subReg);
 }
 
 static char * Tix_TextItemComponent(iPtr, x, y)
@@ -383,9 +424,7 @@ static char * Tix_TextItemComponent(iPtr, x, y)
     int x;
     int y;
 {
-#if 0
     TixTextItem *itPtr = (TixTextItem *)iPtr;
-#endif
     static char * body = "body";
 
     return body;
@@ -399,8 +438,8 @@ static void Tix_TextItemCalculateSize(iPtr)
 
 
     if (itPtr->text) {
-	itPtr->numChars = -1;
-	TixComputeTextGeometry(itPtr->stylePtr->font, itPtr->text,
+	itPtr->numChars = strlen(itPtr->text);
+	TkComputeTextGeometry(itPtr->stylePtr->fontPtr, itPtr->text,
 		itPtr->numChars,
 		itPtr->stylePtr->wrapLength, &itPtr->textW, &itPtr->textH);
 
@@ -456,7 +495,7 @@ Tix_TextItemLostStyle(iPtr)
 /*----------------------------------------------------------------------
  *
  *
- *			Display styles
+ *  			Display styles
  *
  *
  *----------------------------------------------------------------------
@@ -471,11 +510,11 @@ Tix_TextStyleCreate(interp, tkwin, diTypePtr, name)
     TixTextStyle * stylePtr = (TixTextStyle *)ckalloc(sizeof(TixTextStyle));
     int i;
 
-    stylePtr->font	 = NULL;
-    stylePtr->justify	 = TK_JUSTIFY_LEFT;
+    stylePtr->fontPtr 	 = NULL;
+    stylePtr->justify 	 = TK_JUSTIFY_LEFT;
     stylePtr->wrapLength = 0;
     stylePtr->pad[0]	 = 0;
-    stylePtr->pad[1]	 = 0;
+    stylePtr->pad[1] 	 = 0;
     stylePtr->anchor	 = TK_ANCHOR_CENTER;
 
     for (i=0; i<4; i++) {
@@ -509,7 +548,7 @@ Tix_TextStyleConfigure(style, argc, argv, flags)
     GC newGC;
     int i, isNew;
 
-    if (stylePtr->font == NULL) {
+    if (stylePtr->fontPtr == NULL) {
 	isNew = 1;
     } else {
 	isNew = 0;
@@ -523,7 +562,7 @@ Tix_TextStyleConfigure(style, argc, argv, flags)
 	}
     }
 
-    gcValues.font = TixFontId(stylePtr->font);
+    gcValues.font = stylePtr->fontPtr->fid;
     gcValues.graphics_exposures = False;
 
     for (i=0; i<4; i++) {
@@ -614,12 +653,12 @@ Tix_TextStyleSetTemplate(style, tmplPtr)
     int i;
 
     if (tmplPtr->flags & TIX_DITEM_FONT) {
-	if (stylePtr->font != NULL) {
-	    TixFreeFont(stylePtr->font);
+	if (stylePtr->fontPtr != NULL) {
+	    Tk_FreeFontStruct(stylePtr->fontPtr);
 	}
-	stylePtr->font = TixGetFont(
-	    stylePtr->interp, stylePtr->tkwin,
-	    TixNameOfFont(tmplPtr->font));
+	stylePtr->fontPtr = Tk_GetFontStruct(
+  	    stylePtr->interp, stylePtr->tkwin,
+	    Tk_NameOfFontStruct(tmplPtr->fontPtr));
     }
     if (tmplPtr->flags & TIX_DITEM_PADX) {
 	stylePtr->pad[0] = tmplPtr->pad[0];
@@ -634,7 +673,7 @@ Tix_TextStyleSetTemplate(style, tmplPtr)
 		Tk_FreeColor(stylePtr->colors[i].bg);
 	    }
 	    stylePtr->colors[i].bg = Tk_GetColor(
-		stylePtr->interp, stylePtr->tkwin,
+  	    	stylePtr->interp, stylePtr->tkwin,
 		Tk_NameOfColor(tmplPtr->colors[i].bg));
 	}
     }
@@ -644,7 +683,7 @@ Tix_TextStyleSetTemplate(style, tmplPtr)
 		Tk_FreeColor(stylePtr->colors[i].fg);
 	    }
 	    stylePtr->colors[i].fg = Tk_GetColor(
-		stylePtr->interp, stylePtr->tkwin,
+  	    	stylePtr->interp, stylePtr->tkwin,
 		Tk_NameOfColor(tmplPtr->colors[i].fg));
 	}
     }
@@ -655,7 +694,7 @@ Tix_TextStyleSetTemplate(style, tmplPtr)
 	    Tk_FreeColor(stylePtr->borderColor);
 	}
 	stylePtr->borderColor = Tk_GetColor(
-	   stylePtr->interp, stylePtr->tkwin,
+  	   stylePtr->interp, stylePtr->tkwin,
 	   Tk_NameOfColor(tmplPtr->borderColor));
     }
     if (tmplPtr->flags & TIX_DITEM_BORDER_WIDTH) {
