@@ -1,6 +1,3 @@
-
-/*	$Id: tixDiWin.c,v 1.1.1.1 2000/05/17 11:08:41 idiscovery Exp $	*/
-
 /*
  * tixDiWin.c --
  *
@@ -13,9 +10,10 @@
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
  */
-#include <tixPort.h>
+#include <tkPort.h>
+#include <tkInt.h>
 #include <tixInt.h>
-#include <tixDef.h>
+#include "default.h"
 
 /*----------------------------------------------------------------------
  *
@@ -110,8 +108,6 @@ static void		Tix_WindowItemLostStyle  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
 static void 		Tix_WindowItemStyleChanged  _ANSI_ARGS_((
 			    Tix_DItem * iPtr));
-static void		Tix_WindowItemUnmap _ANSI_ARGS_((
-			    TixWindowItem *itPtr));
 static int 		Tix_WindowStyleConfigure _ANSI_ARGS_((
 			    Tix_DItemStyle* style, int argc, char ** argv,
 			    int flags));
@@ -123,10 +119,6 @@ static void		Tix_WindowStyleFree _ANSI_ARGS_((
 static void 		Tix_WindowStyleSetTemplate _ANSI_ARGS_((
 			    Tix_DItemStyle* style,
 			    Tix_StyleTemplate * tmplPtr));
-static void		UnmanageWindow _ANSI_ARGS_((Tix_DItem * iPtr,
-			    Tk_Window tkwin));
-static void		ManageWindow _ANSI_ARGS_((Tix_DItem * iPtr,
-			    Tk_Window tkwin));
 
 Tix_DItemInfo tix_WindowItemType = {
     "window",			/* type */
@@ -219,9 +211,7 @@ static void Tix_WindowItemFree(iPtr)
  *	itPtr->tkwin is changed.
  *----------------------------------------------------------------------
  */
-
-static void
-ManageWindow(iPtr, tkwin)
+static void ManageWindow(iPtr, tkwin)
     Tix_DItem * iPtr;
     Tk_Window tkwin;
 {
@@ -244,9 +234,7 @@ ManageWindow(iPtr, tkwin)
  *	the tkwin parameter may not equal to itPtr->tkwin.
  *----------------------------------------------------------------------
  */
-
-static void
-UnmanageWindow(iPtr, tkwin)
+static void UnmanageWindow(iPtr, tkwin)
     Tix_DItem * iPtr;
     Tk_Window tkwin;
 {
@@ -390,9 +378,7 @@ static char * Tix_WindowItemComponent(iPtr, x, y)
     int x;
     int y;
 {
-#if 0
     TixWindowItem *itPtr = (TixWindowItem *)iPtr;
-#endif
     static char * body = "body";
 
     return body;
@@ -551,8 +537,7 @@ SubWindowLostSlaveProc(clientData, tkwin)
  *
  *----------------------------------------------------------------------
  */
-static void
-Tix_WindowItemUnmap(itPtr)
+void Tix_WindowItemUnmap(itPtr)
     TixWindowItem *itPtr;
 {
     Tk_Window tkwin = itPtr->tkwin;
