@@ -1,6 +1,3 @@
-
-/*	$Id: tixForm.c,v 1.1.1.1 2000/05/17 11:08:41 idiscovery Exp $	*/
-
 /*
  * tixForm.c --
  *
@@ -8,7 +5,18 @@
  *	capability as the Motif Form geometry manager. Please
  *	refer to the documentation for the use of tixForm.
  *
- * 	This file implements the basic algorithm of tixForm.
+ * 	This file implements the algorithm of tixForm.
+ *
+ * LEGAL WARNINGS:
+ *
+ *	The Tix Form geometry manager CANNOT be used in any commercial
+ *	software that supports interactive user interface specification.
+ *	This means if you are writing a GUI builder that includes 
+ *	tixForm, it must be FREELY DISTRIBUTED. Otherwise, you are not
+ *	even permitted to study, imitate, copy or read this source file.
+ *
+ *	Please read the file README.LEGAL for more details on the copyright
+ *	status of Tix 4.0
  *
  * Copyright (c) 1996, Expert Interface Technologies
  *
@@ -30,25 +38,11 @@
  *     clients attached to S must delete their reference to S
  */
 
-#include <tkInt.h>
-#include <tixPort.h>
+#include "tkPort.h"
+#include "tkInt.h"
 #include <tix.h>
-#include <tixForm.h>
+#include "tixForm.h"
 #define DEBUG 0
-
-
-typedef struct SpringLink {
-    struct SpringLink * next;
-    FormInfo *clientPtr;
-} SpringLink;
-
-
-typedef struct SpringList { 
-    SpringLink * head, * tail;
-    int num;
-} SpringList;
-
-
 /*
  * SubCommands of the tixForm command.
  */
@@ -59,11 +53,8 @@ static TIX_DECLARE_SUBCMD(TixFm_Forget);
 EXTERN TIX_DECLARE_SUBCMD(TixFm_Info);
 static TIX_DECLARE_SUBCMD(TixFm_Slaves);
 static TIX_DECLARE_SUBCMD(TixFm_Spring);
-
 static void 		ArrangeGeometry _ANSI_ARGS_((ClientData clientData));
 static void 		ArrangeWhenIdle _ANSI_ARGS_((MasterInfo * masterPtr));
-static void		CancelArrangeWhenIdle _ANSI_ARGS_((
-			    MasterInfo * masterPtr));
 static void 		CalculateMasterSize _ANSI_ARGS_((MasterInfo *master));
 static void 		CheckIntergrity _ANSI_ARGS_((FormInfo * clientPtr));
 static MasterInfo * 	GetMasterInfo _ANSI_ARGS_((Tk_Window tkwin,
@@ -80,42 +71,26 @@ static int 		TixFm_CheckArgv _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int argc, char ** argv));
 static void		TixFm_LostSlaveProc _ANSI_ARGS_((
 			    ClientData clientData, Tk_Window tkwin));
+static void		TixFm_LostMasterProc _ANSI_ARGS_((
+			    ClientData clientData, Tk_Window tkwin));
+static void 		TixFm_MasterReqProc _ANSI_ARGS_((ClientData clientData,
+			    Tk_Window tkwin));
 static void 		TixFm_ReqProc _ANSI_ARGS_((ClientData clientData,
 			    Tk_Window tkwin));
 static int 		PlaceAllClients _ANSI_ARGS_((MasterInfo *masterPtr));
-static int		PlaceClient _ANSI_ARGS_((FormInfo *clientPtr));
+
 static int		PlaceSide_AttOpposite _ANSI_ARGS_((
 			    FormInfo *clientPtr, int axis,  int which));
 static int 		PlaceSide_AttAbsolute _ANSI_ARGS_((
 			    FormInfo *clientPtr, int axis,  int which));
 static int 		PlaceSide_AttNone _ANSI_ARGS_((
 			    FormInfo *clientPtr, int axis,  int which));
-static int		PlaceSide_AttParallel _ANSI_ARGS_((FormInfo *clientPtr,
-			    int axis, int which));
 static int 		PlaceSimpleCase _ANSI_ARGS_((
 			    FormInfo *clientPtr, int axis,  int which));
 static int 		PlaceWithSpring _ANSI_ARGS_((
 			    FormInfo *clientPtr, int axis,  int which));
 static 			int ReqSize  _ANSI_ARGS_((Tk_Window tkwin,
 			    int axis));
-static void 		UnmapClient _ANSI_ARGS_((FormInfo *clientPtr));
-static void		MapClient _ANSI_ARGS_((FormInfo *clientPtr,
-			    int x, int y, int width, int height));
-static int		PinnSide_AttNone _ANSI_ARGS_((FormInfo *clientPtr,
-			    int axis, int which));
-static int		PinnSide_AttPercent _ANSI_ARGS_((FormInfo *clientPtr,
-			    int axis, int which));
-static int		PinnSide_AttOpposite _ANSI_ARGS_((FormInfo *clientPtr,
-			    int axis, int which));
-static int		PinnSide_AttParallel _ANSI_ARGS_((FormInfo *clientPtr,
-			    int axis, int which));
-static SpringLink *	AllocSpringLink _ANSI_ARGS_((void));
-static void		FreeSpringLink _ANSI_ARGS_((SpringLink * link));
-static void		FreeSpringList _ANSI_ARGS_((SpringList * listPtr));
-static void		AddRightSprings _ANSI_ARGS_((SpringList * listPtr,
-			    FormInfo *clientPtr));
-static void		AddLeftSprings _ANSI_ARGS_((SpringList * listPtr,
-			    FormInfo *clientPtr));
 
 /*
  * A macro used to simplify the "pinn client" code
@@ -141,6 +116,12 @@ static Tk_GeomMgr formType = {
     TixFm_LostSlaveProc,	/* lostSlaveProc */
 };
 
+static Tk_GeomMgr masterType = {
+    "tixForm",			/* name */
+    TixFm_MasterReqProc,	/* requestProc */
+    TixFm_LostMasterProc,	/* lostSlaveProc */
+};
+
 /*
  * Hash table used to map from Tk_Window tokens to corresponding
  * FormInfo structures:
@@ -606,9 +587,9 @@ FormInfo * TixFm_FindClientPtrByName(interp, name, topLevel)
 
 
 static int TestAndArrange(masterPtr)
-    MasterInfo *masterPtr;
+    register MasterInfo *masterPtr;
 {
-    FormInfo *clientPtr;
+    register FormInfo *clientPtr;
     int i,j;
 
     /*
@@ -696,7 +677,7 @@ static void MapClient(clientPtr, x, y, width, height)
 }
 
 static void ArrangeWhenIdle(masterPtr)
-    MasterInfo * masterPtr;
+    register MasterInfo * masterPtr;
 {
     if (!(masterPtr->flags.repackPending || masterPtr->flags.isDeleted)) {
 	masterPtr->flags.repackPending = 1;
@@ -704,9 +685,8 @@ static void ArrangeWhenIdle(masterPtr)
     }
 }
 
-static void
-CancelArrangeWhenIdle(masterPtr)
-    MasterInfo * masterPtr;
+static void CancelArrangeWhenIdle(masterPtr)
+    register MasterInfo * masterPtr;
 {
     if (masterPtr->flags.repackPending) {
 	Tk_CancelIdleCall(ArrangeGeometry, (ClientData) masterPtr);
@@ -725,8 +705,8 @@ static void ArrangeGeometry(clientData)
     ClientData clientData;	/* Structure describing parent whose clients
 				 * are to be re-layed out. */
 {
-    MasterInfo *masterPtr;
-    FormInfo *clientPtr;
+    register MasterInfo *masterPtr;
+    register FormInfo *clientPtr;
     int i, j, coord[2][2];
     int mSize[2];			/* Size of master */
     int cSize[2];			/* Size of client */
@@ -853,9 +833,8 @@ static void ArrangeGeometry(clientData)
     masterPtr->flags.repackPending = 0;
 }
 
-static int
-PinnSide_AttNone(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to pinn down */
+static int PinnSide_AttNone(clientPtr, axis, which)
+    register FormInfo *clientPtr;	/* The client to pinn down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
@@ -892,9 +871,8 @@ PinnSide_AttNone(clientPtr, axis, which)
     return TCL_OK;
 }
 
-static int
-PinnSide_AttPercent(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to pinn down */
+static int PinnSide_AttPercent(clientPtr, axis, which)
+    register FormInfo *clientPtr;	/* The client to pinn down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
@@ -904,13 +882,12 @@ PinnSide_AttPercent(clientPtr, axis, which)
     return TCL_OK;
 }
 
-static int
-PinnSide_AttOpposite(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to pinn down */
+static int PinnSide_AttOpposite(clientPtr, axis, which)
+    register FormInfo *clientPtr;	/* The client to pinn down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
-    FormInfo * attachPtr;
+    register FormInfo * attachPtr;
 
     attachPtr = clientPtr->att[axis][which].widget;
 
@@ -925,13 +902,12 @@ PinnSide_AttOpposite(clientPtr, axis, which)
     return TCL_OK;
 }
 
-static int
-PinnSide_AttParallel(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to pinn down */
+static int PinnSide_AttParallel(clientPtr, axis, which)
+    register FormInfo *clientPtr;	/* The client to pinn down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
-    FormInfo * attachPtr;
+    register FormInfo * attachPtr;
 
     attachPtr = clientPtr->att[axis][which].widget;
 
@@ -948,7 +924,7 @@ PinnSide_AttParallel(clientPtr, axis, which)
 
 
 static int PinnClientSide(clientPtr, axis, which, isSelf)
-    FormInfo *clientPtr;	/* The client to pinn down */
+    register FormInfo *clientPtr;	/* The client to pinn down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
     int isSelf;
@@ -1007,9 +983,9 @@ static int PinnClientSide(clientPtr, axis, which, isSelf)
 }
 
 static int PinnClient(clientPtr)
-    FormInfo *clientPtr;
+    register FormInfo *clientPtr;
 {
-    int i;
+    register int i;
 
     for (i=0; i<2; i++) {
 	if (!(clientPtr->sideFlags[i] & PINNED_SIDE0)) {
@@ -1041,9 +1017,9 @@ static int PinnClient(clientPtr)
  *--------------------------------------------------------------
  */
 static void CalculateMasterSize(masterPtr)
-    MasterInfo *masterPtr;
+    register MasterInfo *masterPtr;
 {
-    FormInfo *clientPtr;
+    register FormInfo *clientPtr;
     int i, cSize[2];
     int req[2];
     int intBWidth;
@@ -1183,7 +1159,7 @@ TixFm_StructureProc(clientData, eventPtr)
 					 * referred to by eventPtr. */
     XEvent *eventPtr;			/* Describes what just happened. */
 {
-    FormInfo *clientPtr = (FormInfo *) clientData;
+    register FormInfo *clientPtr = (FormInfo *) clientData;
 
     switch (eventPtr->type) {
       case ConfigureNotify:
@@ -1212,7 +1188,7 @@ TixFm_ReqProc(clientData, tkwin)
     Tk_Window tkwin;		/* Other Tk-related information
 				 * about the window. */
 {
-    FormInfo *clientPtr = (FormInfo *) clientData;
+    register FormInfo *clientPtr = (FormInfo *) clientData;
 
     if (clientPtr) {
 	ArrangeWhenIdle(clientPtr->master);
@@ -1225,7 +1201,7 @@ MasterStructureProc(clientData, eventPtr)
 					 * referred to by eventPtr. */
     XEvent *eventPtr;			/* Describes what just happened. */
 {
-    MasterInfo *masterPtr = (MasterInfo *) clientData;
+    register MasterInfo *masterPtr = (MasterInfo *) clientData;
 
     switch (eventPtr->type) {
       case ConfigureNotify:
@@ -1245,6 +1221,27 @@ MasterStructureProc(clientData, eventPtr)
 	break;
     }
 }
+static void
+TixFm_MasterReqProc(clientData, tkwin)
+    ClientData clientData;	/* TixForm's information about
+				 * window that got new preferred
+				 * geometry.  */
+    Tk_Window tkwin;		/* Other Tk-related information
+				 * about the window. */
+{
+    /* Do nothing */
+}
+
+static void
+TixFm_LostMasterProc(clientData, tkwin)
+    ClientData clientData;	/* Form structure for slave window that
+				 * was stolen away. */
+    Tk_Window tkwin;		/* Tk's handle for the slave window. */
+{
+    register MasterInfo *masterPtr = (MasterInfo *) clientData;
+
+    TixFm_DeleteMaster(masterPtr);
+}
 
 /*
  *--------------------------------------------------------------
@@ -1268,7 +1265,7 @@ TixFm_LostSlaveProc(clientData, tkwin)
 				 * was stolen away. */
     Tk_Window tkwin;		/* Tk's handle for the slave window. */
 {
-    FormInfo *clientPtr = (FormInfo *) clientData;
+    register FormInfo *clientPtr = (FormInfo *) clientData;
 
     Tk_DeleteEventHandler(clientPtr->tkwin, StructureNotifyMask,
 	TixFm_StructureProc, (ClientData) clientPtr);
@@ -1445,8 +1442,7 @@ void TixFm_Unlink(clientPtr)
     TixFm_UnlinkFromMaster(clientPtr);
 
     /* Eventually free this clientPtr structure */
-    hPtr = Tcl_FindHashEntry(&formInfoHashTable,(char*)clientPtr->tkwin);
-    if (hPtr != NULL) {
+    if (hPtr = Tcl_FindHashEntry(&formInfoHashTable,(char*)clientPtr->tkwin)) {
 	Tcl_DeleteHashEntry(hPtr);
     }
     clientPtr->tkwin = NULL;
@@ -1483,7 +1479,7 @@ TixFm_GetFormInfo(tkwin, create)
 				 * FormInfo structure is desired. */
     int create;
 {
-    FormInfo *clientPtr;
+    register FormInfo *clientPtr;
     Tcl_HashEntry *hPtr;
     int isNew;
     int i,j;
@@ -1550,7 +1546,7 @@ GetMasterInfo(tkwin, create)
     int create;			/* Should I create the MasterInfo if it
 				 * does not exist? */
 {
-    MasterInfo *masterPtr;
+    register MasterInfo *masterPtr;
     Tcl_HashEntry *hPtr;
     int isNew;
 
@@ -1616,7 +1612,7 @@ GetMasterInfo(tkwin, create)
  *----------------------------------------------------------------------
  */
 static int PlaceSide_AttNone(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to Place down */
+    register FormInfo *clientPtr;	/* The client to Place down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
@@ -1651,7 +1647,7 @@ static int PlaceSide_AttNone(clientPtr, axis, which)
 }
 
 static int PlaceSide_AttAbsolute(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to Place down */
+    register FormInfo *clientPtr;	/* The client to Place down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
@@ -1669,11 +1665,11 @@ static int PlaceSide_AttAbsolute(clientPtr, axis, which)
 }
 
 static int PlaceSide_AttOpposite(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to Place down */
+    register FormInfo *clientPtr;	/* The client to Place down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
-    FormInfo * attachPtr;
+    register FormInfo * attachPtr;
 
     attachPtr = clientPtr->att[axis][which].widget;
 
@@ -1685,11 +1681,11 @@ static int PlaceSide_AttOpposite(clientPtr, axis, which)
 }
 
 static int PlaceSide_AttParallel(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to Place down */
+    register FormInfo *clientPtr;	/* The client to Place down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
-    FormInfo * attachPtr;
+    register FormInfo * attachPtr;
 
     attachPtr = clientPtr->att[axis][which].widget;
 
@@ -1703,7 +1699,7 @@ static int PlaceSide_AttParallel(clientPtr, axis, which)
 
 
 static int PlaceSimpleCase(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to Place down */
+    register FormInfo *clientPtr;	/* The client to Place down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
@@ -1744,15 +1740,25 @@ static int PlaceSimpleCase(clientPtr, axis, which)
     return TCL_OK;
 }
 
+typedef struct SpringLink {
+    struct SpringLink * next;
+    FormInfo *clientPtr;
+} SpringLink;
+
+
+typedef struct SpringList { 
+    SpringLink * head, * tail;
+    int num;
+} SpringList;
+
+
 /* ToDo: I'll make this more efficient by pre-allocating some links */
-static SpringLink *
-AllocSpringLink()
+static SpringLink * AllocSpringLink()
 {
-    return (SpringLink *) ckalloc(sizeof(SpringLink));
+    return (SpringLink *) malloc(sizeof(SpringLink));
 }
 
-static void
-FreeSpringLink(link)
+static void FreeSpringLink(link)
     SpringLink * link;
 {
     ckfree((char*)link);
@@ -1770,8 +1776,7 @@ static void FreeSpringList(listPtr)
     }
 }
 
-static void
-AddRightSprings(listPtr, clientPtr)
+static void AddRightSprings(listPtr, clientPtr)
     SpringList * listPtr;
     FormInfo *clientPtr;
 {
@@ -1789,8 +1794,7 @@ AddRightSprings(listPtr, clientPtr)
     ++ listPtr->num;
 }
 
-static void
-AddLeftSprings(listPtr,clientPtr)
+static void AddLeftSprings(listPtr,clientPtr)
     SpringList * listPtr;
     FormInfo *clientPtr;
 {
@@ -1803,9 +1807,8 @@ AddLeftSprings(listPtr,clientPtr)
     ++ listPtr->num;
 }
 
-static int
-PlaceWithSpring(clientPtr, axis, which)
-    FormInfo *clientPtr;	/* The client to Place down */
+static int PlaceWithSpring(clientPtr, axis, which)
+    register FormInfo *clientPtr;	/* The client to Place down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
 {
@@ -1900,11 +1903,9 @@ PlaceWithSpring(clientPtr, axis, which)
 	goto fail;
     }
 
-    /*
-     * Now calculate the total requested sizes of the spring group
-     */
-    totalSize     = (float)(0.0);
-    totalStrength = (float)(0.0);
+    /* Now calculate the total requested sizes of the spring group*/
+    totalSize=0;
+    totalStrength=0;
     for (link=springs.head; link; link=link->next) {
 	int size = ReqSize(link->clientPtr->tkwin, axis);
 
@@ -1935,8 +1936,8 @@ PlaceWithSpring(clientPtr, axis, which)
     }
 
     disp = boundary[0];
-    if (totalStrength <= 0.0) {
-	totalStrength = (float)(1.0);
+    if (totalStrength <= 0) {
+	totalStrength = 1;
     }
     for (link=springs.head; link; link=link->next) {
 	float spring0, spring1;
@@ -1946,11 +1947,11 @@ PlaceWithSpring(clientPtr, axis, which)
 	spring0 = (float)link->clientPtr->spring[axis][0];
 	spring1 = (float)link->clientPtr->spring[axis][1];
 
-	if (spring0 < (float)(0.0)) {
-	    spring0 = (float)(0.0);
+	if (spring0 < 0) {
+	    spring0 = 0;
 	}
-	if (spring1 < (float)(0.0)) {
-	    spring1 = (float)(0.0);
+	if (spring1 < 0) {
+	    spring1 = 0;
 	}
 
 	/* Divide by two: because two consecutive clients share the same
@@ -1961,17 +1962,17 @@ PlaceWithSpring(clientPtr, axis, which)
 	    if (spring0 > 0 && link->clientPtr->spring[axis][0] % 2 == 1) {
 		adjust = 1;
 	    }
-	    spring0 /= (float)(2.0);
+	    spring0 /= 2.0;
 	}
 	if (link !=springs.tail) {
-	    spring1 /= (float)(2.0);
+	    spring1 /= 2.0;
 	}
 
 	gap0 = (int)(gap * spring0 / totalStrength) + adjust;
 	gap1 = (int)(gap * spring1 / totalStrength);
 
 	if (link->clientPtr->fill[axis]) {
-	    link->clientPtr->posn[axis][0] = (int)disp;
+	    link->clientPtr->posn[axis][0] = disp;
 	    disp += gap0;
 	    disp += gap1;
 	    disp += ReqSize(link->clientPtr->tkwin, axis);
@@ -1981,20 +1982,18 @@ PlaceWithSpring(clientPtr, axis, which)
 	    if (link->next == NULL) {
 		disp = boundary[1];
 	    }
-	    link->clientPtr->posn[axis][1] = (int)disp;
+	    link->clientPtr->posn[axis][1] = disp;
 	} else {
 	    disp += gap0;
-	    link->clientPtr->posn[axis][0] = (int)disp;
+	    link->clientPtr->posn[axis][0] = disp;
 	    disp += ReqSize(link->clientPtr->tkwin, axis);
-	    link->clientPtr->posn[axis][1] = (int)disp;
+	    link->clientPtr->posn[axis][1] = disp;
 	    disp += gap1;
 
-	    /*
-	     * Somehow there may be a round-off right at the end of the
-	     * list --> kludge
-	     */
+	    /* Somehow there may be a round-off right at the end of the
+	     * list --> kludge*/
 	    if (link->next == NULL && gap1 < 0.001) {
-		link->clientPtr->posn[axis][1] =  (int)boundary[1];
+		link->clientPtr->posn[axis][1] =  boundary[1];
 	    }
 	}
 
@@ -2014,7 +2013,7 @@ PlaceWithSpring(clientPtr, axis, which)
 }
 
 static int PlaceClientSide(clientPtr, axis, which, isSelf)
-    FormInfo *clientPtr;	/* The client to Place down */
+    register FormInfo *clientPtr;	/* The client to Place down */
     int axis;				/* 0 = x axis, 1 = yaxis */
     int which;				/* 0 = min side, 1= max side */
     int isSelf;
@@ -2058,9 +2057,9 @@ static int PlaceClientSide(clientPtr, axis, which, isSelf)
 }
 
 static int PlaceClient(clientPtr)
-    FormInfo *clientPtr;
+    register FormInfo *clientPtr;
 {
-    int i;
+    register int i;
 
     for (i=0; i<2; i++) {
 	if (!(clientPtr->sideFlags[i] & PINNED_SIDE0)) {
@@ -2077,7 +2076,7 @@ static int PlaceClient(clientPtr)
 static int PlaceAllClients(masterPtr)
     MasterInfo * masterPtr;
 {
-    FormInfo *clientPtr;
+    register FormInfo *clientPtr;
     int i;
 
     /*
