@@ -1,6 +1,3 @@
-
-/*	$Id: tixGeometry.c,v 1.3 2004/03/28 02:44:56 hobbs Exp $	*/
-
 /* 
  * tixGeometry.c --
  *
@@ -13,8 +10,9 @@
  *
  */
 
-#include <tixPort.h>
-#include <tixInt.h>
+#include <tkPort.h>
+#include <tk.h>
+#include <tix.h>
 
 static Tcl_HashTable clientTable;	/* hash table for geometry managers */
 
@@ -186,12 +184,12 @@ TIX_DEFINE_CMD(Tix_ManageGeometryCmd)
     if (!isNew) {
 	cnPtr = (ClientStruct *) Tcl_GetHashValue(hashPtr);
 	ckfree(cnPtr->command);
-	cnPtr->command = tixStrDup(argv[2]);
+	cnPtr->command = (char*)strdup(argv[2]);
     } else {
 	cnPtr = (ClientStruct *) ckalloc(sizeof(ClientStruct));
 	cnPtr->tkwin     = tkwin;
 	cnPtr->interp    = interp;
-	cnPtr->command   = tixStrDup(argv[2]);
+	cnPtr->command   = (char*)strdup(argv[2]);
 	cnPtr->isDeleted = 0;
 	Tcl_SetHashValue(hashPtr, cnPtr);
 
@@ -331,9 +329,7 @@ TIX_DEFINE_CMD(Tix_FlushXCmd)
 	return TCL_ERROR;
     }
 
-#if !defined(__WIN32__) && !defined(MAC_TCL) /* UNIX */
     XFlush(Tk_Display(tkwin));
-#endif
     return TCL_OK;
 }
 
@@ -358,3 +354,25 @@ TIX_DEFINE_CMD(Tix_UnmapWindowCmd)
     Tk_UnmapWindow(tkwin);
     return TCL_OK;
 }
+
+/*
+ *
+ * argv[1] = clientPathName
+ *
+ */
+TIX_DEFINE_CMD(Tix_RaiseWindowCmd)
+{
+    Tk_Window 		topLevel = (Tk_Window)clientData;
+    Tk_Window tkwin;
+
+    if (argc != 2) {
+	return Tix_ArgcError(interp, argc, argv, 1, "pathname");
+    }
+
+    if ((tkwin = Tk_NameToWindow(interp, argv[1], topLevel)) == NULL) {
+	return TCL_ERROR;
+    }
+
+    XRaiseWindow(Tk_Display(tkwin), Tk_WindowId(tkwin));
+    return TCL_OK;
+}
