@@ -1,6 +1,3 @@
-
-/*	$Id: tixImgCmp.c,v 1.6 2004/03/28 02:44:56 hobbs Exp $	*/
-
 /* 
  * tkImgCmp.c --
  *
@@ -13,12 +10,12 @@
  *
  */
 
-#include <tixPort.h>
-#include <tixInt.h>
+#include <tkInt.h>
+#include <tkPort.h>
+#include <tix.h>
 #include <tixDef.h>
 
-/*
- * ToDo: 
+/* ToDo: 
  *	- lineconfig and itemconfig command
  */
 
@@ -35,10 +32,6 @@ typedef struct CmpMaster {
 				 * it when the image goes away).  NULL means
 				 * the image command has already been
 				 * deleted. */
-    Display * display;		/* Display of the the window associated with
-				 * this image. We need to keep it
-				 * because Tk_Display(CmpMaster.tkwin) may
-				 * be invalid. */
     Tk_Window tkwin;		/* default options are taken from this window.
 				 * If undefined, will use the main window
 				 * of this application */
@@ -53,7 +46,7 @@ typedef struct CmpMaster {
     int relief;			/* Indicates whether window as a whole is
 				 * raised, sunken, or flat. */
 
-    TixFont font;		/* Information about text font.*/
+    XFontStruct *fontPtr;	/* Information about text font.*/
     XColor *foreground;		/* Color for drawing text and bitmaps */
     GC gc;			/* default GC for drawing text. */
 
@@ -126,7 +119,7 @@ typedef struct CmpTextItem {
     int underline;		/* Index of character to underline.  < 0 means
 				 * don't underline anything. */
     XColor *foreground;
-    TixFont font;		/* Information about text font, or NULL. */
+    XFontStruct *fontPtr;	/* Information about text font, or NULL. */
     GC gc;			/* GC for drawing the bitmap. */
 } CmpTextItem;
 
@@ -142,7 +135,7 @@ typedef union CmpItemPtr {
  * The type record for bitmap images:
  */
 static int		ImgCmpCreate _ANSI_ARGS_((Tcl_Interp *interp,
-			    char *name, int argc, Tcl_Obj *CONST objv[],
+			    char *name, int argc, char **argv,
 			    Tk_ImageType *typePtr, Tk_ImageMaster master,
 			    ClientData *clientDataPtr));
 static ClientData	ImgCmpGet _ANSI_ARGS_((Tk_Window tkwin,
@@ -154,18 +147,15 @@ static void		ImgCmpDisplay _ANSI_ARGS_((ClientData clientData,
 static void		ImgCmpFree _ANSI_ARGS_((ClientData clientData,
 			    Display *display));
 static void		ImgCmpDelete _ANSI_ARGS_((ClientData clientData));
-static void		ImgCmpFreeResources _ANSI_ARGS_((ClientData clientData));
 
 Tk_ImageType tixCompoundImageType = {
-    "compound",                     /* name */
-    ImgCmpCreate,                   /* createProc */
-    ImgCmpGet,                      /* getProc */
-    ImgCmpDisplay,                  /* displayProc */
-    ImgCmpFree,                     /* freeProc */
-    ImgCmpDelete,                   /* deleteProc */
-    NULL,                           /* postscriptProc (tk8.3 or later)*/
-    NULL,                           /* nextPtr */
-    NULL,                           /* reserved */
+    "compound",			/* name */
+    ImgCmpCreate,		/* createProc */
+    ImgCmpGet,			/* getProc */
+    ImgCmpDisplay,		/* displayProc */
+    ImgCmpFree,			/* freeProc */
+    ImgCmpDelete,		/* deleteProc */
+    (Tk_ImageType *) NULL	/* nextPtr */
 };
 
 static Tk_ConfigSpec configSpecs[] = {
@@ -190,7 +180,7 @@ static Tk_ConfigSpec configSpecs[] = {
        (char *) NULL, 0, 0},
 
     {TK_CONFIG_FONT, "-font", "font", "Font",
-       DEF_CMPIMAGE_FONT, Tk_Offset(CmpMaster, font), 0},
+       DEF_CMPIMAGE_FONT, Tk_Offset(CmpMaster, fontPtr), 0},
 
     {TK_CONFIG_COLOR, "-foreground", "foreground", "Foreground",
        DEF_CMPIMAGE_FG_COLOR, Tk_Offset(CmpMaster, foreground),
@@ -291,7 +281,7 @@ static Tk_ConfigSpec textConfigSpecs[] = {
        (char *) NULL, 0, 0},
 
     {TK_CONFIG_FONT, "-font", (char *) NULL, (char *) NULL,
-       "", Tk_Offset(CmpTextItem, font), TK_CONFIG_NULL_OK},
+       "", Tk_Offset(CmpTextItem, fontPtr), TK_CONFIG_NULL_OK},
 
     {TK_CONFIG_COLOR, "-foreground", "foreground", "Foreground",
        "", Tk_Offset(CmpTextItem, foreground),
@@ -324,28 +314,26 @@ static Tk_ConfigSpec textConfigSpecs[] = {
  */
 
 static int		ImgCmpCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int argc, CONST84 char **argv));
+			    Tcl_Interp *interp, int argc, char **argv));
 static void		ImgCmpCmdDeletedProc _ANSI_ARGS_((
 			    ClientData clientData));
 static int		ImgCmpConfigureMaster _ANSI_ARGS_((
-			    CmpMaster *masterPtr, int argc, CONST84 char **argv,
+			    CmpMaster *masterPtr, int argc, char **argv,
 			    int flags));
 CmpBitmapItem *		AddNewBitmap _ANSI_ARGS_((CmpMaster *masterPtr,
 			    CmpLine *line,
-			    int argc, CONST84 char **argv));
+			    int argc, char **argv));
 CmpImageItem * 		AddNewImage _ANSI_ARGS_((CmpMaster *masterPtr,
 			    CmpLine *line,
-			    int argc, CONST84 char **argv));
+			    int argc, char **argv));
 CmpSpaceItem * 		AddNewSpace _ANSI_ARGS_((CmpMaster *masterPtr,
 			    CmpLine *line,
-			    int argc, CONST84 char **argv));
+			    int argc, char **argv));
 CmpTextItem * 		AddNewText _ANSI_ARGS_((CmpMaster *masterPtr,
 			    CmpLine *line,
-			    int argc, CONST84 char **argv));
+			    int argc, char **argv));
 CmpLine* 		AddNewLine _ANSI_ARGS_((CmpMaster *masterPtr,
-			    int argc, CONST84 char **argv));
-static void		CalculateMasterSize _ANSI_ARGS_((
-			    ClientData clientData));
+			    int argc, char **argv));
 static void		ChangeImageWhenIdle _ANSI_ARGS_((
 			    CmpMaster *masterPtr));
 static void		ImageProc _ANSI_ARGS_((ClientData clientData,
@@ -375,12 +363,12 @@ static void		CmpEventProc _ANSI_ARGS_((ClientData clientData,
 
 	/* ARGSUSED */
 static int
-ImgCmpCreate(interp, name, argc, objv, typePtr, master, clientDataPtr)
+ImgCmpCreate(interp, name, argc, argv, typePtr, master, clientDataPtr)
     Tcl_Interp *interp;		/* Interpreter for application containing
 				 * image. */
     char *name;			/* Name to use for image. */
     int argc;			/* Number of arguments. */
-    Tcl_Obj *CONST objv[];	/* Argument strings for options (doesn't
+    char **argv;		/* Argument strings for options (doesn't
 				 * include image name or type). */
     Tk_ImageType *typePtr;	/* Pointer to our type record (not used). */
     Tk_ImageMaster master;	/* Token for image, to be used by us in
@@ -389,24 +377,6 @@ ImgCmpCreate(interp, name, argc, objv, typePtr, master, clientDataPtr)
 				 * it will be returned in later callbacks. */
 {
     CmpMaster *masterPtr;
-    int i;
-    CONST84 char *argvbuf[10];
-    CONST84 char **argv = argvbuf;
-
-    /*
-     * Convert the objv arguments into string equivalent.
-     */
-    if (argc > 10) {
-	argv = (CONST84 char **) ckalloc(argc * sizeof(char *));
-    }
-    for (i = 0; i < argc; i++) {
-        /*
-         * no need to free the value returned by Tcl_GetString. It's
-         * managed by Tcl's object system.
-         */
-
-	argv[i] = Tcl_GetString(objv[i]);
-    }
 
     masterPtr = (CmpMaster *) ckalloc(sizeof(CmpMaster));
     masterPtr->tkMaster = master;
@@ -414,7 +384,6 @@ ImgCmpCreate(interp, name, argc, objv, typePtr, master, clientDataPtr)
     masterPtr->imageCmd = Tcl_CreateCommand(interp, name, ImgCmpCmd,
 	(ClientData)masterPtr, ImgCmpCmdDeletedProc);
     masterPtr->tkwin = NULL;
-    masterPtr->display = NULL;
     masterPtr->width = 0;
     masterPtr->height = 0;
     masterPtr->padX = 0;
@@ -424,7 +393,7 @@ ImgCmpCreate(interp, name, argc, objv, typePtr, master, clientDataPtr)
     masterPtr->borderWidth = 0;
     masterPtr->background = NULL;
     masterPtr->relief = 0;
-    masterPtr->font = NULL;
+    masterPtr->fontPtr = NULL;
     masterPtr->foreground = NULL;
     masterPtr->gc = None;
     masterPtr->showBackground = 0;
@@ -433,15 +402,9 @@ ImgCmpCreate(interp, name, argc, objv, typePtr, master, clientDataPtr)
 	
     if (ImgCmpConfigureMaster(masterPtr, argc, argv, 0) != TCL_OK) {
 	ImgCmpDelete((ClientData) masterPtr);
-	if (argv != argvbuf) {
-	    ckfree((char *) argv);
-	}
 	return TCL_ERROR;
     }
     *clientDataPtr = (ClientData) masterPtr;
-    if (argv != argvbuf) {
-	ckfree((char *) argv);
-    }
     return TCL_OK;
 }
 
@@ -469,7 +432,7 @@ ImgCmpConfigureMaster(masterPtr, argc, argv, flags)
     CmpMaster *masterPtr;	/* Pointer to data structure describing
 				 * overall bitmap image to (reconfigure). */
     int argc;			/* Number of entries in argv. */
-    CONST84 char **argv;	/* Pairs of configuration options for image. */
+    char **argv;		/* Pairs of configuration options for image. */
     int flags;			/* Flags to pass to Tk_ConfigureWidget,
 				 * such as TK_CONFIG_ARGV_ONLY. */
 {
@@ -497,22 +460,21 @@ ImgCmpConfigureMaster(masterPtr, argc, argv, flags)
 	    "no value given for -window option.", NULL);
 	return TCL_ERROR;
     }
-    masterPtr->display = Tk_Display(masterPtr->tkwin);
 
     if (Tk_ConfigureWidget(masterPtr->interp, masterPtr->tkwin,
-	    configSpecs, argc, argv, (char *) masterPtr, flags) != TCL_OK) {
+	configSpecs, argc, argv, (char *) masterPtr, flags)
+	!= TCL_OK) {
 	return TCL_ERROR;
     }
 
     Tk_CreateEventHandler(masterPtr->tkwin,
 	StructureNotifyMask, CmpEventProc, (ClientData)masterPtr);
-
     /*
      * Get the default GC for text and bitmaps
      */
     gcValues.foreground = masterPtr->foreground->pixel;
     gcValues.background = Tk_3DBorderColor(masterPtr->background)->pixel;
-    gcValues.font = TixFontId(masterPtr->font);
+    gcValues.font = masterPtr->fontPtr->fid;
     gcValues.graphics_exposures = False;
     newGC = Tk_GetGC(masterPtr->tkwin,
 	 GCBackground|GCForeground|GCFont|GCGraphicsExposures,
@@ -548,7 +510,7 @@ ImgCmpCmd(clientData, interp, argc, argv)
     ClientData clientData;	/* Information about button widget. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int argc;			/* Number of arguments. */
-    CONST84 char **argv;	/* Argument strings. */
+    char **argv;		/* Argument strings. */
 {
     CmpMaster *masterPtr = (CmpMaster *) clientData;
     int c, code;
@@ -665,11 +627,9 @@ ImgCmpCmd(clientData, interp, argc, argv)
 	}
 	return code;
     } else if ((c == 'i') && (strncmp(argv[1], "itemconfigure", length)== 0)) {
-	Tcl_AppendResult(interp, "unimplemented", NULL);
-	return TCL_ERROR;
+
     } else if ((c == 'l') && (strncmp(argv[1], "lineconfigure", length)== 0)) {
-	Tcl_AppendResult(interp, "unimplemented", NULL);
-	return TCL_ERROR;
+
     } else {
 	Tcl_AppendResult(interp, "bad option \"", argv[1],
 	    "\": must be cget or configure", (char *) NULL);
@@ -687,7 +647,7 @@ CmpLine *
 AddNewLine(masterPtr, argc, argv)
     CmpMaster *masterPtr;
     int argc;			/* Number of arguments. */
-    CONST84 char **argv;	/* Argument strings. */
+    char **argv;		/* Argument strings. */
 {
     CmpLine * lPtr = (CmpLine *)ckalloc(sizeof(CmpLine));
 
@@ -703,15 +663,14 @@ AddNewLine(masterPtr, argc, argv)
     lPtr->anchor = TK_ANCHOR_CENTER;
 
     if (Tk_ConfigureWidget(masterPtr->interp, masterPtr->tkwin,
-	    lineConfigSpecs, argc, argv, (char *) lPtr, 
-	    TK_CONFIG_ARGV_ONLY) != TCL_OK) {
+	lineConfigSpecs, argc, argv, (char *) lPtr, 
+	TK_CONFIG_ARGV_ONLY) != TCL_OK) {
+
 	FreeLine(lPtr);
 	return NULL;
     }
 
-    /*
-     * Append to the end of the master's lines
-     */
+    /* append to the end of the master's lines */
     if (masterPtr->lineHead == NULL) {
 	masterPtr->lineHead = masterPtr->lineTail = lPtr;
     } else {
@@ -732,7 +691,7 @@ AddNewBitmap(masterPtr, line, argc, argv)
     CmpMaster *masterPtr;
     CmpLine *line;
     int argc;			/* Number of arguments. */
-    CONST84 char **argv;	/* Argument strings. */
+    char **argv;		/* Argument strings. */
 {
     CmpItemPtr p;
     XGCValues gcValues;
@@ -753,8 +712,9 @@ AddNewBitmap(masterPtr, line, argc, argv)
     p.bitmap->gc = None;
 
     if (Tk_ConfigureWidget(masterPtr->interp, masterPtr->tkwin,
-	    bitmapConfigSpecs, argc, argv, (char *) p.bitmap, 
-	    TK_CONFIG_ARGV_ONLY) != TCL_OK) {
+	bitmapConfigSpecs, argc, argv, (char *) p.bitmap, 
+	TK_CONFIG_ARGV_ONLY) != TCL_OK) {
+
 	goto error;
     }
 
@@ -792,7 +752,7 @@ AddNewImage(masterPtr, line, argc, argv)
     CmpMaster *masterPtr;
     CmpLine *line;
     int argc;			/* Number of arguments. */
-    CONST84 char **argv;	/* Argument strings. */
+    char **argv;		/* Argument strings. */
 {
     CmpItemPtr p;
 
@@ -811,8 +771,9 @@ AddNewImage(masterPtr, line, argc, argv)
     p.image->image = NULL;
 
     if (Tk_ConfigureWidget(masterPtr->interp, masterPtr->tkwin,
-	    imageConfigSpecs, argc, argv, (char *) p.image, 
-	    TK_CONFIG_ARGV_ONLY) != TCL_OK) {
+	imageConfigSpecs, argc, argv, (char *) p.image, 
+	TK_CONFIG_ARGV_ONLY) != TCL_OK) {
+
 	goto error;
     }
 
@@ -843,7 +804,7 @@ AddNewSpace(masterPtr, line, argc, argv)
     CmpMaster *masterPtr;
     CmpLine *line;
     int argc;			/* Number of arguments. */
-    CONST84 char **argv;	/* Argument strings. */
+    char **argv;		/* Argument strings. */
 {
     CmpItemPtr p;
 
@@ -881,7 +842,7 @@ AddNewText(masterPtr, line, argc, argv)
     CmpMaster *masterPtr;
     CmpLine *line;
     int argc;			/* Number of arguments. */
-    CONST84 char **argv;	/* Argument strings. */
+    char **argv;		/* Argument strings. */
 {
     CmpItemPtr p;
     XGCValues gcValues;
@@ -903,7 +864,7 @@ AddNewText(masterPtr, line, argc, argv)
     p.text->wrapLength = 0;
 
     p.text->foreground = NULL;
-    p.text->font = NULL;
+    p.text->fontPtr = NULL;
     p.text->gc = None;
 
     if (Tk_ConfigureWidget(masterPtr->interp, masterPtr->tkwin,
@@ -919,10 +880,10 @@ AddNewText(masterPtr, line, argc, argv)
     } else {
 	gcValues.foreground = masterPtr->foreground->pixel;
     }
-    if (p.text->font) {
-	gcValues.font = TixFontId(p.text->font);
+    if (p.text->fontPtr) {
+	gcValues.font = p.text->fontPtr->fid;
     } else {
-	gcValues.font = TixFontId(masterPtr->font);
+	gcValues.font = masterPtr->fontPtr->fid;
     }
     gcValues.graphics_exposures = False;
     p.text->gc = Tk_GetGC(masterPtr->tkwin,
@@ -1009,20 +970,20 @@ CalculateMasterSize(clientData)
 
 	      case TYPE_TEXT:
 		{
-		    TixFont font;
+		    XFontStruct *fontPtr;
 
 		    if (p.text->text == NULL) {
 			break;
 		    }
 		  
-		    if (p.text->font) {
-			font = p.text->font;
+		    if (p.text->fontPtr) {
+			fontPtr = p.text->fontPtr;
 		    } else {
-			font = masterPtr->font;
+			fontPtr = masterPtr->fontPtr;
 		    }
 		    
-		    p.text->numChars = -1;
-		    TixComputeTextGeometry(font, p.text->text,
+		    p.text->numChars = strlen(p.text->text);
+		    TkComputeTextGeometry(fontPtr, p.text->text,
 			p.text->numChars,
 			p.text->wrapLength,
 			&p.text->width, &p.text->height);
@@ -1175,20 +1136,20 @@ ImgCmpDisplay(clientData, display, drawable, imageX, imageY, width,
 
 	      case TYPE_TEXT:
 		{
-		    TixFont font;
+		    XFontStruct *fontPtr;
 
 		    if (p.text->text == NULL) {
 			break;
 		    }
 		  
-		    if (p.text->font) {
-			font = p.text->font;
+		    if (p.text->fontPtr) {
+			fontPtr = p.text->fontPtr;
 		    } else {
-			font = masterPtr->font;
+			fontPtr = masterPtr->fontPtr;
 		    }
 
-		    TixDisplayText(Tk_Display(masterPtr->tkwin), drawable,
-			font, p.text->text, p.text->numChars,
+		    TkDisplayText(Tk_Display(masterPtr->tkwin), drawable,
+			fontPtr, p.text->text, p.text->numChars,
 			dx, dy+extraY,	    
 			p.text->width - 2*p.item->padX,
 			p.text->justify,
@@ -1200,8 +1161,8 @@ ImgCmpDisplay(clientData, display, drawable, imageX, imageY, width,
 	      case TYPE_BITMAP:
 		XCopyPlane(Tk_Display(masterPtr->tkwin), p.bitmap->bitmap,
 		    drawable, p.bitmap->gc, 0, 0,
-		    (unsigned) p.bitmap->width  - 2*p.item->padX,
-		    (unsigned) p.bitmap->height - 2*p.item->padY,
+		    p.bitmap->width  - 2*p.item->padX,
+		    p.bitmap->height - 2*p.item->padY,
 		    dx, dy+extraY, 1);
 
 		break;
@@ -1231,25 +1192,24 @@ ImgCmpDisplay(clientData, display, drawable, imageX, imageY, width,
  * Side effects:
  *	Internal data structures get cleaned up.
  *
- * Arguments:
- *  clientData -- Pointer to CmpInstance for instance to be displayed
- *  display    -- Display containing image window
- *
  *----------------------------------------------------------------------
  */
 
 static void
 ImgCmpFree(clientData, display)
-    ClientData clientData;
-    Display *display;
+    ClientData clientData;	/* Pointer to CmpInstance structure for
+				 * for instance to be displayed. */
+    Display *display;		/* Display containing window that used image.*/
 {
-    /*
-     * Since one compound image can only be used in one window, when
-     * that window is deleted, this image is now useless and should be
-     * deleted as well
+#if 0
+    /* Since one compound image can only be used in one window, when that 
+     * window is deleted, this image is now useless and should be deleted as
+     * well
      */
+    ImgCmpDelete(clientData);
+#endif
 }
-
+
 static void FreeLine(lPtr)
     CmpLine * lPtr;
 {
@@ -1257,7 +1217,7 @@ static void FreeLine(lPtr)
 	Tk_Display(lPtr->masterPtr->tkwin), 0);
     ckfree((char *) lPtr);
 }
-
+
 static void FreeItem(p)
     CmpItemPtr p;
 {
@@ -1299,100 +1259,6 @@ static void FreeItem(p)
     ckfree((char *) p.item);
 }
 
-/*
- *----------------------------------------------------------------------
- *
- * ImgCmpFreeResources --
- *
- *	This procedure frees resources associated with the window
- *	specified with the -window arg to "image create compound ..."
- *
- *	This procedure must be called from both ImgCmpDelete and from
- *	the destroy notifier CmpEventProc() (for the -window window)
- * 	in order to ensure resources are freed under all circumstances.
- *
- *	The way Tk shuts down windows (in tkWindow.c) does not allow
- *	the destroy notifier CmpEventProc() to just delete the TCL
- *	command associated with the image.  The destroy notifier for
- *	the TCL command calls Tk_DeleteImage().  This command has no
- *	effect when Tk is shutting down (see tkImage.c) since the main
- *	window has already been removed from the main window list. As
- *	a result, ImgCmpDelete() doesn't get called when we want it to.
- *
- *	Later, tkWindow.c will call tkDeleteAllImages() to delete all 
- *	images, but by then the window referred to by masterPtr->tkwin
- *	is gone.  ImgCmdDelete cannot free the resources.
- * 
- *	By allowing CmpEventProc() to do most of the cleanup, we avoid
- *	this situation.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	Resources associated with the image get freed, new image command
- *	is removed from interpreter.
- *
- *----------------------------------------------------------------------
- */
-static void
-ImgCmpFreeResources(masterData)
-    ClientData masterData;	/* Pointer to CmpMaster structure for
-				 * image.  Must not have any more instances. */
-{
-    CmpMaster *masterPtr = (CmpMaster *) masterData;
-    CmpLine * lPtr;
-    CmpItemPtr p;
-
-    if (masterPtr->tkwin == NULL) {
-        return ;
-    }
-
-    Tk_Preserve((ClientData) masterPtr);
-
-    if (masterPtr->isDeleted == 0) {
-        masterPtr->isDeleted = 1;
-
-        Tk_DeleteEventHandler(masterPtr->tkwin,
-		StructureNotifyMask, 
-		CmpEventProc, (ClientData)masterPtr);
-        for (lPtr=masterPtr->lineHead; lPtr;) {
-            CmpLine * toDelete = lPtr;
-            lPtr = lPtr->next;
-		    
-            for (p.item=toDelete->itemHead; p.item;) {
-                CmpItemPtr toDelete;
-			    
-                toDelete.item = p.item;
-                p.item=p.item->next;
-			    
-                FreeItem(toDelete);
-            }
-            FreeLine(toDelete);
-        }
-
-        if (masterPtr->changing) {
-            Tk_CancelIdleCall(CalculateMasterSize, (ClientData)masterPtr);
-        }
-        masterPtr->tkMaster = NULL;
-
-        if (masterPtr->imageCmd != NULL) {
-            CONST84 char * cmd = Tcl_GetCommandName(masterPtr->interp,
-                masterPtr->imageCmd);
-            masterPtr->imageCmd = NULL;
-            Tcl_DeleteCommand(masterPtr->interp, cmd);
-        }
-
-        if (masterPtr->gc != None) {
-            Tk_FreeGC(masterPtr->display, masterPtr->gc);
-        }
-	    
-        Tk_FreeOptions(configSpecs, (char *) masterPtr, masterPtr->display, 0);
-    }
-
-    Tk_Release((ClientData) masterPtr);
-}
-
 /*
  *----------------------------------------------------------------------
  *
@@ -1415,8 +1281,65 @@ ImgCmpDelete(masterData)
 				 * image.  Must not have any more instances. */
 {
     CmpMaster *masterPtr = (CmpMaster *) masterData;
+    CmpLine * lPtr;
+    CmpItemPtr p;
 
-    ImgCmpFreeResources(masterData);
+    if (masterPtr->tkwin == NULL) {
+	goto done;
+    }
+
+    Tk_Preserve((ClientData) masterPtr);
+
+    Tk_DeleteEventHandler(masterPtr->tkwin,
+	StructureNotifyMask, CmpEventProc, (ClientData)masterPtr);
+
+    if (Tk_Display(masterPtr->tkwin) == NULL) {
+	/* Hack : When we issue "destroy .", 
+	 * Tk_Display(masterPtr->tkwin) will mysteriously become
+	 * 0x0. In that case, we know the app is quitting anyways, so don't
+	 * bother to do anything. And if we try to use a 0x0 display, we'd get
+	 * a TK panic!
+	 */
+	Tk_Release((ClientData) masterPtr);
+	return;
+    }
+    if (masterPtr->isDeleted) {
+	Tk_Release((ClientData) masterPtr);
+	return;
+    }
+    masterPtr->isDeleted = 1;
+
+    for (lPtr=masterPtr->lineHead; lPtr;) {
+	CmpLine * toDelete = lPtr;
+	lPtr = lPtr->next;
+
+	for (p.item=toDelete->itemHead; p.item;) {
+	    CmpItemPtr toDelete;
+
+	    toDelete.item = p.item;
+	    p.item=p.item->next;
+
+	    FreeItem(toDelete);
+	}
+	FreeLine(toDelete);
+    }
+
+    if (masterPtr->changing) {
+	Tk_CancelIdleCall(CalculateMasterSize, (ClientData)masterPtr);
+    }
+    masterPtr->tkMaster = NULL;
+    if (masterPtr->imageCmd != NULL) {
+	Tcl_DeleteCommand(masterPtr->interp,
+	    Tcl_GetCommandName(masterPtr->interp, masterPtr->imageCmd));
+    }
+    if (masterPtr->gc != None) {
+	Tk_FreeGC(Tk_Display(masterPtr->tkwin), masterPtr->gc);
+    }
+
+    Tk_FreeOptions(configSpecs, (char *) masterPtr, (Display *) NULL, 0);
+    Tk_Release((ClientData) masterPtr);
+
+  done:
     ckfree((char *) masterPtr);
 }
 
@@ -1443,11 +1366,16 @@ ImgCmpCmdDeletedProc(clientData)
 {
     CmpMaster *masterPtr = (CmpMaster *) clientData;
 
-    masterPtr->imageCmd = NULL;
-
-    if (masterPtr->tkMaster != NULL) {
+    Tk_Preserve((ClientData) masterPtr);
+    if (masterPtr->isDeleted == 1) {
+	Tk_Release((ClientData) masterPtr);
+	return;
+    } else {
+	if (masterPtr->tkMaster != NULL) {
 	    Tk_DeleteImage(masterPtr->interp, 
-			   Tk_NameOfImage(masterPtr->tkMaster));
+		Tk_NameOfImage(masterPtr->tkMaster));
+	}
+	Tk_Release((ClientData) masterPtr);
     }
 }
 /*
@@ -1456,7 +1384,7 @@ ImgCmpCmdDeletedProc(clientData)
  * ImageProc --
  *
  *	This procedure is invoked by the image code whenever the manager
- *	for an image does something that affects the size or contents
+ *	for an image does something that affects the size of contents
  *	of an image displayed in a button.
  *
  * Results:
@@ -1496,7 +1424,7 @@ ImageProc(clientData, x, y, width, height, imgWidth, imgHeight)
  *
  * Side effects:
  *	When the window gets deleted, internal structures get
- *	cleaned up. 
+ *	cleaned up.  When it gets exposed, it is redisplayed.
  *
  *--------------------------------------------------------------
  */
@@ -1506,9 +1434,7 @@ CmpEventProc(clientData, eventPtr)
     ClientData clientData;	/* Information about window. */
     XEvent *eventPtr;		/* Information about event. */
 {
-    /* CmpMaster *masterPtr = (CmpMaster *)clientData; */
-
     if (eventPtr->type == DestroyNotify) {
-	    ImgCmpFreeResources(clientData);
+	ImgCmpCmdDeletedProc(clientData);
     }
 }
