@@ -1,28 +1,144 @@
-
-/*	$Id: tixImgXpm.c,v 1.4 2004/03/28 02:44:56 hobbs Exp $	*/
-
-/*
+/**
  * tixImgXpm.c --
  *
  *	This file implements images of type "pixmap" for Tix.
+ * ______________________________________________________________________
  *
- * Copyright (c) 1996, Expert Interface Technologies
+ * Copyright statement for tixImgXpm.c
+ *	Copyright 1996, Expert Interface Technologies
  *
- * See the file "license.terms" for information on usage and redistribution
- * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ * The following terms apply only to this file and no other parts of the
+ * Tix library.
  *
+ *	Permission is hereby granted, without written agreement and
+ *	without license or royalty fees, to use, copy, modify, and
+ *	distribute this file, for any purpose, provided that existing
+ *	copyright notices are retained in all copies and that this
+ *	notice is included verbatim in any distributions.
+ *
+ *	DISCLAIMER OF ALL WARRANTIES
+ *
+ *	IN NO EVENT SHALL THE AUTHOR OF THIS SOFTWARE BE LIABLE TO ANY
+ *	PARTY FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR
+ *	CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF THIS SOFTWARE
+ *	AND ITS DOCUMENTATION, EVEN IF THE AUTHOR OF THIS SOFTWARE HAS
+ *	BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ *	THE AUTHOR OF THIS SOFTWARE SPECIFICALLY DISCLAIMS ANY
+ *	WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ *	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ *	PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"
+ *	BASIS, AND THE AUTHOR OF THIS SOFTWARE HAS NO OBLIGATION TO
+ *	PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
+ *	MODIFICATIONS.
+ * ___________________________________________________________________
+ *
+ * This file is adapted from the Tk 4.0 source file tkImgBmap.c
+ * Original tkImgBmap.c copyright information:
+ *
+ *	Copyright (c) 1994 The Regents of the University of California.
+ *	Copyright (c) 1994-1995 Sun Microsystems, Inc.
+ *
+ *	See the file "license.terms.tcltk" for information on usage
+ *	and redistribution of the original tkImgBmap.c file, and for a
+ *	DISCLAIMER OF ALL WARRANTIES from the authors of tkImgBmap.c.
  */
+#include "tkInt.h"
+#include "tkPort.h"
+#include <tix.h>
 
-#include <tixPort.h>
-#include <tixInt.h>
-#include <tixImgXpm.h>
+/* constants used only in this file */
+
+#define XPM_MONO		1
+#define XPM_GRAY_4		2
+#define XPM_GRAY		3
+#define XPM_COLOR		4
+#define XPM_SYMBOLIC		5
+#define XPM_UNKNOWN		6
 
 /*
- * Prototypes for procedures used only locally in this file:
+ * The following data structure represents the master for a pixmap
+ * image:
+ */
+
+typedef struct PixmapMaster {
+    Tk_ImageMaster tkMaster;	/* Tk's token for image master.  NULL means
+				 * the image is being deleted. */
+    Tcl_Interp *interp;		/* Interpreter for application that is
+				 * using image. */
+    Tcl_Command imageCmd;	/* Token for image command (used to delete
+				 * it when the image goes away).  NULL means
+				 * the image command has already been
+				 * deleted. */
+    char *fileString;		/* Value of -file option (malloc'ed).
+				 * valid only if the -file option is specified
+				 */
+    char *dataString;		/* Value of -data option (malloc'ed).
+				 * valid only if the -data option is specified
+				 */
+				/* First in list of all instances associated
+				 * with this master. */
+    Tk_Uid id;			/* ID's for XPM data already compiled
+				 * into the tixwish binary */
+    int size[2];		/* width and height */
+    int ncolors;		/* number of colors */
+    int cpp;			/* characters per pixel */
+    char ** data;		/* The data that defines this pixmap 
+				 * image (array of strings). It is
+				 * converted into an X Pixmap when this
+				 * image is instanciated
+				 */
+    int isDataAlloced;		/* False iff the data is got from
+				 * the -id switch */
+    struct PixmapInstance *instancePtr;
+} PixmapMaster;
+
+/* Make this more portable */
+
+typedef struct ColorStruct {
+    char c;			/* This is used if CPP is one */
+    char * cstring;		/* This is used if CPP is bigger than one */
+    XColor * colorPtr;
+} ColorStruct;
+
+/*
+ * The following data structure represents all of the instances of an
+ * image that lie within a particular window:
+ *
+ * %% ToDo
+ * Currently one instance is created for each window that uses this pixmap.
+ * This is usually OK because pixmaps are usually not shared or only shared by
+ * a small number of windows. To improve resource allocation, we can
+ * create an instance for each (Display x Visual x Depth) combo. This will
+ * usually reduce the number of instances to one.
+ */
+typedef struct PixmapInstance {
+    int refCount;		/* Number of instances that share this
+				 * data structure. */
+    PixmapMaster *masterPtr;	/* Pointer to master for image. */
+    Tk_Window tkwin;		/* Window in which the instances will be
+				 * displayed. */
+    Pixmap pixmap;		/* The pixmap to display. */
+    Pixmap mask;		/* Mask: only display pixmap pixels where
+				 * there are 1's here. */
+    GC gc;			/* Graphics context for displaying pixmap.
+				 * None means there was an error while
+				 * setting up the instance, so it cannot
+				 * be displayed. */
+    struct PixmapInstance *nextPtr;
+				/* Next in list of all instance structures
+				 * associated with masterPtr (NULL means
+				 * end of list).
+				 */
+    ColorStruct * colors;
+} PixmapInstance;
+
+/*
+ * The type record for pixmap images:
  */
 
 static int		ImgXpmCreate _ANSI_ARGS_((Tcl_Interp *interp,
-			    char *name, int argc, Tcl_Obj *CONST objv[],
+			    char *name, int argc, char **argv,
 			    Tk_ImageType *typePtr, Tk_ImageMaster master,
 			    ClientData *clientDataPtr));
 static ClientData	ImgXpmGet _ANSI_ARGS_((Tk_Window tkwin,
@@ -34,31 +150,16 @@ static void		ImgXpmDisplay _ANSI_ARGS_((ClientData clientData,
 static void		ImgXpmFree _ANSI_ARGS_((ClientData clientData,
 			    Display *display));
 static void		ImgXpmDelete _ANSI_ARGS_((ClientData clientData));
-static int		ImgXpmCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int argc, CONST84 char **argv));
-static void		ImgXpmCmdDeletedProc _ANSI_ARGS_((
-			    ClientData clientData));
-static void		ImgXpmConfigureInstance _ANSI_ARGS_((
-			    PixmapInstance *instancePtr));
-static int		ImgXpmConfigureMaster _ANSI_ARGS_((
-			    PixmapMaster *masterPtr, int argc, CONST84 char **argv,
-			    int flags));
-static int		ImgXpmGetData _ANSI_ARGS_((Tcl_Interp *interp,
-			    PixmapMaster *masterPtr));
-static char ** 		ImgXpmGetDataFromFile _ANSI_ARGS_((Tcl_Interp * interp,
-			    char * string, int * numLines_return));
-static char ** 		ImgXpmGetDataFromId _ANSI_ARGS_((Tcl_Interp * interp,
-			    CONST84 char * id));
-static char ** 		ImgXpmGetDataFromString _ANSI_ARGS_((Tcl_Interp*interp,
-			    char * string, int * numLines_return));
-static void 		ImgXpmGetPixmapFromData _ANSI_ARGS_((
-			    Tcl_Interp * interp,
-			    PixmapMaster *masterPtr,
-			    PixmapInstance *instancePtr));
-static char *		GetType _ANSI_ARGS_((char * colorDefn,
-			    int  * type_ret));
-static char *		GetColor _ANSI_ARGS_((char * colorDefn,
-			    char * colorName, int * type_ret));
+
+Tk_ImageType tixPixmapImageType = {
+    "pixmap",			/* name */
+    ImgXpmCreate,		/* createProc */
+    ImgXpmGet,			/* getProc */
+    ImgXpmDisplay,		/* displayProc */
+    ImgXpmFree,			/* freeProc */
+    ImgXpmDelete,		/* deleteProc */
+    (Tk_ImageType *) NULL	/* nextPtr */
+};
 
 /*
  * Information used for parsing configuration specs:
@@ -75,22 +176,32 @@ static Tk_ConfigSpec configSpecs[] = {
 	(char *) NULL, 0, 0}
 };
 
-Tk_ImageType tixPixmapImageType = {
-    "pixmap",                       /* name */
-    ImgXpmCreate,                   /* createProc */
-    ImgXpmGet,                      /* getProc */
-    ImgXpmDisplay,                  /* displayProc */
-    ImgXpmFree,                     /* freeProc */
-    ImgXpmDelete,                   /* deleteProc */
-    NULL,                           /* postscriptProc (tk8.3 or later)*/
-    NULL,                           /* nextPtr */
-    NULL,                           /* reserved */
-};
-
 /*
- * Local data, used only in this file
+ * Prototypes for procedures used only locally in this file:
  */
+static int		ImgXpmCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+static void		ImgXpmCmdDeletedProc _ANSI_ARGS_((
+			    ClientData clientData));
+static void		ImgXpmConfigureInstance _ANSI_ARGS_((
+			    PixmapInstance *instancePtr));
+static int		ImgXpmConfigureMaster _ANSI_ARGS_((
+			    PixmapMaster *masterPtr, int argc, char **argv,
+			    int flags));
+static int		ImgXpmGetData _ANSI_ARGS_((Tcl_Interp *interp,
+			    PixmapMaster *masterPtr));
+static char ** 		ImgXpmGetDataFromFile _ANSI_ARGS_((Tcl_Interp * interp,
+			    char * string, int * numLines_return));
+static char ** 		ImgXpmGetDataFromId _ANSI_ARGS_((Tcl_Interp * interp,
+			    char * id));
+static char ** 		ImgXpmGetDataFromString _ANSI_ARGS_((Tcl_Interp*interp,
+			    char * string, int * numLines_return));
+static int 		ImgXpmGetPixmapFromData _ANSI_ARGS_((
+			    Tcl_Interp * interp,
+			    PixmapMaster *masterPtr,
+			    PixmapInstance *instancePtr));
 
+/* Local data, used only in this file */
 static Tcl_HashTable xpmTable;
 static int xpmTableInited = 0;
 
@@ -112,12 +223,12 @@ static int xpmTableInited = 0;
  *----------------------------------------------------------------------
  */
 static int
-ImgXpmCreate(interp, name, argc, objv, typePtr, master, clientDataPtr)
+ImgXpmCreate(interp, name, argc, argv, typePtr, master, clientDataPtr)
     Tcl_Interp *interp;		/* Interpreter for application containing
 				 * image. */
     char *name;			/* Name to use for image. */
     int argc;			/* Number of arguments. */
-    Tcl_Obj *CONST objv[];	/* Argument strings for options (doesn't
+    char **argv;		/* Argument strings for options (doesn't
 				 * include image name or type). */
     Tk_ImageType *typePtr;	/* Pointer to our type record (not used). */
     Tk_ImageMaster master;	/* Token for image, to be used by us in
@@ -126,24 +237,6 @@ ImgXpmCreate(interp, name, argc, objv, typePtr, master, clientDataPtr)
 				 * it will be returned in later callbacks. */
 {
     PixmapMaster *masterPtr;
-    int i;
-    CONST84 char *argvbuf[10];
-    CONST84 char **argv = argvbuf;
-
-    /*
-     * Convert the objv arguments into string equivalent.
-     */
-    if (argc > 10) {
-	argv = (CONST84 char **) ckalloc(argc * sizeof(char *));
-    }
-    for (i = 0; i < argc; i++) {
-        /*
-         * no need to free the value returned by Tcl_GetString. It's
-         * managed by Tcl's object system.
-         */
-
-	argv[i] = Tcl_GetString(objv[i]);
-    }
 
     masterPtr = (PixmapMaster *) ckalloc(sizeof(PixmapMaster));
     masterPtr->tkMaster = master;
@@ -160,14 +253,8 @@ ImgXpmCreate(interp, name, argc, objv, typePtr, master, clientDataPtr)
 
     if (ImgXpmConfigureMaster(masterPtr, argc, argv, 0) != TCL_OK) {
 	ImgXpmDelete((ClientData) masterPtr);
-	if (argv != argvbuf) {
-	    ckfree((char *) argv);
-	}
 	return TCL_ERROR;
     }
-    if (argv != argvbuf) {
-	ckfree((char *) argv);
-    }
     *clientDataPtr = (ClientData) masterPtr;
     return TCL_OK;
 }
@@ -199,7 +286,7 @@ ImgXpmConfigureMaster(masterPtr, argc, argv, flags)
     PixmapMaster *masterPtr;	/* Pointer to data structure describing
 				 * overall pixmap image to (reconfigure). */
     int argc;			/* Number of entries in argv. */
-    CONST84 char **argv;	/* Pairs of configuration options for image. */
+    char **argv;		/* Pairs of configuration options for image. */
     int flags;			/* Flags to pass to Tk_ConfigureWidget,
 				 * such as TK_CONFIG_ARGV_ONLY. */
 {
@@ -247,16 +334,11 @@ ImgXpmConfigureMaster(masterPtr, argc, argv, flags)
 	Tk_ImageChanged(masterPtr->tkMaster, 0, 0, 0, 0, 0, 0);
     }
 
+  done:
     return TCL_OK;
 
   error:
     /* Restore it to the original (possible valid) mode */
-    if (masterPtr->dataString && masterPtr->dataString != oldData) {
-	ckfree(masterPtr->dataString);
-    }
-    if (masterPtr->fileString && masterPtr->fileString != oldFile) {
-	ckfree(masterPtr->fileString);
-    }
     masterPtr->dataString = oldData;
     masterPtr->fileString = oldFile;
     masterPtr->id = oldId;
@@ -286,45 +368,57 @@ ImgXpmGetData(interp, masterPtr)
     Tcl_Interp *interp;			/* For reporting errors. */
     PixmapMaster *masterPtr;
 {
-    char ** data = NULL;
-    int  isAllocated = 0;	/* do we need to free "data"? */
+    char ** data;
+    int  isAllocated;			/* do we need to free "data"? */
     int listArgc;
-    CONST84 char ** listArgv = NULL;
+    char ** listArgv = NULL;
     int numLines;
     int size[2];
     int cpp;
     int ncolors;
-    int code = TCL_OK;
 
     if (masterPtr->id != NULL) {
 	data = ImgXpmGetDataFromId(interp, masterPtr->id);
-    } else if (masterPtr->fileString != NULL) {
+	isAllocated = 0;
+    }
+    else if (masterPtr->fileString != NULL) {
 	data = ImgXpmGetDataFromFile(interp, masterPtr->fileString, &numLines);
 	isAllocated = 1;
-    } else if (masterPtr->dataString != NULL) {
+    }
+    else if (masterPtr->dataString != NULL) {
 	data = ImgXpmGetDataFromString(interp,masterPtr->dataString,&numLines);
 	isAllocated = 1;
-    } else {
+    }
+    else {
 	/* Should have been enforced by ImgXpmConfigureMaster() */
-	Tcl_Panic("ImgXpmGetData(): -data, -file and -id are all NULL");
+	panic("ImgXpmGetData(): -data, -file and -id are all NULL");
     }
 
     if (data == NULL) {
-	/* nothing has been allocated yet. Don't need to goto done */
 	return TCL_ERROR;
     }
 
     /* Parse the first line of the data and get info about this pixmap */
     if (Tcl_SplitList(interp, data[0], &listArgc, &listArgv) != TCL_OK) {
-	code = TCL_ERROR; goto done;
+	goto error;
     }
 
-    if ((listArgc < 4) /* file format error */
-	    || (Tcl_GetInt(interp, listArgv[0], &size[0]) != TCL_OK)
-	    || (Tcl_GetInt(interp, listArgv[1], &size[1]) != TCL_OK)
-	    || (Tcl_GetInt(interp, listArgv[2], &ncolors) != TCL_OK)
-	    || (Tcl_GetInt(interp, listArgv[3], &cpp) != TCL_OK)) {
-	code = TCL_ERROR; goto done;
+    if (listArgc < 4) {
+	Tcl_AppendResult(interp, "File format error", NULL);
+	goto error;
+    }
+
+    if (Tcl_GetInt(interp, listArgv[0], &size[0]) != TCL_OK) {
+	goto error;
+    }
+    if (Tcl_GetInt(interp, listArgv[1], &size[1]) != TCL_OK) {
+	goto error;
+    }
+    if (Tcl_GetInt(interp, listArgv[2], &ncolors) != TCL_OK) {
+	goto error;
+    }
+    if (Tcl_GetInt(interp, listArgv[3], &cpp) != TCL_OK) {
+	goto error;
     }
 
     if (isAllocated) {
@@ -332,40 +426,40 @@ ImgXpmGetData(interp, masterPtr)
 	    /* the number of lines read from the file/data
 	     * is not the same as specified in the data
 	     */
-	    code = TCL_ERROR; goto done;
+	    goto error;
 	}
     }
 
   done:
-    if (code == TCL_OK) {
-	if (masterPtr->isDataAlloced && masterPtr->data) {
-	    ckfree((char*)masterPtr->data);
-	}
-	masterPtr->isDataAlloced = isAllocated;
-	masterPtr->data = data;
-	masterPtr->size[0] = size[0];
-	masterPtr->size[1] = size[1];
-	masterPtr->cpp = cpp;
-	masterPtr->ncolors = ncolors;
-    } else {
-	if (isAllocated && data) {
-	    ckfree((char*)data);
-	}
-
-	Tcl_ResetResult(interp);
-	Tcl_AppendResult(interp, "File format error", NULL);
+    if (masterPtr->isDataAlloced && masterPtr->data) {
+	ckfree((char*)masterPtr->data);
     }
+    masterPtr->isDataAlloced = isAllocated;
+    masterPtr->data = data;
+    masterPtr->size[0] = size[0];
+    masterPtr->size[1] = size[1];
+    masterPtr->cpp = cpp;
+    masterPtr->ncolors = ncolors;
+    
+    return TCL_OK;
 
+  error:
+    Tcl_ResetResult(interp);
+    Tcl_AppendResult(interp, "File format error", NULL);
+
+    if (isAllocated && data) {
+	ckfree((char*)data);
+    }
     if (listArgv) {
 	ckfree((char*)listArgv);
     }
 		   
-    return code;
+    return TCL_ERROR;
 }
 
 static char ** ImgXpmGetDataFromId(interp, id)
     Tcl_Interp * interp;
-    CONST84 char * id;
+    char * id;
 {
     Tcl_HashEntry * hashPtr;
 
@@ -518,72 +612,51 @@ static char ** ImgXpmGetDataFromFile(interp, fileName, numLines_return)
     char * fileName;
     int * numLines_return;
 {
-    FILE * fd = NULL;
-    int size, n;
+    int fileId, size;
     char ** data;
+    struct stat statBuf;
     char *cmdBuffer = NULL;
     Tcl_DString buffer;			/* initialized by Tcl_TildeSubst */
 
-    fileName = Tcl_TranslateFileName(interp, fileName, &buffer);
+    fileName = Tcl_TildeSubst(interp, fileName, &buffer);
     if (fileName == NULL) {
 	goto error;
     }
 
-    /*
-     * Open the file and find its size
-     */
-
-    fd = fopen(fileName, "r");
-    if (fd == NULL) {
+    fileId = open(fileName, O_RDONLY, 0);
+    if (fileId < 0) {
 	Tcl_AppendResult(interp, "couldn't read file \"", fileName,
 		"\": ", Tcl_PosixError(interp), (char *) NULL);
 	goto error;
     }
-    if (fseek(fd, 0, SEEK_END) < 0) {
-	Tcl_AppendResult(interp, "couldn't fseek file \"", fileName,
+    if (fstat(fileId, &statBuf) == -1) {
+	Tcl_AppendResult(interp, "couldn't stat file \"", fileName,
 		"\": ", Tcl_PosixError(interp), (char *) NULL);
+	close(fileId);
 	goto error;
     }
-    size = ftell(fd);
+    cmdBuffer = (char *) ckalloc((unsigned) statBuf.st_size+1);
+    size = read(fileId, cmdBuffer, (size_t) statBuf.st_size);
     if (size < 0) {
-	Tcl_AppendResult(interp, "couldn't ftell file \"", fileName,
-		"\": ", Tcl_PosixError(interp), (char *) NULL);
-	goto error;
-    }
-    if (fseek(fd, 0, SEEK_SET) < 0) {
-	Tcl_AppendResult(interp, "couldn't fseek file \"", fileName,
-		"\": ", Tcl_PosixError(interp), (char *) NULL);
-	goto error;
-    }
-
-    /*
-     * Read the entire file
-     */
-
-    cmdBuffer = (char *) ckalloc((unsigned) size + 1);
-    n = fread(cmdBuffer, 1, (size_t) size, fd);
-    if (size != n) {
 	Tcl_AppendResult(interp, "error in reading file \"", fileName,
 		"\": ", Tcl_PosixError(interp), (char *) NULL);
+	close(fileId);
 	goto error;
     }
-    if (fclose(fd) != 0) {
+    if (close(fileId) != 0) {
 	Tcl_AppendResult(interp, "error closing file \"", fileName,
 		"\": ", Tcl_PosixError(interp), (char *) NULL);
-        fd = NULL;
 	goto error;
     }
     cmdBuffer[size] = 0;
 
+  done:
     data = ImgXpmGetDataFromString(interp, cmdBuffer, numLines_return);
     ckfree(cmdBuffer);
     Tcl_DStringFree(&buffer);
     return data;
 
   error:
-    if (fd != NULL) {
-        fclose(fd);
-    }
     if (cmdBuffer != NULL) {
 	ckfree(cmdBuffer);
     }
@@ -592,8 +665,7 @@ static char ** ImgXpmGetDataFromFile(interp, fileName, numLines_return)
 }
 
 
-static char *
-GetType(colorDefn, type_ret)
+static char * GetType(colorDefn, type_ret)
     char * colorDefn;
     int  * type_ret;
 {
@@ -639,16 +711,13 @@ GetType(colorDefn, type_ret)
     return p;
 }
 
-/*
- * colorName is guaranteed to be big enough
- */
-static char *
-GetColor(colorDefn, colorName, type_ret)
+/* colorName is guaranteed to be big enough */
+static char * GetColor(colorDefn, colorName, type_ret)
     char * colorDefn;
     char * colorName;		/* if found, name is copied to this array */
     int  * type_ret;
 {
-    int type;
+    int n, type;
     char * p;
 
     if (!colorDefn) {
@@ -708,17 +777,27 @@ GetColor(colorDefn, colorName, type_ret)
  *	Creates a pixmap for an image instance.
  *----------------------------------------------------------------------
  */
-static void
-ImgXpmGetPixmapFromData(interp, masterPtr, instancePtr)
+static int ImgXpmGetPixmapFromData(interp, masterPtr, instancePtr)
     Tcl_Interp * interp;
     PixmapMaster *masterPtr;
     PixmapInstance *instancePtr;
 {
     XImage * image = NULL, * mask = NULL;
-    int depth, i, j, k, lOffset, isTransp = 0, isMono;
+    int pad, depth, i, j, k, n, lOffset, isTransp = 0, isMono;
     ColorStruct * colors;
+    GC gc;
+    Display *display = Tk_Display(instancePtr->tkwin);
 
     depth = Tk_Depth(instancePtr->tkwin);
+    if (depth > 16) {
+	pad = 32;
+    }
+    else if (depth > 8) {
+	pad = 16;
+    }
+    else {
+	pad = 8;
+    }
 
     switch ((Tk_Visual(instancePtr->tkwin))->class) {
       case StaticGray:
@@ -729,7 +808,22 @@ ImgXpmGetPixmapFromData(interp, masterPtr, instancePtr)
 	isMono = 0;
     }
 
-    TixpXpmAllocTmpBuffer(masterPtr, instancePtr, &image, &mask);
+    /*
+     * Create the XImage structures to store the temporary image
+     */
+    image = XCreateImage(display,
+	Tk_Visual(instancePtr->tkwin),
+	depth, ZPixmap, 0, 0,
+	masterPtr->size[0], masterPtr->size[1], pad, 0);
+    image->data =
+      (char *)ckalloc(image->bytes_per_line * masterPtr->size[1]);
+
+    mask  = XCreateImage(display,
+	Tk_Visual(instancePtr->tkwin),
+	1, ZPixmap, 0, 0,
+	masterPtr->size[0], masterPtr->size[1], pad, 0);
+    mask->data =
+      (char *)ckalloc(mask->bytes_per_line  * masterPtr->size[1]);
 
     /*
      * Parse the colors
@@ -737,15 +831,13 @@ ImgXpmGetPixmapFromData(interp, masterPtr, instancePtr)
     lOffset = 1;
     colors = (ColorStruct*)ckalloc(sizeof(ColorStruct)*masterPtr->ncolors);
 
-    /*
-     * Initialize the color structures
-     */
+    /* Initialize the color structures */
     for (i=0; i<masterPtr->ncolors; i++) {
 	colors[i].colorPtr = NULL;
 	if (masterPtr->cpp == 1) {
 	    colors[i].c = 0;
 	} else {
-	    colors[i].cstring = (char*)ckalloc((unsigned) masterPtr->cpp);
+	    colors[i].cstring = (char*)ckalloc(masterPtr->cpp);
 	    colors[i].cstring[0] = 0;
 	}
     }
@@ -848,8 +940,13 @@ ImgXpmGetPixmapFromData(interp, masterPtr, instancePtr)
 	    if (masterPtr->cpp == 1) {
 		for (k=0; k<masterPtr->ncolors; k++) {
 		    if (*p == colors[k].c) {
-			TixpXpmSetPixel(instancePtr, image, mask, j, i,
-			        colors[k].colorPtr, &isTransp);
+			if (colors[k].colorPtr != NULL) {
+			    XPutPixel(image, j, i, colors[k].colorPtr->pixel);
+			    XPutPixel(mask,  j, i, 1);
+			} else {
+			    XPutPixel(mask,  j, i, 0);
+			    isTransp = 1;
+			}
 			break;
 		    }
 		}
@@ -860,8 +957,13 @@ ImgXpmGetPixmapFromData(interp, masterPtr, instancePtr)
 		for (k=0; k<masterPtr->ncolors; k++) {
 		    if (strncmp(p, colors[k].cstring, 
 			    (size_t)masterPtr->cpp) == 0) {
-			TixpXpmSetPixel(instancePtr, image, mask, j, i,
-			        colors[k].colorPtr, &isTransp);
+			if (colors[k].colorPtr != NULL) {
+			    XPutPixel(image, j, i, colors[k].colorPtr->pixel);
+			    XPutPixel(mask,  j, i, 1);
+			} else {
+			    XPutPixel(mask,  j, i, 0);
+			    isTransp = 1;
+			}
 			break;
 		    }
 		}
@@ -872,10 +974,48 @@ ImgXpmGetPixmapFromData(interp, masterPtr, instancePtr)
 	}
     }
 
+    /*
+     * Create the pixmap(s) from the XImage structure. The mask is created
+     * only if needed (i.e., there is at least one transparent pixel)
+     */
     instancePtr->colors = colors;
 
-    TixpXpmRealizePixmap(masterPtr, instancePtr, image, mask, isTransp);
-    TixpXpmFreeTmpBuffer(masterPtr, instancePtr, image, mask);
+    /* main image */
+    instancePtr->pixmap = Tk_GetPixmap(display,
+	Tk_WindowId(instancePtr->tkwin),
+	masterPtr->size[0], masterPtr->size[1], depth);
+
+    gc = Tk_GetGC(instancePtr->tkwin, 0, NULL);
+
+    TkPutImage(NULL, 0, display, instancePtr->pixmap,
+	gc, image, 0, 0, 0, 0, masterPtr->size[0], masterPtr->size[1]);
+
+    Tk_FreeGC(display, gc);
+
+    /* mask, if necessary */
+    if (isTransp) {
+	instancePtr->mask = Tk_GetPixmap(display,
+	    Tk_WindowId(instancePtr->tkwin),
+	    masterPtr->size[0], masterPtr->size[1], 1);
+	gc = XCreateGC(display, instancePtr->mask, 0, NULL);
+	TkPutImage(NULL, 0, display, instancePtr->mask,
+	    gc, mask,  0, 0, 0, 0, masterPtr->size[0], masterPtr->size[1]);
+	XFreeGC(display, gc);
+    } else {
+	instancePtr->mask = None;
+    }
+
+    /* Done */
+    if (image) {
+	ckfree((char*)image->data);
+	image->data = NULL;
+	XDestroyImage(image);
+    }
+    if (mask) {
+	ckfree((char*)mask->data);
+	mask->data = NULL;
+	XDestroyImage(mask);
+    }
 }
 
 /*
@@ -902,11 +1042,16 @@ ImgXpmConfigureInstance(instancePtr)
     PixmapInstance *instancePtr;	/* Instance to reconfigure. */
 {
     PixmapMaster *masterPtr = instancePtr->masterPtr;
+    XGCValues gcValues;
+    GC gc;
+    unsigned int gcMask;
 
     if (instancePtr->pixmap != None) {
-	Tk_FreePixmap(Tk_Display(instancePtr->tkwin), instancePtr->pixmap);
+	XFreePixmap(Tk_Display(instancePtr->tkwin), instancePtr->pixmap);
+    }
+    if (instancePtr->mask != None) {
+	XFreePixmap(Tk_Display(instancePtr->tkwin), instancePtr->mask);
     }
-    TixpXpmFreeInstanceData(instancePtr, 0, Tk_Display(instancePtr->tkwin));
 
     if (instancePtr->colors != NULL) {
 	int i;
@@ -925,13 +1070,30 @@ ImgXpmConfigureInstance(instancePtr)
 	Tk_MakeWindowExist(instancePtr->tkwin);
     }
 
-    /*
-     * Assumption: masterPtr->data is always non NULL (enfored by
+    /* Assumption: masterPtr->data is always non NULL (enfored by
      * ImgXpmConfigureMaster()). Also, the data must be in a valid
      * format (partially enforced by ImgXpmConfigureMaster(), see comments
      * inside that function).
      */
     ImgXpmGetPixmapFromData(masterPtr->interp, masterPtr, instancePtr);
+
+    /* Allocate a GC for drawing this instance (mask is not used if there
+     * is no transparent pixels inside the image).*/
+    if (instancePtr->mask != None) {
+	gcMask = GCGraphicsExposures|GCClipMask;
+    } else {
+	gcMask = GCGraphicsExposures;
+    }
+    gcValues.graphics_exposures = False;
+    gcValues.clip_mask = instancePtr->mask;
+    
+    gc = Tk_GetGC(instancePtr->tkwin, gcMask, &gcValues);
+
+    if (instancePtr->gc != None) {
+	Tk_FreeGC(Tk_Display(instancePtr->tkwin), instancePtr->gc);
+    }
+    instancePtr->gc = gc;
+    return;
 }
 
 /*
@@ -957,7 +1119,7 @@ ImgXpmCmd(clientData, interp, argc, argv)
     ClientData clientData;	/* Information about button widget. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int argc;			/* Number of arguments. */
-    CONST84 char **argv;	/* Argument strings. */
+    char **argv;		/* Argument strings. */
 {
     PixmapMaster *masterPtr = (PixmapMaster *) clientData;
     int c, code;
@@ -971,7 +1133,6 @@ ImgXpmCmd(clientData, interp, argc, argv)
     }
     c = argv[1][0];
     length = strlen(argv[1]);
-
     if ((c == 'c') && (strncmp(argv[1], "cget", length) == 0)
 	    && (length >= 2)) {
 	if (argc != 3) {
@@ -995,26 +1156,13 @@ ImgXpmCmd(clientData, interp, argc, argv)
 		    TK_CONFIG_ARGV_ONLY);
 	}
 	return code;
-    } else if ((c == 'r') && (strncmp(argv[1], "refcount", length) == 0)) {
-	/*
-	 * The "refcount" command is for debugging only
-	 */
-	PixmapInstance *instancePtr;
-	int count = 0;
-	char buff[30];
-
-	for (instancePtr=masterPtr->instancePtr; instancePtr;
-	     instancePtr = instancePtr->nextPtr) {
-	    count += instancePtr->refCount;
-	}
-	sprintf(buff, "%d", count);
-	Tcl_SetResult(interp, buff, TCL_VOLATILE);
-	return TCL_OK;
-    } else {
-	Tcl_AppendResult(interp, "bad option \"", argv[1],
-	    "\": must be cget, configure or refcount", (char *) NULL);
-	return TCL_ERROR;
     }
+
+  error:
+
+    Tcl_AppendResult(interp, "bad option \"", argv[1],
+	"\": must be cget or configure", (char *) NULL);
+    return TCL_ERROR;
 }
 
 /*
@@ -1068,11 +1216,11 @@ ImgXpmGet(tkwin, masterData)
     instancePtr->masterPtr = masterPtr;
     instancePtr->tkwin = tkwin;
     instancePtr->pixmap = None;
+    instancePtr->mask = None;
+    instancePtr->gc = None;
     instancePtr->nextPtr = masterPtr->instancePtr;
     instancePtr->colors = NULL;
     masterPtr->instancePtr = instancePtr;
-
-    TixpInitPixmapInstance(masterPtr, instancePtr);
     ImgXpmConfigureInstance(instancePtr);
 
     /*
@@ -1120,8 +1268,30 @@ ImgXpmDisplay(clientData, display, drawable, imageX, imageY, width,
     int drawableX, drawableY;	/* Coordinates within drawable that
 				 * correspond to imageX and imageY. */
 {
-    TixpXpmDisplay(clientData, display, drawable, imageX, imageY, width,
-	height, drawableX, drawableY);
+    PixmapInstance *instancePtr = (PixmapInstance *) clientData;
+
+    /*
+     * If there's no graphics context, it means that an error occurred
+     * while creating the image instance so it can't be displayed.
+     */
+
+    if (instancePtr->gc == None) {
+	return;
+    }
+
+    /*
+     * We always use masking: modify the mask origin within
+     * the graphics context to line up with the image's origin.
+     * Then draw the image and reset the clip origin, if there's
+     * a mask.
+     */
+
+    XSetClipOrigin(display, instancePtr->gc, drawableX - imageX,
+	drawableY - imageY);
+    XCopyArea(display, instancePtr->pixmap, drawable, instancePtr->gc,
+	imageX, imageY, (unsigned) width, (unsigned) height,
+	drawableX, drawableY);
+    XSetClipOrigin(display, instancePtr->gc, 0, 0);
 }
 
 /*
@@ -1160,10 +1330,14 @@ ImgXpmFree(clientData, display)
      * the instance structure.
      */
     if (instancePtr->pixmap != None) {
-	Tk_FreePixmap(display, instancePtr->pixmap);
+	XFreePixmap(display, instancePtr->pixmap);
+    }
+    if (instancePtr->mask != None) {
+	XFreePixmap(display, instancePtr->mask);
+    }
+    if (instancePtr->gc != None) {
+	Tk_FreeGC(display, instancePtr->gc);
     }
-    TixpXpmFreeInstanceData(instancePtr, 1, display);
-
     if (instancePtr->colors != NULL) {
 	int i;
 	for (i=0; i<instancePtr->masterPtr->ncolors; i++) {
@@ -1223,9 +1397,7 @@ ImgXpmDelete(masterData)
     }
     if (masterPtr->isDataAlloced && masterPtr->data != NULL) {
 	ckfree((char*)masterPtr->data);
-	masterPtr->data = NULL;
     }
-
     Tk_FreeOptions(configSpecs, (char *) masterPtr, (Display *) NULL, 0);
     ckfree((char *) masterPtr);
 }
@@ -1255,10 +1427,7 @@ ImgXpmCmdDeletedProc(clientData)
 
     masterPtr->imageCmd = NULL;
     if (masterPtr->tkMaster != NULL) {
-	if (Tk_MainWindow(masterPtr->interp) != NULL) {
-	    Tk_DeleteImage(masterPtr->interp,
-		    Tk_NameOfImage(masterPtr->tkMaster));
-	}
+	Tk_DeleteImage(masterPtr->interp, Tk_NameOfImage(masterPtr->tkMaster));
     }
 }
 
