@@ -1,6 +1,3 @@
-
-/*	$Id: tixInputO.c,v 1.2 2004/03/28 02:44:57 hobbs Exp $	*/
-
 /* 
  * tixInputO.c --
  *
@@ -14,8 +11,8 @@
  *
  */
 
+#include <tkPort.h>
 #include <tkInt.h>
-#include <tixPort.h>
 #include <tix.h>
 
 /*
@@ -79,15 +76,13 @@ static Tk_ConfigSpec configSpecs[] = {
 static void		WidgetCmdDeletedProc _ANSI_ARGS_((
 			    ClientData clientData));
 static int		WidgetConfigure _ANSI_ARGS_((Tcl_Interp *interp,
-			    WidgetPtr wPtr, int argc, CONST84 char **argv,
+			    WidgetPtr wPtr, int argc, char **argv,
 			    int flags));
 static void		WidgetDestroy _ANSI_ARGS_((ClientData clientData));
 static void		WidgetEventProc _ANSI_ARGS_((ClientData clientData,
 			    XEvent *eventPtr));
 static int		WidgetCommand _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *, int argc, CONST84 char **argv));
-static void		Tix_MakeInputOnlyWindowExist _ANSI_ARGS_((
-			    WidgetPtr wPtr));
+			    Tcl_Interp *, int argc, char **argv));
 
 
 #define INPUT_ONLY_EVENTS_MASK \
@@ -114,8 +109,7 @@ static XSetWindowAttributes inputOnlyAtts = {
     None			/* cursor */
 };
 
-
-static
+
 void Tix_MakeInputOnlyWindowExist(wPtr)
     WidgetPtr wPtr;
 {
@@ -181,9 +175,9 @@ Tix_InputOnlyCmd(clientData, interp, argc, argv)
 				 * interpreter. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int argc;			/* Number of arguments. */
-    CONST84 char **argv;	/* Argument strings. */
+    char **argv;		/* Argument strings. */
 {
-    Tk_Window mainwin = (Tk_Window) clientData;
+    Tk_Window main = (Tk_Window) clientData;
     WidgetPtr wPtr;
     Tk_Window tkwin;
 
@@ -193,7 +187,7 @@ Tix_InputOnlyCmd(clientData, interp, argc, argv)
 	return TCL_ERROR;
     }
 
-    tkwin = Tk_CreateWindowFromPath(interp, mainwin, argv[1], (char *) NULL);
+    tkwin = Tk_CreateWindowFromPath(interp, main, argv[1], (char *) NULL);
     if (tkwin == NULL) {
 	return TCL_ERROR;
     }
@@ -249,11 +243,11 @@ WidgetCommand(clientData, interp, argc, argv)
     ClientData clientData;		/* Information about the widget. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
-    CONST84 char **argv;		/* Argument strings. */
+    char **argv;			/* Argument strings. */
 {
     WidgetPtr wPtr = (WidgetPtr) clientData;
     int result = TCL_OK;
-    size_t length;
+    int length;
     char c;
 
     if (argc < 2) {
@@ -323,7 +317,7 @@ WidgetConfigure(interp, wPtr, argc, argv, flags)
     Tcl_Interp *interp;			/* Used for error reporting. */
     WidgetPtr wPtr;			/* Information about widget. */
     int argc;				/* Number of valid entries in argv. */
-    CONST84 char **argv;		/* Arguments. */
+    char **argv;			/* Arguments. */
     int flags;				/* Flags to pass to
 					 * Tk_ConfigureWidget. */
 {
