@@ -1,6 +1,3 @@
-
-/*	$Id: tixMwm.c,v 1.1.1.1 2000/05/17 11:08:42 idiscovery Exp $	*/
-
 /*
  * tixMwm.c --
  *
@@ -13,25 +10,17 @@
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
  */
-
-#include <tkInt.h>
-#include <tixPort.h>
-#include <tixInt.h>
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
-#include <X11/Xproto.h>
-#include <X11/Xutil.h>
-
+#include "tkPort.h"
+#include "tkInt.h"
+#include <tix.h>
 
 #ifdef HAS_MOTIF_INC
 #include <Xm/MwmUtil.h>
 #else
 
-/*
- * This section is provided for the machines that don't have the Motif
- * header files installed.
+/* This section is provided for the machines that don't have the Motif
+ * header files installed
  */
-
 #define MWM_DECOR_ALL           (1L << 0)
 #define MWM_DECOR_BORDER        (1L << 1)
 #define MWM_DECOR_RESIZEH       (1L << 2)
@@ -106,9 +95,6 @@ typedef struct Tix_MwmProtocol {
     unsigned int	active : 1;
 } Tix_MwmProtocol;
 
-
-/* Function declaration */
-
 static void		AddMwmProtocol _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tix_MwmInfo *wmPtr, char * name, char * message));
 static void		ActivateMwmProtocol _ANSI_ARGS_((Tcl_Interp *interp,
@@ -139,13 +125,6 @@ static int 		SetMwmDecorations _ANSI_ARGS_((Tcl_Interp *interp,
 static int		SetMwmTransientFor _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tix_MwmInfo*wmPtr, TkWindow *mainWindow, int argc,
 			    char ** argv));
-static void		StructureProc _ANSI_ARGS_((ClientData clientData,
-			    XEvent *eventPtr));
-
-/* Local variables */
-
-static Tcl_HashTable mwmTable;
-
 
 /*
  *----------------------------------------------------------------------
@@ -223,48 +202,10 @@ Tix_MwmCmd(clientData, interp, argc, argv)
 	return TCL_ERROR;
     }
 }
-
-/*
- *----------------------------------------------------------------------
- * TixMwmProtocolHandler --
- *
- *	A generic X event handler that handles the events from the Mwm
- *	Window manager.
- *
- * Results:
- *	True iff the event has been handled.
- *
- * Side effects:
- *	None.
- *----------------------------------------------------------------------
- */
 
-int
-TixMwmProtocolHandler(clientData, eventPtr)
-    ClientData clientData;
-    XEvent *eventPtr;
-{
-    TkWindow *winPtr;
-    Window handlerWindow;
 
-    if (eventPtr->type != ClientMessage) {
-	return 0;
-    }
-
-    handlerWindow = eventPtr->xany.window;
-    winPtr = (TkWindow *) Tk_IdToWindow(eventPtr->xany.display, handlerWindow);
-    if (winPtr != NULL) {
-	if (eventPtr->xclient.message_type ==
-	    Tk_InternAtom((Tk_Window) winPtr,"_MOTIF_WM_MESSAGES")) {
-	    TkWmProtocolEventProc(winPtr, eventPtr);
-	    return 1;
-	}
-    }
-    return 0;
-}
-
-static int
-MwmDecor(interp, string)
+static
+int MwmDecor(interp, string)
     Tcl_Interp * interp;
     char * string;
 {
@@ -519,9 +460,9 @@ static void AddMwmProtocol(interp, wmPtr, name, message)
     }
 
     if (ptPtr->name == NULL) {
-	ptPtr->name = tixStrDup(name);
+	ptPtr->name = (char*)strdup(name);
     }
-    ptPtr->menuMessage = tixStrDup(message);
+    ptPtr->menuMessage = (char*)strdup(message);
     ptPtr->messageLen  = strlen(message);
     ptPtr->active = 1;
 
@@ -626,7 +567,7 @@ static void ResetProtocols(clientData)
 	}
 
 	Tcl_DStringAppend(&dString, ptPtr->menuMessage, ptPtr->messageLen);
-	sprintf(tmp, " f.send_msg %d\n", (int)(ptPtr->protocol));
+	sprintf(tmp, " f.send_msg %d\n", ptPtr->protocol);
 	Tcl_DStringAppend(&dString, tmp, (int)strlen(tmp));
     }
 
@@ -697,76 +638,13 @@ int SetMwmTransientFor(interp, wmPtr, mainWindow, argc, argv)
 	return TCL_ERROR;
     }
 }
-
-/*
- *----------------------------------------------------------------------
- *
- * StructureProc --
- *
- *	Gets called in response to StructureNotify events in toplevels
- *	operated by the tixMwm command. 
- *
- * Results:
- *	none
- *
- * Side effects:
- *	The Tix_MwmInfo for the toplevel is deleted when the toplevel
- *	is destroyed.
- *
- *----------------------------------------------------------------------
- */
-static void
-StructureProc(clientData, eventPtr)
-    ClientData clientData;		/* Our information about window
-					 * referred to by eventPtr. */
-    XEvent *eventPtr;			/* Describes what just happened. */
-{
-    register Tix_MwmInfo * wmPtr = (Tix_MwmInfo *) clientData;
-    Tcl_HashEntry *hashPtr;
-    
-    if (eventPtr->type == DestroyNotify) {
-	Tcl_HashSearch 	  hSearch;
-	Tix_MwmProtocol * ptPtr;
 
-	/* Delete all protocols in the hash table associated with
-	 * this toplevel
-	 */
-	for (hashPtr = Tcl_FirstHashEntry(&wmPtr->protocols, &hSearch);
-	     hashPtr;
-	     hashPtr = Tcl_NextHashEntry(&hSearch)) {
-
-	    ptPtr = (Tix_MwmProtocol *)Tcl_GetHashValue(hashPtr);
-	    ckfree(ptPtr->name);
-	    ckfree(ptPtr->menuMessage);
-	    ckfree((char*)ptPtr);
-	    Tcl_DeleteHashEntry(hashPtr);
-	}
-
-	Tcl_DeleteHashTable(&wmPtr->protocols);
-
-	/*
-	 * Delete info about this toplevel in the table of all toplevels
-	 * controlled by tixMwm
-	 */
-	hashPtr = Tcl_FindHashEntry(&mwmTable, (char*)wmPtr->tkwin);
-	if (hashPtr != NULL) {
-	    Tcl_DeleteHashEntry(hashPtr);
-	}
-
-	if (wmPtr->resetProtocol) {
-	    Tk_CancelIdleCall(ResetProtocols, (ClientData)wmPtr);
-	    wmPtr->resetProtocol = 0;
-	}
-
-	ckfree((char*)wmPtr);
-    }
-}
-
 static Tix_MwmInfo *
 GetMwmInfo(interp, tkwin)
     Tcl_Interp * interp;
     Tk_Window tkwin;
 {
+    static Tcl_HashTable mwmTable;
     static inited = 0;
     Tcl_HashEntry *hashPtr;
     int isNew;
@@ -800,10 +678,6 @@ GetMwmInfo(interp, tkwin)
 	QueryMwmHints(wmPtr);
 
 	Tcl_SetHashValue(hashPtr, (char*)wmPtr);
-
-	Tk_CreateEventHandler(tkwin, StructureNotifyMask,
-	    StructureProc, (ClientData)wmPtr);
-
 	return wmPtr;
     }
 }
