@@ -4,116 +4,49 @@
  *	This file contains some utility functions for Tix, such as the
  *	subcommand handling functions and option handling functions.
  *
- * Copyright (c) 1993-1999 Ioi Kim Lam.
- * Copyright (c) 2000-2001 Tix Project Group.
+ * Copyright (c) 1996, Expert Interface Technologies
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * $Id: tixUtils.c,v 1.11 2004/03/28 02:44:57 hobbs Exp $
  */
 
-/*
- * tclInt.h is needed for the va_list declaration.
- */
 #include <tclInt.h>
-#include <tixPort.h>
-#include <tixInt.h>
+#include <tk.h>
+#include <tkPort.h>
+#include <tix.h>
+
+/*
+ * Declarations for various library procedures and variables (don't want
+ * to include tkInt.h or tkConfig.h here, because people might copy this
+ * file out of the Tk source directory to make their own modified versions).
+ */
 
 /*
  * Forward declarations for procedures defined later in this file:
  */
 
-static int		ReliefParseProc(ClientData clientData,
-	Tcl_Interp *interp, Tk_Window tkwin, CONST84 char *value,
-	char *widRec, int offset);
-static char *	ReliefPrintProc(ClientData clientData,
-	Tk_Window tkwin, char *widRec, int offset,
-	Tix_FreeProc **freeProcPtr);
+static void		Prompt _ANSI_ARGS_((Tcl_Interp *interp, int partial));
+static void		StdinProc _ANSI_ARGS_((ClientData clientData,
+			    int mask));
 
-#define WRONG_ARGC 1
-#define NO_MATCH   2
-
-
-/*----------------------------------------------------------------------
- * TixSaveInterpState --
- *
- *	Save the current application-visible state of the interpreter.
- *	This can later be restored by the TixSaveInterpState() function.
- *	These two functions are useful if you want to evaluate a Tcl
- *	command, which may cause errors, inside a command function.
- *
- *	Each TixSaveInterpState() call much be matched by one
- *	TixRestoreInterpState() call with the same statePtr. statePtr
- *	should be allocated by the calling function, usually
- *	as a variable on the stack.
- *----------------------------------------------------------------------
+/*
+ * Some ugly but necessary global vars used in this file
  */
+static Tcl_DString command;	/* Used to assemble lines of terminal input
+				 * into Tcl commands. */
 
-void
-TixSaveInterpState(interp, statePtr)
-    Tcl_Interp * interp;
-    TixInterpState * statePtr;
-{
-    CONST84 char * p;
-    if (interp->result) {
-	statePtr->result = tixStrDup(interp->result);
-    } else {
-	statePtr->result = NULL;
-    }
 
-    p = Tcl_GetVar2(interp, "errorInfo", NULL, TCL_GLOBAL_ONLY);
-    statePtr->errorInfo = (p ? tixStrDup(p) : NULL);
-
-    p = Tcl_GetVar2(interp, "errorCode", NULL, TCL_GLOBAL_ONLY);
-    statePtr->errorCode = (p ? tixStrDup(p) : NULL);
-}
-
-/*----------------------------------------------------------------------
- * TixRestoreInterpState --
+/* Tix_HandleSubCmds --
+ *
+ *	This function makes it easier to write major-minor style TCL commands.
+ * It matches the minor command (sub-command) names with names defined in
+ * the cmdInfo structure and call the appropriate sub-command functions for
+ * you. This function will automatically generate error messages when
+ * the user calls an invalid sub-command or calls a sub-command with
+ * incorrect number of arguments.
  *
- *	See TixSaveInterpState above.
- *----------------------------------------------------------------------
  */
-
-void
-TixRestoreInterpState(interp, statePtr)
-    Tcl_Interp * interp;
-    TixInterpState * statePtr;
-{
-    if (statePtr->result) {
-	Tcl_SetResult(interp, statePtr->result, TCL_DYNAMIC);
-    }
-    if (statePtr->errorInfo) {
-	Tcl_SetVar2(interp, "errorInfo", NULL, statePtr->errorInfo,
-		TCL_GLOBAL_ONLY);
-	ckfree((char*)statePtr->errorInfo);
-    } else {
-	Tcl_UnsetVar2(interp, "errorInfo", NULL, TCL_GLOBAL_ONLY);
-    }
-    if (statePtr->errorCode) {
-	Tcl_SetVar2(interp, "errorCode", NULL, statePtr->errorCode,
-		TCL_GLOBAL_ONLY);
-	ckfree((char*)statePtr->errorCode);
-    } else {
-	Tcl_UnsetVar2(interp, "errorCode", NULL, TCL_GLOBAL_ONLY);
-    }
-}
-
-/*----------------------------------------------------------------------
- * Tix_HandleSubCmds --
- *
- *	This function makes it easier to write major-minor style TCL
- *	commands.  It matches the minor command (sub-command) names
- *	with names defined in the cmdInfo structure and call the
- *	appropriate sub-command functions for you. This function will
- *	automatically generate error messages when the user calls an
- *	invalid sub-command or calls a sub-command with incorrect
- *	number of arguments.
- *
- *----------------------------------------------------------------------
- */
-
 int Tix_HandleSubCmds(cmdInfo, subCmdInfo, clientData, interp, argc, argv)
     Tix_CmdInfo * cmdInfo;
     Tix_SubCmdInfo * subCmdInfo;
@@ -121,12 +54,13 @@ int Tix_HandleSubCmds(cmdInfo, subCmdInfo, clientData, interp, argc, argv)
 				 * interpreter. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int argc;			/* Number of arguments. */
-    CONST84 char **argv;	/* Argument strings. */
+    char **argv;		/* Argument strings. */
 {
+    enum {WRONG_ARGC, NO_MATCH};
 
     int i;
+    int len;
     int error = NO_MATCH;
-    unsigned int len;
     Tix_SubCmdInfo * s;
 
     /*
@@ -189,7 +123,7 @@ int Tix_HandleSubCmds(cmdInfo, subCmdInfo, clientData, interp, argc, argv)
 	 * got a match but incorrect number of arguments
 	 */
 	Tcl_AppendResult(interp, "wrong # args: should be \"",
-	    argv[0], " ", argv[1], " ", s->info, "\"", (char *) NULL);
+	    argv[0], " ", argv[1], " ", s->info, (char *) NULL);
     } else {
 	int max;
 
@@ -232,14 +166,13 @@ int Tix_HandleSubCmds(cmdInfo, subCmdInfo, clientData, interp, argc, argv)
     }
     return TCL_ERROR;
 }
-
-/*----------------------------------------------------------------------
- * Tix_Exit --
+
+/*
+ * Tix_Exit
  *
- *	Call the "exit" tcl command so that things can be cleaned up
- *	before calling the unix exit(2);
+ * Call the "exit" tcl command so that things can be cleaned up before
+ * calling the unix exit(2);
  *
- *----------------------------------------------------------------------
  */
 void Tix_Exit(interp, code)
     Tcl_Interp* interp;
@@ -252,21 +185,265 @@ void Tix_Exit(interp, code)
     }
 
     if (interp) {
-	Tcl_EvalEx(interp, "exit", -1, TCL_GLOBAL_ONLY);
+	Tcl_GlobalEval(interp, "exit");
     }
     exit(code);
 }
+
+void Tix_OpenStdin(interp)
+    Tcl_Interp *interp;
+{
+    static int stdin_opened = 0;
+
+    if (stdin_opened ==  0)  {
+	Tk_CreateFileHandler(0, TK_READABLE, StdinProc, (ClientData) interp);
+	Prompt(interp, 0);
+	Tcl_DStringInit(&command);
+
+	stdin_opened = 1;
+    }
+}
+
+/*
+ * Tix_ShellInputCmd -
+ *
+ * This command forces wish to read from the standard input. This makes
+ * debugging a lot easier.
+ *
+ * If wish is already reading from stdin, this command has no effect.
+ *
+ */
+int Tix_ShellInputCmd(clientData, interp, argc, argv)
+    ClientData clientData;	/* Main window associated with
+				 * interpreter. */
+    Tcl_Interp *interp;		/* Current interpreter. */
+    int argc;			/* Number of arguments. */
+    char **argv;		/* Argument strings. */
+{
+
+#ifndef _Windows
+    Tix_OpenStdin(interp);
+
+    return TCL_OK;
+#else
+#ifdef NO_DLL
+    return TkConsoleInit(interp);
+#else
+    return TCL_OK;
+#endif
+#endif
+}
+
+
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * StdinProc --
+ *
+ *	This procedure is invoked by the event dispatcher whenever
+ *	standard input becomes readable.  It grabs the next line of
+ *	input characters, adds them to a command being assembled, and
+ *	executes the command if it's complete.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Could be almost arbitrary, depending on the command that's
+ *	typed.
+ *
+ *----------------------------------------------------------------------
+ */
+
+    /* ARGSUSED */
+static void
+StdinProc(clientData, mask)
+    ClientData clientData;		/* Not used. */
+    int mask;				/* Not used. */
+{
+#define BUFFER_SIZE 4000
+    char input[BUFFER_SIZE+1];
+    static int gotPartial = 0;
+    char *cmd;
+    int code, count;
+    Tcl_Interp * interp = (Tcl_Interp*)clientData;
+
+    count = read(fileno(stdin), input, BUFFER_SIZE);
+    if (isatty(0)) {
+	if (count <= 0) {
+	    if (!gotPartial) {
+		/* The user has typed the end-of-file key
+		 */
+		Tcl_GlobalEval(interp, "exit");
+		exit(1);
+	    } else {
+		count = 0;
+	    }
+	}
+    } else {
+	if (count <= 0) {
+	    /* End of file */
+	    Tk_CreateFileHandler(0, 0, StdinProc, (ClientData) interp);
+	    return;
+	}
+    }
+
+    cmd = Tcl_DStringAppend(&command, input, count);
+    if (count != 0) {
+	if ((input[count-1] != '\n') && (input[count-1] != ';')) {
+	    gotPartial = 1;
+	    goto prompt;
+	}
+	if (!Tcl_CommandComplete(cmd)) {
+	    gotPartial = 1;
+	    goto prompt;
+	}
+    }
+    gotPartial = 0;
+
+    /*
+     * Disable the stdin file handler while evaluating the command;
+     * otherwise if the command re-enters the event loop we might
+     * process commands from stdin before the current command is
+     * finished.  Among other things, this will trash the text of the
+     * command being evaluated.
+     */
+
+    Tk_CreateFileHandler(0, 0, StdinProc, (ClientData) interp);
+    code = Tcl_RecordAndEval(interp, cmd, 0);
+    Tk_CreateFileHandler(0, TK_READABLE, StdinProc, (ClientData) interp);
+    Tcl_DStringFree(&command);
+    if (interp->result != 0 && isatty(0)) {
+	printf("%s\n", interp->result);
+    }
+
+    /*
+     * Output a prompt.
+     */
+
+  prompt:
+    Prompt(interp, gotPartial);
+}
 
+/*
+ *----------------------------------------------------------------------
+ *
+ * Prompt --
+ *
+ *	Issue a prompt on standard output, or invoke a script
+ *	to issue the prompt.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	A prompt gets output, and a Tcl script may be evaluated
+ *	in interp.
+ *
+ *----------------------------------------------------------------------
+ */
+
+static void
+Prompt(interp, partial)
+    Tcl_Interp *interp;			/* Interpreter to use for prompting. */
+    int partial;			/* Non-zero means there already
+					 * exists a partial command, so use
+					 * the secondary prompt. */
+{
+    char *promptCmd;
+    int code;
+
+    promptCmd = Tcl_GetVar(interp,
+	partial ? "tcl_prompt2" : "tcl_prompt1", TCL_GLOBAL_ONLY);
+    if (promptCmd == NULL) {
+	defaultPrompt:
+	if (!partial && isatty(0)){
+	    fputs("% ", stdout);
+	}
+    } else {
+	code = Tcl_GlobalEval(interp, promptCmd);
+	if (code != TCL_OK) {
+	    Tcl_AddErrorInfo(interp,
+		    "\n    (script that generates prompt)");
+	    fprintf(stderr, "%s\n", interp->result);
+	    goto defaultPrompt;
+	}
+    }
+    fflush(stdout);
+}
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * Tix_LoadTclLibrary --
+ *
+ *	Loads in a TCL library for an application according to 
+ *	the library settings.
+ *
+ * Results:
+ *	TCL_OK or TCL_ERROR
+ *
+ * envName	the environment variable that indicates the library
+ * tclName	the TCL variable that points to the TCL library.
+ * initFile	the file to load in during initialization.
+ * defDir	the default directory to search if the user hasn't set
+ *		the environment variable.
+ * appName	the name of the application.
+ *----------------------------------------------------------------------
+ */
+
+/* Some compilers can't handle multi-line character strings very well ...
+ * So I just using this big lump of mess here.
+ */
+static char _format[] = "lappend auto_path $%s \nif [file exists $%s/%s] {\nsource $%s/%s\n} else {\nset msg \"\ncan't find $%s/%s;\\nperhaps you \"\nappend msg \"need to install %s\\nor set your %s \"\nappend msg \"environment variable?\"\nerror $msg\n}";
+
+int
+Tix_LoadTclLibrary(interp, envName, tclName, initFile, defDir, appName)
+    Tcl_Interp *interp;
+    char *envName;
+    char *tclName;
+    char *initFile;
+    char *defDir;
+    char *appName;
+{
+    char * libDir, *initCmd;	/* should be big enough */
+    size_t size;
+    int code;
+    char *format;
+    format = _format;
+
+    if (!(libDir = getenv(envName))) {
+	libDir = defDir; 
+    }
+
+    size = strlen(format) + strlen(tclName)*4 + strlen(initFile)*3
+	+ strlen(appName) + strlen(envName) + 100;
+    initCmd = ckalloc(sizeof(char) * size);
+
+    Tcl_SetVar(interp, tclName, libDir, TCL_GLOBAL_ONLY);
+
+    sprintf(initCmd, format,
+	tclName,
+	tclName, initFile,
+	tclName, initFile,
+	tclName, initFile,
+	appName, envName
+    );
+
+    code =  Tcl_GlobalEval(interp, initCmd);
+    ckfree(initCmd);
+    return code;
+}
+
 /*----------------------------------------------------------------------
  * Tix_CreateCommands --
  *
  *
  *	Creates a list of commands stored in the array "commands"
- *----------------------------------------------------------------------
+ *
  */
 
-static int initialized = 0;
-
 void Tix_CreateCommands(interp, commands, clientData, deleteProc)
     Tcl_Interp *interp;
     Tix_TclCmd *commands;
@@ -275,127 +452,19 @@ void Tix_CreateCommands(interp, commands, clientData, deleteProc)
 {
     Tix_TclCmd * cmdPtr;
 
-    if (!initialized) {
-	Tcl_CmdInfo cmdInfo;
-
-	initialized = 1;
-	if (!Tcl_GetCommandInfo(interp,"image", (Tcl_CmdInfo *) &cmdInfo)) {
-	    Tcl_Panic("cannot find the \"image\" command");
-	} else if (cmdInfo.isNativeObjectProc == 1) {
-	    initialized = 2; /* we use objects */
-	}
-    }
     for (cmdPtr = commands; cmdPtr->name != NULL; cmdPtr++) {
 	Tcl_CreateCommand(interp, cmdPtr->name,
 	     cmdPtr->cmdProc, clientData, deleteProc);
     }
 }
 
-/*
- *----------------------------------------------------------------------
- * Tix_GetAnchorGC --
- *
- *	Get the GC for drawing the anchor dotted lines around anchor
- *	elements.
- *
- * Results:
- *	Returns a GC that can be passed to Tix_DrawAnchorLines for
- *	drawing an anchor line for the given background color.
- *
- * Side effects:
- *	None.
- *----------------------------------------------------------------------
- */
-
-GC
-Tix_GetAnchorGC(tkwin, bgColor)
-	Tk_Window tkwin;
-	XColor *bgColor;
-{
-    XGCValues gcValues;
-    XColor valueKey;
-    XColor * anchorColor;
-    int r, g, b;
-    int max;
-
-    /*
-     * Get the best color to draw the dotted lines on the given background
-     * color.
-     */
-
-    r = bgColor->red;
-    g = bgColor->green;
-    b = bgColor->blue;
-
-    r = (65535 - r) & 0xffff;
-    g = (65535 - g) & 0xffff;
-    b = (65535 - b) & 0xffff;
-
-    max = r;
-    if (max < g) {
-	max = g;
-    }
-    if (max < b) {
-	max = b;
-    }
-
-    max = max / 256;
-    if (max > 96) {
-	/*
-	 * scale color up
-	 */
-
-	r = (r * 255) / max;
-	g = (g * 255) / max;
-	b = (b * 255) / max;
-    } else {
-	/*
-	 * scale color down
-	 */
-	int min = r;
-	if (min > g) {
-	    min = g;
-	}
-	if (min > b) {
-	    min = b;
-	}
-	r = r - min;
-	g = g - min;
-	b = b - min;
-    }
-
-    valueKey.red   = r;
-    valueKey.green = g;
-    valueKey.blue  = b;
-
-    anchorColor = Tk_GetColorByValue(tkwin, &valueKey);
-
-    gcValues.foreground		= anchorColor->pixel;
-    gcValues.graphics_exposures = False;
-    gcValues.subwindow_mode	= IncludeInferiors;
-
-    return Tk_GetGC(tkwin, GCForeground|GCGraphicsExposures|GCSubwindowMode,
-	    &gcValues);
-}
-
-/*
- *----------------------------------------------------------------------
+/*----------------------------------------------------------------------
  * Tix_DrawAnchorLines --
  *
- *	Draw dotted anchor lines around anchor elements. The exact
- *	behavior is defined in the platform-specific
- *	TixpDrawAnchorLines function.
+ * 	Draw dotted anchor lines around anchor elements
  *
- * Results:
- *	None.
- *
- * Side effects:
- *	None.
- *----------------------------------------------------------------------
  */
-
-void
-Tix_DrawAnchorLines(display, drawable, gc, x, y, w, h)
+void Tix_DrawAnchorLines(display, drawable, gc, x, y, w, h)
     Display *display;
     Drawable drawable;
     GC gc;
@@ -404,31 +473,52 @@ Tix_DrawAnchorLines(display, drawable, gc, x, y, w, h)
     int w;
     int h;
 {
-    TixpDrawAnchorLines(display, drawable, gc, x, y, w, h);
+    XPoint points[4];
+
+    if (w < 1) {
+	w = 1;
+    }
+    if (h < 1) {
+	h = 1;
+    }
+
+    XDrawRectangle(display, drawable, gc, x, y, w, h);
+
+    /* Draw these points so that the corners will not be rounded */
+    points[0].x = x;
+    points[0].y = y;
+    points[1].x = x+w;
+    points[1].y = y;
+    points[2].x = x;
+    points[2].y = y+h;
+    points[3].x = x+w;
+    points[3].y = y+h;
+    XDrawPoints(display, drawable, gc,
+	points, 4, CoordModeOrigin);
 }
 
 /*----------------------------------------------------------------------
  * Tix_CreateSubWindow --
  *
+ *
  *	Creates a subwindow for a widget (usually used to draw headers,
  *	e.g, HList and Grid widgets)
- *----------------------------------------------------------------------
+ *
  */
-
 Tk_Window
 Tix_CreateSubWindow(interp, tkwin, subPath)
     Tcl_Interp * interp;
     Tk_Window tkwin;
-    CONST84 char * subPath;
+    char * subPath;
 {
     Tcl_DString dString;
     Tk_Window subwin;
 
     Tcl_DStringInit(&dString);
     Tcl_DStringAppend(&dString, Tk_PathName(tkwin),
-	    (int) strlen(Tk_PathName(tkwin)));
+	strlen(Tk_PathName(tkwin)));
     Tcl_DStringAppend(&dString, ".tixsw:", 7);
-    Tcl_DStringAppend(&dString, subPath, (int) strlen(subPath));
+    Tcl_DStringAppend(&dString, subPath, strlen(subPath));
 
     subwin = Tk_CreateWindowFromPath(interp, tkwin, dString.string,
 	(char *) NULL);
@@ -437,6 +527,19 @@ Tix_CreateSubWindow(interp, tkwin, subPath)
 
     return subwin;
 }
+
+/*----------------------------------------------------------------------
+ * Tix_GetRenderBuffer --
+ *
+ *	Returns a drawable for rendering a widget. If there is sufficient
+ *	resource, a pixmap is returned so that double-buffering can
+ *	be done. However, if resource is insufficient, then the
+ *	windowId is returned. In the second case happens, the caller
+ *	of this function has two choices: (1) draw to the window directly
+ *	(which may lead to flashing on the screen) or (2) try to allocate
+ *	smaller pixmaps.
+ *
+ */
 static int
 ErrorProc(clientData, errorEventPtr)
     ClientData clientData;
@@ -448,48 +551,14 @@ ErrorProc(clientData, errorEventPtr)
     return 0;				/* return 0 means error has been
 					 * handled properly */
 }
-
-/*
- *----------------------------------------------------------------------
- * Tix_GetRenderBuffer --
- *
- *	Returns a drawable for rendering a widget. If there is
- *	sufficient graphics resource, a pixmap is returned so that
- *	double-buffering can be done. However, if resource is
- *	insufficient, then the windowId is returned. In the second
- *	case happens, the caller of this function has two choices: (1)
- *	draw to the window directly (which may lead to flickering on
- *	the screen) or (2) try to allocate smaller pixmaps.
- *
- * Results:
- *	An allocated pixmap of the same depth as the window, or the
- *	window itself.
- *
- * Side effects:
- *	A pixmap may be allocated. The caller should call
- *	Tk_FreePixmap() to free the pixmap returned by this function.
- *
- *----------------------------------------------------------------------
- */
 
-/*
- * Uncomment this if you want to use single-buffer mode drawing to
- * debug paintings.
- */
-
-/* #define PAINT_DEBUG 1 */
-
-Drawable
-Tix_GetRenderBuffer(display, windowId, width, height, depth)
-    Display *display;		/* Display of the windowId */
-    Window windowId;		/* Window to draw into */
-    int width;			/* width of the drawing region */
-    int height;			/* height of the drawing region */
-    int depth;			/* Depth of the window. TODO remove this arg*/
+Drawable Tix_GetRenderBuffer(display, windowId, width, height, depth)
+    Display *display;
+    Window windowId;
+    int width;
+    int height;
+    int depth;
 {
-#ifdef PAINT_DEBUG
-    return windowId;
-#else
     Tk_ErrorHandler handler;
     Pixmap pixmap;
     int badAlloc = 0;
@@ -498,14 +567,12 @@ Tix_GetRenderBuffer(display, windowId, width, height, depth)
 	-1, -1, (Tk_ErrorProc *) ErrorProc, (ClientData) &badAlloc);
     pixmap = Tk_GetPixmap(display, windowId, width, height, depth);
 
-#if !defined(__WIN32__) && !defined(MAC_TCL) /* UNIX */
-    /*
-     * This XSync call is necessary because X may delay the delivery of the
+    /* This XSync call is necessary because X may delay the delivery of the
      * error message. This will make our graphics a bit slower, though,
      * especially over slow lines
      */
     XSync(display, 0);
-#endif
+
     /* If ErrorProc() is eevr called, it is called before XSync returns */
 
     Tk_DeleteErrorHandler(handler);
@@ -515,7 +582,6 @@ Tix_GetRenderBuffer(display, windowId, width, height, depth)
     } else {
 	return windowId;
     }
-#endif
 }
 
 /*
@@ -538,7 +604,19 @@ Tix_GetRenderBuffer(display, windowId, width, height, depth)
  */
 	/* VARARGS2 */ /* ARGSUSED */
 int
+#ifdef TCL_VARARGS_DEF
 Tix_GlobalVarEval TCL_VARARGS_DEF(Tcl_Interp *,arg1)
+#else
+#ifndef lint
+Tix_GlobalVarEval(va_alist)
+#else
+Tix_GlobalVarEval(iPtr, p, va_alist)
+    Tcl_Interp *iPtr;		/* Interpreter in which to execute command. */
+    char *p;			/* One or more strings to concatenate,
+				 * terminated with a NULL string. */
+#endif
+    va_dcl
+#endif
 {
     va_list argList;
     Tcl_DString buf;
@@ -546,9 +624,10 @@ Tix_GlobalVarEval TCL_VARARGS_DEF(Tcl_Interp *,arg1)
     Tcl_Interp *interp;
     int result;
 
+#ifdef TCL_VARARGS_DEF
     /*
      * Copy the strings one after the other into a single larger
-     * string.	Use stack-allocated space for small commands, but if
+     * string.  Use stack-allocated space for small commands, but if
      * the command gets too large than call ckalloc to create the
      * space.
      */
@@ -564,88 +643,27 @@ Tix_GlobalVarEval TCL_VARARGS_DEF(Tcl_Interp *,arg1)
     }
     va_end(argList);
 
-    result = Tcl_EvalEx(interp, Tcl_DStringValue(&buf),
-	    Tcl_DStringLength(&buf), TCL_GLOBAL_ONLY);
+    result = Tcl_GlobalEval(interp, Tcl_DStringValue(&buf));
     Tcl_DStringFree(&buf);
     return result;
-}
-
-/*----------------------------------------------------------------------
- * TixGetHashTable --
- *
- *	This functions makes it possible to keep one hash table per
- *	interpreter. This way, Tix classes can be used in multiple
- *	interpreters.
- *
- *----------------------------------------------------------------------
- */
-
-static void		DeleteHashTableProc _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp * interp));
-static void
-DeleteHashTableProc(clientData, interp)
-    ClientData clientData;
-    Tcl_Interp * interp;
-{
-    Tcl_HashTable * htPtr = (Tcl_HashTable *)clientData;
-    Tcl_HashSearch hashSearch;
-    Tcl_HashEntry * hashPtr;
-
-    for (hashPtr = Tcl_FirstHashEntry(htPtr, &hashSearch);
-	    hashPtr;
-	    hashPtr = Tcl_NextHashEntry(&hashSearch)) {
-	Tcl_DeleteHashEntry(hashPtr);
-    }
-
-    Tcl_DeleteHashTable(htPtr);
-    ckfree((char*)htPtr);
-}
-
-/*
- *----------------------------------------------------------------------
- * TixGetHashTable() --
- *
- *	Returns a named hashtable to be used for the given
- *	interpreter. Creates the hashtable if it doesn't exist yet. It
- *	uses Tcl_GetAssocData to make sure that the hashtable is not
- *	shared by different interpreters.
- *
- * Results:
- *	Pointer to the hashtable.
- *
- * Side effects:
- *	The hashtable is created if it doesn't exist yet.
- *
- *----------------------------------------------------------------------
- */
-
-Tcl_HashTable *
-TixGetHashTable(interp, name, deleteProc, keyType)
-    Tcl_Interp * interp;
-    char * name;
-    Tcl_InterpDeleteProc *deleteProc;
-    int keyType;
-{
-    Tcl_HashTable * htPtr;
-
-    htPtr = (Tcl_HashTable*)Tcl_GetAssocData(interp, name, NULL);
-
-    if (htPtr == NULL) {
-	htPtr = (Tcl_HashTable *)ckalloc(sizeof(Tcl_HashTable));
-	Tcl_InitHashTable(htPtr, keyType);
-	Tcl_SetAssocData(interp, name, NULL, (ClientData)htPtr);
-
-	if (deleteProc) {
-	    Tcl_CallWhenDeleted(interp, deleteProc, (ClientData)htPtr);
-	} else {
-	    Tcl_CallWhenDeleted(interp, DeleteHashTableProc,
-		    (ClientData)htPtr);
+#else
+    va_start(argList);
+    interp = va_arg(argList, Tcl_Interp *);
+    Tcl_DStringInit(&buf);
+    while (1) {
+	string = va_arg(argList, char *);
+	if (string == NULL) {
+	    break;
 	}
+	Tcl_DStringAppend(&buf, string, -1);
     }
+    va_end(argList);
 
-    return htPtr;
+    result = Tcl_GlobalEval(interp, Tcl_DStringValue(&buf));
+    Tcl_DStringFree(&buf);
+    return result;
+#endif
 }
-
 /*----------------------------------------------------------------------
  *
  *		 The Tix Customed Config Options
@@ -660,17 +678,16 @@ TixGetHashTable(interp, name, deleteProc, keyType)
  *	inside the widget record.
  *----------------------------------------------------------------------
  */
-static int
-ReliefParseProc(clientData, interp, tkwin, value, widRec,offset)
+static int ReliefParseProc(clientData, interp, tkwin, value, widRec,offset)
     ClientData clientData;
     Tcl_Interp *interp;
     Tk_Window tkwin;
-    CONST84 char *value;
-    char *widRec;	/* Must point to a valid Tix_DItem struct */
+    char *value;
+    char *widRec;		/* Must point to a valid Tix_DItem struct */
     int offset;
 {
     Tix_Relief * ptr = (Tix_Relief *)(widRec + offset);
-    Tix_Relief	 newVal;
+    Tix_Relief   newVal;
 
     if (value != NULL) {
 	size_t len = strlen(value);
@@ -691,7 +708,7 @@ ReliefParseProc(clientData, interp, tkwin, value, widRec,offset)
 	    goto error;
 	}
     } else {
-	value = "";
+	value == "";
 	goto error;
     }
 
@@ -704,8 +721,7 @@ ReliefParseProc(clientData, interp, tkwin, value, widRec,offset)
     return TCL_ERROR;
 }
 
-static char *
-ReliefPrintProc(clientData, tkwin, widRec,offset, freeProcPtr)
+static char *ReliefPrintProc(clientData, tkwin, widRec,offset, freeProcPtr)
     ClientData clientData;
     Tk_Window tkwin;
     char *widRec;
@@ -741,148 +757,24 @@ Tk_CustomOption tixConfigRelief = {
     ReliefParseProc, ReliefPrintProc, 0,
 };
 
-/* Tix_SetRcFileName --
- *
- *	Sets a user-specific startup file in a way that's compatible with
- *	different versions of Tclsh
- */
-void Tix_SetRcFileName(interp, rcFileName)
+void Tix_SetRcFileName(interp, appName)
     Tcl_Interp * interp;
-    CONST84 char * rcFileName;
+    char * appName;
 {
-    /*
-     * Starting from TCL 7.5, the symbol tcl_rcFileName is no longer
+    char *buff = ckalloc(strlen(appName) + 100);
+
+    sprintf(buff, "~/.%src");
+
+#if ((TCL_MAJOR_VERSION > 7) || ((TCL_MAJOR_VERSION == 7) && (TCL_MINOR_VERSION >= 5)))
+    /* Starting from TCL 7.5, the symbol tcl_rcFileName is no longer
      * exported by libtcl.a. Instead, this variable must be set using
      * a TCL global variable
      */
-    Tcl_SetVar(interp, "tcl_rcFileName", rcFileName, TCL_GLOBAL_ONLY);
-}
+    Tcl_SetVar(interp, "tcl_rcFileName", buff, TCL_GLOBAL_ONLY);
+    ckfree(buff);
+#else
+    tcl_RcFileName = buff;
+#endif
 
-/*
- * The TkComputeTextGeometry function is no longer supported in Tk 8.0+
- */
 
-/*
- *----------------------------------------------------------------------
- *
- * TixComputeTextGeometry --
- *
- *	This procedure computes the amount of screen space needed to
- *	display a multi-line string of text.
- *
- * Results:
- *	There is no return value.  The dimensions of the screen area
- *	needed to display the text are returned in *widthPtr, and *heightPtr.
- *
- * Side effects:
- *	None.
- *
- *----------------------------------------------------------------------
- */
-
-void
-TixComputeTextGeometry(font, string, numChars, wrapLength,
-	widthPtr, heightPtr)
-    TixFont font;		/* Font that will be used to display text. */
-    CONST84 char *string;	/* String whose dimensions are to be
-				 * computed. */
-    int numChars;		/* Number of characters to consider from
-				 * string. -1 means the entire size of
-				 * the text string */
-    int wrapLength;		/* Longest permissible line length, in
-				 * pixels.  <= 0 means no automatic wrapping:
-				 * just let lines get as long as needed. */
-    int *widthPtr;		/* Store width of string here. */
-    int *heightPtr;		/* Store height of string here. */
-{
-    Tk_TextLayout textLayout;
-
-    /*
-     * The justification itself doesn't affect the geometry (size) of 
-     * the text string. We pass TK_JUSTIFY_LEFT.
-     */
-
-    textLayout = Tk_ComputeTextLayout(font,
-	string, numChars, wrapLength, TK_JUSTIFY_LEFT, 0,
-	widthPtr, heightPtr);
-    Tk_FreeTextLayout(textLayout);
-}
-
-/*
- *----------------------------------------------------------------------
- *
- * TixDisplayText --
- *
- *	Display a text string on one or more lines.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	The text given by "string" gets displayed at the given location
- *	in the given drawable with the given font etc.
- *
- *----------------------------------------------------------------------
- */
-
-void
-TixDisplayText(display, drawable, font, string, numChars, x, y,
-	length, justify, underline, gc)
-    Display *display;		/* X display to use for drawing text. */
-    Drawable drawable;		/* Window or pixmap in which to draw the
-				 * text. */
-    TixFont font;		/* Font that determines geometry of text
-				 * (should be same as font in gc). */
-    CONST84 char *string;	/* String to display;  may contain embedded
-				 * newlines. */
-    int numChars;		/* Number of characters to use from string. */
-    int x, y;			/* Pixel coordinates within drawable of
-				 * upper left corner of display area. */
-    int length;			/* Line length in pixels;  used to compute
-				 * word wrap points and also for
-				 * justification. Must be > 0. */
-    Tk_Justify justify;		/* How to justify lines. */
-    int underline;		/* Index of character to underline, or < 0
-				 * for no underlining. */
-    GC gc;			/* Graphics context to use for drawing text. */
-{
-    Tk_TextLayout textLayout;
-    int dummyx, dummyy;
-
-    textLayout = Tk_ComputeTextLayout(font,
-	string, numChars, length, justify, 0,
-	&dummyx, &dummyy);
-
-    Tk_DrawTextLayout(display, drawable, gc, textLayout,
-	    x, y, 0, -1);
-    Tk_UnderlineTextLayout(display, drawable, gc,
-	    textLayout, x, y, underline);
-
-    Tk_FreeTextLayout(textLayout);
-}
-
-/*
- *----------------------------------------------------------------------
- * Tix_ZAlloc --
- *
- *	Allocate the memory block with ckalloc and zeros it.
- *
- * Results:
- *	Same as ckalloc() except the new memory block is filled with 
- *	zero. Returns NULL if memory allocation fails.
- *
- * Side effects:
- *	None.
- *----------------------------------------------------------------------
- */
-
-char * Tix_ZAlloc(nbytes)
-    unsigned int nbytes;	/* size of memory block to alloc, in
-				 * number of bytes.*/
-{
-    char * ptr = (char*)ckalloc(nbytes);
-    if (ptr) {
-	memset(ptr, 0, nbytes);
-    }
-    return ptr;
 }
