@@ -1,23 +1,24 @@
 /*
  * tixWidget.c --
  *
- *	Constructs Tix-based mega widgets
+ *	Constructs Tix-based compound widgets
  *
- * Copyright (c) 1993-1999 Ioi Kim Lam.
- * Copyright (c) 2000-2001 Tix Project Group.
+ * Copyright (c) 1996, Expert Interface Technologies
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * $Id: tixWidget.c,v 1.5 2004/03/28 02:44:57 hobbs Exp $
  */
 
-#include <tcl.h>
 #include <tclInt.h>
-#include <tixInt.h>
+#include <tkPort.h>
+#include <tk.h>
+#include <tix.h>
 
-static int	ParseOptions(Tcl_Interp *interp, TixClassRecord *cPtr,
-	CONST84 char *widRec, int argc, CONST84 char** argv);
+
+static int			ParseOptions _ANSI_ARGS_((
+				    Tcl_Interp * interp,TixClassRecord * cPtr,
+				    char *widRec, int argc, char** argv));
 
 TIX_DECLARE_CMD(Tix_InstanceCmd);
 
@@ -27,37 +28,32 @@ TIX_DECLARE_CMD(Tix_InstanceCmd);
  * 	Create an instance object of a Tix widget class.
  *
  * argv[0]  = object name.
- * argv[1+] = args
- *----------------------------------------------------------------------
+ * argv[1+] = args 
  */
 TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
 {
     TixClassRecord * cPtr =(TixClassRecord *)clientData;
     TixConfigSpec * spec;
-    CONST84 char * value;
-    CONST84 char * widRec = NULL;
-    char * widCmd = NULL, * rootCmd = NULL;
+    char * widRec = NULL;
+    char * rootCmd = NULL;
+    char * tmpArgv[3];
+    char * value;
     int i;
     int code = TCL_OK;
     Tk_Window mainWin = Tk_MainWindow(interp);
 
+#ifdef ITCL_20
+    register Interp *iPtr = (Interp *) interp;
+    CallFrame *savedVarFramePtr;
+    Itcl_ActiveNamespace nsToken = NULL;
+#endif
+
     if (argc <= 1) {
 	return Tix_ArgcError(interp, argc, argv, 1, "pathname ?arg? ...");
     } else {
 	widRec = argv[1];
     }
 
-    if (strstr(argv[1], "::") != NULL) {
-        /*
-         * Cannot contain :: in widget name, otherwise all hell will
-         * rise w.r.t. namespace
-         */
-
-        Tcl_AppendResult(interp, "invalid widget name \"", argv[1],
-		"\": may not contain substring \"::\"", NULL);
-        return TCL_ERROR;
-    }
-
     if (Tk_NameToWindow(interp, widRec, mainWin) != NULL) {
 	Tcl_ResetResult(interp);
 	Tcl_AppendResult(interp, "window name \"", widRec,
@@ -67,6 +63,17 @@ TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
 	Tcl_ResetResult(interp);
     }
 
+#ifdef ITCL_20
+    savedVarFramePtr = iPtr->varFramePtr;
+    iPtr->varFramePtr = NULL;
+
+    nsToken = Itcl_ActivateNamesp(interp, (Itcl_Namespace)iPtr->globalNs);
+    if (nsToken == NULL) {
+        code = TCL_ERROR;
+	goto done;
+    }
+#endif
+
     /*
      * Before doing anything, let's reset the TCL result, errorInfo,
      * errorCode, etc.
@@ -75,16 +82,9 @@ TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
     Tcl_SetVar2(interp, "errorCode", NULL, "", TCL_GLOBAL_ONLY);
     Tcl_ResetResult(interp);
 
-    /*
-     * Set up the widget record
-     *
-     * TODO: avoid buffer allocation if possible.
-     */
-    widCmd = ckalloc(strlen(widRec) + 3);
-    sprintf(widCmd, "::%s", widRec);
-    rootCmd = ckalloc(strlen(widRec) + 8);
-    sprintf(rootCmd, "::%s:root", widRec);
-
+    /* Set up the widget record */
+    rootCmd = ckalloc(strlen(widRec)+10);
+    sprintf(rootCmd, "%s:root", widRec);
     Tcl_SetVar2(interp, widRec, "className", cPtr->className, TCL_GLOBAL_ONLY);
     Tcl_SetVar2(interp, widRec, "ClassName", cPtr->ClassName, TCL_GLOBAL_ONLY);
     Tcl_SetVar2(interp, widRec, "context",   cPtr->className, TCL_GLOBAL_ONLY);
@@ -95,7 +95,7 @@ TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
      * database
      */
     if (Tix_CallMethod(interp, cPtr->className, widRec, "CreateRootWidget",
-	    argc-2, argv+2, NULL) != TCL_OK) {
+	    argc-2, argv+2) != TCL_OK) {
 	code = TCL_ERROR;
 	goto done;
     }
@@ -112,31 +112,34 @@ TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
     /* Rename the root widget command and create a new TCL command for
      * this widget
      */
+    tmpArgv[0] = "rename";
+    tmpArgv[1] = widRec;
+    tmpArgv[2] = rootCmd;
 
-    if (TclRenameCommand(interp, widCmd, rootCmd) != TCL_OK) {
+    if (Tcl_RenameCmd((ClientData)0, interp, 3, tmpArgv) != TCL_OK) {
 	code = TCL_ERROR;
 	goto done;
     }
 
     Tcl_CreateCommand(interp, widRec, Tix_InstanceCmd,
-	(ClientData)cPtr, NULL);
+	(ClientData)cPtr, (void (*)()) NULL);
 
     /* Now call the initialization methods defined by the Tix Intrinsics
      */
     if (Tix_CallMethod(interp, cPtr->className, widRec, "InitWidgetRec",
-	    0, 0, NULL) != TCL_OK) {
+	    0, 0) != TCL_OK) {
 	code = TCL_ERROR;
 	goto done;
     }
 
     if (Tix_CallMethod(interp, cPtr->className, widRec, "ConstructWidget",
-	    0, 0, NULL) != TCL_OK) {
+	    0, 0) != TCL_OK) {
 	code = TCL_ERROR;
 	goto done;
     }
 
     if (Tix_CallMethod(interp, cPtr->className, widRec, "SetBindings",
-	    0, 0, NULL) != TCL_OK) {
+		0, 0) != TCL_OK) {
 	code = TCL_ERROR;
 	goto done;
     }
@@ -157,14 +160,14 @@ TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
 	}
     }
 
-    Tcl_SetResult(interp, (char *) widRec, TCL_VOLATILE);
+    Tcl_SetResult(interp, widRec, TCL_VOLATILE);
 
   done:
 
     if (code != TCL_OK) {
 	/* %% TCL CORE USED !! %% */
 	Interp *iPtr = (Interp *) interp;
-	CONST84 char * oldResult, * oldErrorInfo, * oldErrorCode;
+	char * oldResult, * oldErrorInfo, * oldErrorCode;
 	Tk_Window topLevel, tkwin;
 
 	/* We need to save the old error message because
@@ -172,7 +175,7 @@ TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
 	 * calls.
 	 */
 	if (interp->result) {
-	    oldResult = tixStrDup(interp->result);
+	    oldResult = (char*)strdup(interp->result);
 	} else {
 	    oldResult = NULL;
 	}
@@ -185,40 +188,19 @@ TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
 	topLevel = cPtr->mainWindow;
 
 	if (widRec != NULL) {
-	    Display *display = NULL;
-
-	    tkwin = Tk_NameToWindow(interp, widRec, topLevel);
-	    if (tkwin != NULL) {
-		display = Tk_Display(tkwin);
+	    if (tkwin = Tk_NameToWindow(interp, widRec, topLevel)) {
 		Tk_DestroyWindow(tkwin);
 	    }
 
-	    /*
-             * (2) Clean up widget command + root command. Because widCmd
-             *     and rootCmd contains ::, the commands will be correctly
-             *     deleted from the global namespace.
-             */
-
-	    Tcl_DeleteCommand(interp, widCmd);
+	    /* (2) widget command + root command */
+	    Tcl_DeleteCommand(interp, widRec);
 	    Tcl_DeleteCommand(interp, rootCmd);
 
 	    /* (3) widget record */
 	    Tcl_UnsetVar(interp, widRec, TCL_GLOBAL_ONLY);
-
-	    if (display) {
-#if !defined(__WIN32__) && !defined(MAC_TCL) /* UNIX */
-                /* TODO: why is this necessary?? */
-		XSync(display, False);
-#endif
-		while (1) {
-		    if (Tk_DoOneEvent(TK_X_EVENTS|TK_DONT_WAIT) == 0) {
-			break;
-		    }
-		}
-	    }
 	}
 	if (oldResult) {
-	    Tcl_SetResult(interp, (char *) oldResult, TCL_DYNAMIC);
+	    Tcl_SetResult(interp, oldResult, TCL_DYNAMIC);
 	}
 	if (oldErrorInfo && *oldErrorInfo) {
 	    Tcl_SetVar2(interp, "errorInfo", NULL, oldErrorInfo,
@@ -233,13 +215,18 @@ TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
 	}
 	iPtr->flags |= ERR_IN_PROGRESS;
     }
-    if (widCmd) {
-	ckfree(widCmd);
-    }
     if (rootCmd) {
 	ckfree(rootCmd);
     }
 
+#ifdef ITCL_20
+    if (nsToken != NULL) {
+	Itcl_DeactivateNamesp(interp, nsToken);
+    }
+    iPtr->varFramePtr = savedVarFramePtr;
+#endif
+
+
     return code;
 }
 
@@ -252,14 +239,16 @@ TIX_DEFINE_CMD(Tix_CreateWidgetCmd)
 static int ParseOptions(interp, cPtr, widRec, argc, argv)
     Tcl_Interp * interp;
     TixClassRecord * cPtr;
-    CONST84 char *widRec;
+    char *widRec;
     int argc;
-    CONST84 char** argv;
+    char** argv;
 {
     int i;
+    int flag = TCL_GLOBAL_ONLY;
     TixConfigSpec *spec;
     Tk_Window tkwin;
-    CONST84 char * value;
+    char * value;
+    static Tk_Window topLevel = NULL;
 
     if ((argc %2) != 0) {
 	Tcl_AppendResult(interp, "missing argument for \"", argv[argc-1],
@@ -267,12 +256,15 @@ static int ParseOptions(interp, cPtr, widRec, argc, argv)
 	return TCL_ERROR;
     }
 
-    if ((tkwin = Tk_NameToWindow(interp, widRec, cPtr->mainWindow)) == NULL) {
+    if (topLevel == NULL) {
+	topLevel = Tk_MainWindow(interp);
+    }
+
+    if ((tkwin = Tk_NameToWindow(interp, widRec, topLevel)) == NULL) {
 	return TCL_ERROR;
     }
 
     /* Set all specs by their default values */
-    /* BUG: default value may be override by options database */
     for (i=0; i<cPtr->nSpecs; i++) {
 	spec = cPtr->specs[i];
 
