@@ -1,7 +1,3 @@
-# -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
-#
-#	$Id: Balloon.tcl,v 1.6 2004/03/28 02:44:57 hobbs Exp $
-#
 # Balloon.tcl --
 #
 #	The help widget. It provides both "balloon" type of help
@@ -9,9 +5,7 @@
 #	this widget to indicate the function of the widgets inside
 #	your application.
 #
-# Copyright (c) 1993-1999 Ioi Kim Lam.
-# Copyright (c) 2000-2001 Tix Project Group.
-# Copyright (c) 2004 ActiveState
+# Copyright (c) 1996, Expert Interface Technologies
 #
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -25,14 +19,15 @@ tixWidgetClass tixBalloon {
 	bind post unbind
     }
     -flag {
-	-installcolormap -initwait -state -statusbar -cursor
+	-installcolormap -initwait -state -statusbar
     }
     -configspec {
 	{-installcolormap installColormap InstallColormap false}
 	{-initwait initWait InitWait 1000}
 	{-state state State both}
-	{-statusbar statusBar StatusBar ""}
- 	{-cursor cursor Cursor left_ptr}
+	{-statusbar statusBar StatusBar {}}
+
+ 	{-cursor cursor Cursur left_ptr}
     }
     -default {
 	{*background 			#ffff60}
@@ -44,26 +39,24 @@ tixWidgetClass tixBalloon {
 	{*Label.justify			left}
     }
 }
-# static seem to be -installcolormap -initwait -statusbar -cursor
 
 # Class Record
 #
-global tixBalloon
-set tixBalloon(bals) ""
+set tixBalloon(bals) {}
 
-proc tixBalloon:InitWidgetRec {w} {
+proc tixBalloon::InitWidgetRec {w} {
     upvar #0 $w data
     global tixBalloon
 
     tixChainMethod $w InitWidgetRec
 
     set data(isActive)    0
-    set data(client)    ""
+    set data(client)    {}
 
     lappend tixBalloon(bals) $w
 }
 
-proc tixBalloon:ConstructWidget {w} {
+proc tixBalloon::ConstructWidget {w} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructWidget
@@ -74,7 +67,7 @@ proc tixBalloon:ConstructWidget {w} {
     # Frame 1 : arrow
     frame $w.f1 -bd 0
     set data(w:label) [label $w.f1.lab -bd 0 -relief flat \
-			   -bitmap [tix getbitmap balarrow]]
+		       -bitmap [tix getbitmap balarrow]]
     pack $data(w:label) -side left -padx 1 -pady 1
     
     # Frame 2 : Message
@@ -84,36 +77,36 @@ proc tixBalloon:ConstructWidget {w} {
 
     # Pack all
     pack $w.f1 -fill both
-    pack $w.f2 -fill both
+    pack $w.f2 -fill both    
 
     # This is an event tag used by the clients
     #
-    bind TixBal$w <Destroy> [list tixBalloon:ClientDestroy $w %W]
+    bind TixBal$w <Destroy> "tixBalloon::ClientDestroy $w %W"
 }
 
-proc tixBalloon:Destructor {w} {
+proc tixBalloon::Destructor {w} {
     global tixBalloon
 
-    set bals ""
+    set bals {}
     foreach b $tixBalloon(bals) {
 	if {$w != $b} {
 	    lappend bals $b
 	}
     }
     set tixBalloon(bals) $bals
-
-    tixChainMethod $w Destructor
 }
 
 #----------------------------------------------------------------------
 # Config:
 #----------------------------------------------------------------------
-proc tixBalloon:config-state {w value} {
+proc tixBalloon::config-state {w value} {
     upvar #0 $w data
 
-    set re {^(none|balloon|status|both)$}
-    if {![regexp -- $re $value]} {
-	error "invalid value $value, must be none, balloon, status, or both"
+    case $value {
+	{none balloon status both} {}
+	default {
+	   error "invalid value $value, must be none, balloon, status, or both"
+	}
     }
 }
 
@@ -121,61 +114,64 @@ proc tixBalloon:config-state {w value} {
 # "RAW" event bindings:
 #----------------------------------------------------------------------
 
-bind all <B1-Motion> 	    "+tixBalloon_XXMotion %X %Y 1"
-bind all <B2-Motion> 	    "+tixBalloon_XXMotion %X %Y 2"
-bind all <B3-Motion> 	    "+tixBalloon_XXMotion %X %Y 3"
-bind all <B4-Motion> 	    "+tixBalloon_XXMotion %X %Y 4"
-bind all <B5-Motion> 	    "+tixBalloon_XXMotion %X %Y 5"
-bind all <Any-Motion> 	    "+tixBalloon_XXMotion %X %Y 0"
-# Should %b be 0? %b is illegal
-bind all <Leave>      	    "+tixBalloon_XXMotion %X %Y 0"
-bind all <Button>      	    "+tixBalloon_XXButton   %X %Y %b"
-bind all <ButtonRelease>    "+tixBalloon_XXButtonUp %X %Y %b"
+bind all <B1-Motion> 	    "+tixBalloon:XXMotion %X %Y 1"
+bind all <B2-Motion> 	    "+tixBalloon:XXMotion %X %Y 2"
+bind all <B3-Motion> 	    "+tixBalloon:XXMotion %X %Y 3"
+bind all <B4-Motion> 	    "+tixBalloon:XXMotion %X %Y 4"
+bind all <B5-Motion> 	    "+tixBalloon:XXMotion %X %Y 5"
+bind all <Any-Motion> 	    "+tixBalloon:XXMotion %X %Y 0"
+bind all <Leave>      	    "+tixBalloon:XXMotion %X %Y %b"
+bind all <Button>      	    "+tixBalloon:XXButton   %X %Y %b"
+bind all <ButtonRelease>    "+tixBalloon:XXButtonUp %X %Y %b"
 
-proc tixBalloon_XXMotion {rootX rootY b} {
+proc tixBalloon:XXMotion {rootX rootY b} {
     global tixBalloon
 
     foreach w $tixBalloon(bals) {
-	tixBalloon:XXMotion $w $rootX $rootY $b
+	tixBalloon::XXMotion $w $rootX $rootY $b
     }
 }
 
-proc tixBalloon_XXButton {rootX rootY b} {
+proc tixBalloon:XXButton {rootX rootY b} {
     global tixBalloon
 
     foreach w $tixBalloon(bals) {
-	tixBalloon:XXButton $w $rootX $rootY $b
+	tixBalloon::XXButton $w $rootX $rootY $b
     }
 }
 
-proc tixBalloon_XXButtonUp {rootX rootY b} {
+proc tixBalloon:XXButtonUp {rootX rootY b} {
     global tixBalloon
 
     foreach w $tixBalloon(bals) {
-	tixBalloon:XXButtonUp $w $rootX $rootY $b
+	tixBalloon::XXButtonUp $w $rootX $rootY $b
     }
 }
 
+
 # return true if d is a descendant of w
 #
 proc tixIsDescendant {w d} {
-    return [expr {$w eq "." || [string match $w.* $d]}]
+    if [string match $w .] {
+	return 1
+    }
+    return [string match $w.* $d]
 }
 
 # All the button events are fine if the ballooned widget is
 # a descendant of the grabbing widget
 #
-proc tixBalloon:GrabBad {w cw} {
+proc tixBalloon::GrabBad {w cw} {
     global tixBalloon
 
     set g [grab current $w]
-    if {$g == ""} {
+    if {$g == {}} {
 	return 0
     }
-    if {[info exists tixBalloon(g_ignore,$g)]} {
+    if [info exists tixBalloon(g_ignore,$g)] {
 	return 1
     }
-    if {[info exists tixBalloon(g_ignore,[winfo class $g])]} {
+    if [info exists tixBalloon(g_ignore,[winfo class $g])] {
 	return 1
     }
     if {$g == $cw || [tixIsDescendant $g $cw]} {
@@ -184,46 +180,42 @@ proc tixBalloon:GrabBad {w cw} {
     return 1
 }
 
-proc tixBalloon:XXMotion {w rootX rootY b} {
+proc tixBalloon::XXMotion {w rootX rootY b} {
     upvar #0 $w data
 
-    if {![info exists data(-state)]} {
-	# puts "tixBalloon:XXMotion called without a state\n$w"
-	set data(state) none
-	return
-    }
-    if {$data(-state) eq "none"} {
+    if {$data(-state) == "none"} {
 	return
     }
 
     if {$b == 0} {
-	if {[info exists data(b:1)]} {unset data(b:1)}
-	if {[info exists data(b:2)]} {unset data(b:2)}
-	if {[info exists data(b:3)]} {unset data(b:3)}
-	if {[info exists data(b:4)]} {unset data(b:4)}
-	if {[info exists data(b:5)]} {unset data(b:5)}
+	catch {unset data(b:1)}
+	catch {unset data(b:2)}
+	catch {unset data(b:3)}
+	catch {unset data(b:4)}
+	catch {unset data(b:5)}
     }
 
-    if {[llength [array names data b:*]]} {
+
+    if {[array names data b:*] != {}} {
 	# Some buttons are down. Do nothing
 	#
 	return
     }
 
-    set cw [winfo containing -displayof $w $rootX $rootY]
-    if {[tixBalloon:GrabBad $w $cw]} {
+    set cw [winfo containing $rootX $rootY]
+    if [tixBalloon::GrabBad $w $cw] {
 	return
     }
 
     # Find the a client window that matches
     #
-    if {$w eq $cw || [string match $w.* $cw]} {
+    if {$w == $cw || [string match $w.* $cw]} {
 	# Cursor moved over the balloon -- Ignore
 	return
     }
 
-    while {$cw != ""} {
-	if {[info exists data(m:$cw)]} {
+    while {$cw != {}} {
+	if [info exists data(m:$cw)] {
 	    set client $cw
 	    break
 	} else {
@@ -234,43 +226,43 @@ proc tixBalloon:XXMotion {w rootX rootY b} {
 	# The cursor is at a position covered by a non-client
 	# Popdown the balloon if it is up
 	if {$data(isActive)} {
-	    tixBalloon:Deactivate $w
+	    tixBalloon::Deactivate $w
 	}
-	set data(client) ""
-	if {[info exists data(cancel)]} {
+	set data(client) {}
+	catch {
 	    unset data(cancel) 
 	}
 	return
     }
 
-    if {$data(client) ne $client} {
+    if {$data(client) != $client} {
 	if {$data(isActive)} {
-	    tixBalloon:Deactivate $w
+	    tixBalloon::Deactivate $w
 	}
 	set data(client) $client
-	after $data(-initwait) tixBalloon:SwitchToClient $w $client
+	after $data(-initwait) tixBalloon::SwitchToClient $w $client
     }
 }
 
-proc tixBalloon:XXButton {w rootX rootY b} {
+proc tixBalloon::XXButton {w rootX rootY b} {
     upvar #0 $w data
 
-    tixBalloon:XXMotion $w $rootX $rootY $b
+    tixBalloon::XXMotion $w $rootX $rootY $b
 
     set data(b:$b) 1
 
     if {$data(isActive)} {
-	tixBalloon:Deactivate $w
+	tixBalloon::Deactivate $w
     } else {
 	set data(cancel) 1
     }
 }
 
-proc tixBalloon:XXButtonUp {w rootX rootY b} {
+proc tixBalloon::XXButtonUp {w rootX rootY b} {
     upvar #0 $w data
 
-    tixBalloon:XXMotion $w $rootX $rootY $b
-    if {[info exists data(b:$b)]} {
+    tixBalloon::XXMotion $w $rootX $rootY $b
+    catch {
 	unset data(b:$b)
     }
 }
@@ -281,7 +273,7 @@ proc tixBalloon:XXButtonUp {w rootX rootY b} {
 
 # switch the balloon to a new client
 #
-proc tixBalloon:SwitchToClient {w client} {
+proc tixBalloon::SwitchToClient {w client} {
     upvar #0 $w data
 
     if {![winfo exists $w]} {
@@ -290,84 +282,76 @@ proc tixBalloon:SwitchToClient {w client} {
     if {![winfo exists $client]} {
 	return
     }
-    if {$client ne $data(client)} {
+    if {$client != $data(client)} {
 	return
     }
-    if {[info exists data(cancel)]} {
-	unset data(cancel)
+    if [info exists data(cancel)] {
+	catch {
+	    unset data(cancel)
+	}
 	return
     }
 
-    if {[tixBalloon:GrabBad $w $w]} {
+    if [tixBalloon::GrabBad $w $w] {
 	return
     }
 
-    tixBalloon:Activate $w
+    tixBalloon::Activate $w
 }
 
-proc tixBalloon:ClientDestroy {w client} {
+proc tixBalloon::ClientDestroy {w client} {
     if {![winfo exists $w]} {
 	return
     }
 
     upvar #0 $w data
 
-    if {$data(client) eq $client} {
-	tixBalloon:Deactivate $w
-	set data(client) ""
+    if {$data(client) == $client} {
+	tixBalloon::Deactivate $w
+	set data(client) {}
     }
 
     # Maybe thses have already been unset by the Destroy method
     #
-    if {[info exists data(m:$client)]} {unset data(m:$client)}
-    if {[info exists data(s:$client)]} {unset data(s:$client)}
+    catch {unset data(m:$client)}
+    catch {unset data(s:$client)}
 }
 
 #----------------------------------------------------------------------
 # Popping up balloon:
 #----------------------------------------------------------------------
-proc tixBalloon:Activate {w} {
+proc tixBalloon::Activate {w} {
     upvar #0 $w data
 
-    if {[tixBalloon:GrabBad $w $w]} {
+    if [tixBalloon::GrabBad $w $w] {
 	return
     }
-    if {[winfo containing -displayof $w \
-	    [winfo pointerx $w] [winfo pointery $w]] == ""} {
+    if {[winfo containing [winfo pointerx $w] [winfo pointery $w]] == {}} {
 	return
     }
 
-    if {![info exists data(-state)]} {
-	# puts "tixBalloon:Activate called without a state\n$w"
-	set data(state) none
-	return
-    }
-    if {$data(-state) eq "none"} {
-	return
-    }
-
-    switch -exact -- $data(-state) {
+    switch $data(-state) {
 	"both" {
-	    tixBalloon:PopUp $w
-	    tixBalloon:SetStatus $w
+	    tixBalloon::PopUp $w
+	    tixBalloon::SetStatus $w
 	}
 	"balloon" {
-	    tixBalloon:PopUp $w
+	    tixBalloon::PopUp $w
 	}
 	"status" {
-	    tixBalloon:SetStatus $w
+	    tixBalloon::SetStatus $w
 	}
     }
 
     set data(isActive) 1
 
-    after 200 tixBalloon:Verify $w
+    after 200 tixBalloon::Verify $w
 }
 
 
 # %% Perhaps this is no more needed
 #
-proc tixBalloon:Verify {w} {
+proc tixBalloon::Verify {w} {
     upvar #0 $w data
 
     if {![winfo exists $w]} {
@@ -377,33 +361,32 @@ proc tixBalloon:Verify {w} {
 	return
     }
 
-    if {[tixBalloon:GrabBad $w $w]} {
-	tixBalloon:Deactivate $w
+    if [tixBalloon::GrabBad $w $w] {
+	tixBalloon::Deactivate $w
 	return
     }
-    if {[winfo containing -displayof $w \
-	    [winfo pointerx $w] [winfo pointery $w]] == ""} {
-	tixBalloon:Deactivate $w
+    if {[winfo containing [winfo pointerx $w] [winfo pointery $w]] == {}} {
+	tixBalloon::Deactivate $w
 	return
     }
-    after 200 tixBalloon:Verify $w
+    after 200 tixBalloon::Verify $w
 }
 
-proc tixBalloon:Deactivate {w} {
+proc tixBalloon::Deactivate {w} {
     upvar #0 $w data
 
-    tixBalloon:PopDown $w
-    tixBalloon:ClearStatus $w
+    tixBalloon::PopDown $w
+    tixBalloon::ClearStatus $w
     set data(isActive) 0
-    if {[info exists data(cancel)]} {
+    catch {
 	unset data(cancel)
     }
 }
 
-proc tixBalloon:PopUp {w} {
+proc tixBalloon::PopUp {w} {
     upvar #0 $w data
 
-    if {[string is true -strict $data(-installcolormap)]} {
+    if [tixGetBoolean -nocomplain $data(-installcolormap)] {
 	wm colormapwindows [winfo toplevel $data(client)] $w
     }
 
@@ -412,8 +395,6 @@ proc tixBalloon:PopUp {w} {
     # put on the visible screen
     #
     set client $data(client)
-    if {$data(m:$client) == ""} {return ""}
-
     $data(w:message) config -text $data(m:$client)
     wm geometry $w +10000+10000
     wm deiconify $w
@@ -430,40 +411,13 @@ proc tixBalloon:PopUp {w} {
     }
     # Put it on the visible screen
     #
-    set x [expr {[winfo rootx $client]+[winfo width  $client]/2}]
-    set y [expr {int([winfo rooty $client]+[winfo height $client]/1.3)}]
-
-    set width  [winfo reqwidth $w]
-    set height [winfo reqheight $w]
-    set scrwidth  [winfo vrootwidth  $w]
-    set scrheight [winfo vrootheight $w]
-
-    # If the balloon is too far right, pull it back to the left
-    #
-    if {($x + $width) > $scrwidth} {
-	set x [expr {$scrwidth - $width}]
-    }
-
-    # If the balloon is too far left, pull it back to the right
-    #
-    if {$x < 0} {
-	set x 0
-    }
-
-    # If the listbox is below bottom of screen, put it upwards
-    #
-    if {($y + $height) > $scrheight} {
-	set y [expr {$scrheight-$height}]
-    }
-    if {$y < 0} {
-	set y 0
-    }
+    set x [expr [winfo rootx $client]+[winfo width  $client]/2]
+    set y [expr int([winfo rooty $client]+[winfo height $client]/1.3)]
 
     wm geometry $w +$x+$y
-    after idle raise $w
 }
 
-proc tixBalloon:PopDown {w} {
+proc tixBalloon::PopDown {w} {
     upvar #0 $w data
 
     # Close the balloon
@@ -472,14 +426,16 @@ proc tixBalloon:PopDown {w} {
 
     # We don't set the data(client) to be zero, so that the balloon
     # will re-appear only if you move out then in the client window
-    # set data(client) ""
+    # set data(client) {}
 }
 
-proc tixBalloon:SetStatus {w} {
+proc tixBalloon::SetStatus {w} {
     upvar #0 $w data
 
-    if {![winfo exists $data(-statusbar)]
-	|| ![info exists data(s:$data(client))]} {
+    if {![winfo exists $data(-statusbar)]} {
+	return
+    }
+    if {![info exists data(s:$data(client))]} {
 	return
     }
 
@@ -491,7 +447,7 @@ proc tixBalloon:SetStatus {w} {
     }
 }
 
-proc tixBalloon:ClearStatus {w} {
+proc tixBalloon::ClearStatus {w} {
     upvar #0 $w data
 
     if {![winfo exists $data(-statusbar)]} {
@@ -514,23 +470,27 @@ proc tixBalloon:ClearStatus {w} {
 
 # %% if balloon is already popped-up for this client, change mesage
 #
-proc tixBalloon:bind {w client args} {
+proc tixBalloon::bind {w client args} {
     upvar #0 $w data
 
-    set alreadyBound [info exists data(m:$client)]
+    if [info exists data(m:$client)] {
+	set alreadyBound 1
+    } else {
+	set alreadyBound 0
+    }
 
-    set opt(-balloonmsg) ""
-    set opt(-statusmsg)  ""
-    set opt(-msg)        ""
+    set opt(-balloonmsg) {}
+    set opt(-statusmsg)  {}
+    set opt(-msg)        {}
 
     tixHandleOptions opt {-balloonmsg -msg -statusmsg} $args
 
-    if {$opt(-balloonmsg) != ""} {
+    if {$opt(-balloonmsg) != {}} {
 	set data(m:$client) $opt(-balloonmsg)
     } else {
 	set data(m:$client) $opt(-msg)
     }
-    if {$opt(-statusmsg) != ""} {
+    if {$opt(-statusmsg) != {}} {
 	set data(s:$client) $opt(-statusmsg)
     } else {
 	set data(s:$client) $opt(-msg)
@@ -539,24 +499,24 @@ proc tixBalloon:bind {w client args} {
     tixAppendBindTag $client TixBal$w
 }
 
-proc tixBalloon:post {w client} {
+proc tixBalloon::post {w client} {
     upvar #0 $w data
 
-    if {![info exists data(m:$client)] || $data(m:$client) == ""} {
+    if {![info exists data(m:$client)]} {
 	return
     }
-    tixBalloon:Enter $w $client
+    tixBalloon::Enter $w $client
     incr data(fakeEnter)
 }
 
-proc tixBalloon:unbind {w client} {
+proc tixBalloon::unbind {w client} {
     upvar #0 $w data
 
-    if {[info exists data(m:$client)]} {
-	if {[info exists data(m:$client)]} {unset data(m:$client)}
-	if {[info exists data(s:$client)]} {unset data(s:$client)}
+    if [info exists data(m:$client)] {
+	catch {unset data(m:$client)}
+	catch {unset data(s:$client)}
 
-	if {[winfo exists $client]} {
+	if [winfo exists $client] {
 	    catch {tixDeleteBindTag $client TixBal$w}
 	}
     }
@@ -571,7 +531,7 @@ proc tixBalloon:unbind {w client} {
 # $w can be a widget name or a classs name
 proc tixBalIgnoreWhenGrabbed {wc} {
     global tixBalloon
-    set tixBalloon(g_ignore,$wc) ""
+    set tixBalloon(g_ignore,$wc) {}
 }
 
 tixBalIgnoreWhenGrabbed TixComboBox
