@@ -1,7 +1,3 @@
-# -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
-#
-#	$Id: DirTree.tcl,v 1.2.2.2 2002/01/24 10:08:58 idiscovery Exp $
-#
 # DirTree.tcl --
 #
 #	Implements directory tree for Unix file systems
@@ -14,8 +10,7 @@
 #
 #      none: The dir has no subdirectori(es).
 #
-# Copyright (c) 1993-1999 Ioi Kim Lam.
-# Copyright (c) 2000-2001 Tix Project Group.
+# Copyright (c) 1996, Expert Interface Technologies
 #
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -31,18 +26,22 @@ tixWidgetClass tixDirTree {
 	-browsecmd -command -directory -disablecallback -showhidden -value
     }
     -configspec {
-	{-browsecmd browseCmd BrowseCmd ""}
-	{-command command Command ""}
+	{-browsecmd browseCmd BrowseCmd {}}
+	{-command command Command {}}
+	{-directory directory Directory {}}
 	{-disablecallback disableCallback DisableCallback 0 tixVerifyBoolean}
 	{-showhidden showHidden ShowHidden 0 tixVerifyBoolean}
-	{-value value Value ""}
     }
     -alias {
-	{-directory -value}
+	{-value	-directory}
     }
     -default {
 	{.scrollbar			auto}
+	{*Scrollbar.background          #d9d9d9}
+	{*Scrollbar.relief              sunken}
 	{*Scrollbar.takeFocus           0}
+	{*Scrollbar.troughColor         #c3c3c3}
+	{*Scrollbar.width               15}
 	{*borderWidth                   1}
 	{*hlist.indicator               1}
 	{*hlist.background              #c3c3c3}
@@ -60,55 +59,47 @@ tixWidgetClass tixDirTree {
     }
 }
 
-proc tixDirTree:InitWidgetRec {w} {
+proc tixDirTree::InitWidgetRec {w} {
     upvar #0 $w data
 
     tixChainMethod $w InitWidgetRec
 
-    if {$data(-value) == ""} {
+    if {$data(-directory) == {}} {
 	global env
 	if {[info exists env(PWD)]} {
-	    set data(-value) $env(PWD)
+	    set data(-directory) $env(PWD)
 	} else {
-	    set data(-value) [pwd]
+	    set data(-directory) [pwd]
 	}
     }
 
-    tixDirTree:SetDir $w [tixFileIntName $data(-value)]
+    tixDirTree::SetDir $w [tixFileIntName $data(-directory)]
 }
 
-proc tixDirTree:ConstructWidget {w} {
+proc tixDirTree::ConstructWidget {w} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructWidget
-    tixDoWhenMapped $w "tixDirTree:StartUp $w"
+    tixDoWhenMapped $w "tixDirTree::StartUp $w"
 
     $data(w:hlist) config \
 	-separator [tixDirSep] \
 	-selectmode "single" -drawbranch 1
-
-    # We must creat an extra copy of these images to avoid flashes on
-    # the screen when user changes directory
-    #
-    set data(images) [image create compound -window $data(w:hlist)]
-    $data(images) add image -image [tix getimage act_fold]
-    $data(images) add image -image [tix getimage folder]
-    $data(images) add image -image [tix getimage openfold]
 }
 
-proc tixDirTree:SetBindings {w} {
+proc tixDirTree::SetBindings {w} {
     upvar #0 $w data
 
     tixChainMethod $w SetBindings
 
 # %% do I still need this?
-#   bind $data(w:hlist) <3> "tixDirTree:DeleteSib $w %x %y"
+#   bind $data(w:hlist) <3> "tixDirTree::DeleteSib $w %x %y"
 }
 
 # This procedure is supposed to "trim" the directory tree view to
 # just the current directory and its ancestors.
 #
-#proc tixDirTree:DeleteSib {w x y} {
+#proc tixDirTree::DeleteSib {w x y} {
 #    upvar #0 $w data
 #
 #    set ent [$data(w:hlist) nearest $y]
@@ -119,17 +110,17 @@ proc tixDirTree:SetBindings {w} {
 #	for {set e $ent} {$e != "/"} {set e [$data(w:hlist) info parent $e]} {
 #	    $data(w:hlist) delete siblings $e
 #	}
-#	tixDirTree:Browse $w $ent
+#	tixDirTree::Browse $w $ent
 #    }
 #}
 
 # %% This functions needs to be optimized
 #
 #
-proc tixDirTree:HasSubDir {w dir} {
+proc tixDirTree::HasSubDir {w dir} {
     upvar #0 $w data
 
-    if {[tixListDir $dir 1 0 0 $data(-showhidden)] != ""} {
+    if {[tixListDir $dir 1 0 0 $data(-showhidden)] != {}} {
 	return 1
     } else {
 	return 0
@@ -139,7 +130,7 @@ proc tixDirTree:HasSubDir {w dir} {
 
 # Add one dir into the parent directory, sorted alphabetically
 #
-proc tixDirTree:AddToList {w dir parent name image} {
+proc tixDirTree::AddToList {w dir parent name image} {
     upvar #0 $w data
 
     set added 0
@@ -150,27 +141,28 @@ proc tixDirTree:AddToList {w dir parent name image} {
 	    break
 	}
     }
-    if {!$added} {
+    if !$added {
 	$data(w:hlist) add $dir -text $name -image $image
     }
 
-    if {[tixDirTree:HasSubDir $w $dir]} {
-	tixVTree:SetMode $w $dir open
+    if [tixDirTree::HasSubDir $w $dir] {
+	tixVTree::SetMode $w $dir open
     }
 }
 
 # Add $dir and all ancestors of $dir into the HList widget
 #
 #
-proc tixDirTree:AddAncestors {w dir} {
+proc tixDirList::AddAncestors {w dir} {
     upvar #0 $w data
+    uplevel #0 set TRANSPARENT_GIF_COLOR [$data(w:hlist) cget -bg]
 
-    set path ""
-    set parent ""
+    set path {}
+    set parent {}
     foreach name [tixFileSplit $dir] {
 	set path [tixSubFolder $path $name]
 	if {![$data(w:hlist) info exists $path]} {
-	    tixDirTree:AddToList $w $path $parent [tixFileDisplayName $path] \
+	    tixDirTree::AddToList $w $path $parent [tixFileDisplayName $path] \
 		[tix getimage openfold]
 	}
 	set parent $path
@@ -180,7 +172,7 @@ proc tixDirTree:AddAncestors {w dir} {
 # Add all the sub directories of $dir into the HList widget
 #
 #
-proc tixDirTree:ListDirs {w dir} {
+proc tixDirTree::ListDirs {w dir} {
     upvar #0 $w data
     uplevel #0 set TRANSPARENT_GIF_COLOR [$data(w:hlist) cget -bg]
 
@@ -189,7 +181,7 @@ proc tixDirTree:ListDirs {w dir} {
     foreach name [tixListDir $dir 1 0 0 $data(-showhidden)] {
 	set subdir [tixSubFolder $dir $name]
 	if {![$data(w:hlist) info exists $subdir]} {
-	    tixDirTree:AddToList $w $subdir $dir [tixFileDisplayName $subdir] \
+	    tixDirTree::AddToList $w $subdir $dir [tixFileDisplayName $subdir] \
 		[tix getimage folder]
 	}
     }
@@ -197,7 +189,7 @@ proc tixDirTree:ListDirs {w dir} {
     tixWidgetDoWhenIdle tixBusy $w off $data(w:hlist)
 }
 
-proc tixDirTree:LoadDir {w dir {mode toggle}} {
+proc tixDirTree::LoadDir {w dir {mode toggle}} {
     if {![winfo exists $w]} {
 	return
     }
@@ -207,13 +199,13 @@ proc tixDirTree:LoadDir {w dir {mode toggle}} {
 
     # Add the directory and set it to the active directory
     #
-    if {![$data(w:hlist) info exists $dir]} {
-	tixDirTree:AddAncestors $w $dir
+    if ![$data(w:hlist) info exists $dir] {
+	tixDirList::AddAncestors $w $dir
     }
     $data(w:hlist) entryconfig $dir -image [tix getimage act_fold]
 
     if {$mode == "toggle"} {
-	if {[$data(w:hlist) info children $dir] == ""} {
+	if {[$data(w:hlist) info children $dir] == {}} {
 	    set mode expand
 	} else {
 	    set mode flatten
@@ -221,58 +213,58 @@ proc tixDirTree:LoadDir {w dir {mode toggle}} {
     }
 
     if {$mode == "expand"} {
-	tixDirTree:ListDirs $w $dir
-	if {[$data(w:hlist) info children $dir] == ""} {
-	    tixVTree:SetMode $w $dir none
+	tixDirTree::ListDirs $w $dir
+	if {[$data(w:hlist) info children $dir] == {}} {
+	    tixVTree::SetMode $w $dir none
 	} else {
-	    tixVTree:SetMode $w $dir close
+	    tixVTree::SetMode $w $dir close
 	}
     } else {
 	$data(w:hlist) delete offsprings $dir
-	tixVTree:SetMode $w $dir open
+	tixVTree::SetMode $w $dir open
     }
 }
 
-proc tixDirTree:ToggleDir {w value mode} {
+proc tixDirTree::ToggleDir {w value mode} {
     upvar #0 $w data
 
-    tixDirTree:LoadDir $w $value $mode
-    tixDirTree:CallCommand $w
+    tixDirTree::LoadDir $w $value $mode
+    tixDirTree::CallCommand $w
 }
 
-proc tixDirTree:CallCommand {w} {
+proc tixDirTree::CallCommand {w} {
     upvar #0 $w data
 
-    if {$data(-command) != "" && !$data(-disablecallback)} {
+    if {$data(-command) != {} && !$data(-disablecallback)} {
 	set bind(specs) {%V}
-	set bind(%V)    $data(-value)
+	set bind(%V)    $data(-directory)
 
-	tixEvalCmdBinding $w $data(-command) bind $data(-value)
+	tixEvalCmdBinding $w $data(-command) bind $data(-directory)
     }
 }
 
-proc tixDirTree:CallBrowseCmd {w ent} {
+proc tixDirTree::CallBrowseCmd {w ent} {
     upvar #0 $w data
 
-    if {$data(-browsecmd) != "" && !$data(-disablecallback)} {
+    if {$data(-browsecmd) != {} && !$data(-disablecallback)} {
 	set bind(specs) {%V}
-	set bind(%V)    $data(-value)
+	set bind(%V)    $data(-directory)
 
-	tixEvalCmdBinding $w $data(-browsecmd) bind [list $data(-value)]
+	tixEvalCmdBinding $w $data(-browsecmd) bind [list $data(-directory)]
     }
 }
 
-proc tixDirTree:StartUp {w} {
+proc tixDirTree::StartUp {w} {
     if {![winfo exists $w]} {
 	return
     }
 
     upvar #0 $w data
 
-    tixDirTree:LoadDir $w $data(i-directory)
+    tixDirTree::LoadDir $w $data(i-directory)
 }
 
-proc tixDirTree:ChangeDir {w value {forced 0}} {
+proc tixDirTree::ChangeDir {w value {forced 0}} {
     upvar #0 $w data
 
     if {!$forced && $data(i-directory) == $value} {
@@ -283,7 +275,7 @@ proc tixDirTree:ChangeDir {w value {forced 0}} {
     if {!$forced && [$data(w:hlist) info exists $value]} {
 	# Set the old directory to "non active"
 	#
-	if {[$data(w:hlist) info exists $data(i-directory)]} {
+	if [$data(w:hlist) info exists $data(i-directory)] {
 	    $data(w:hlist) entryconfig $data(i-directory) \
 		-image [tix getimage folder]
 	}
@@ -293,7 +285,7 @@ proc tixDirTree:ChangeDir {w value {forced 0}} {
 
     } else {
 	if {$forced} {
-	    if {[$data(w:hlist) info children $value] == ""} {
+	    if {[$data(w:hlist) info children $value] == {}} {
 		set mode flatten
 	    } else {
 		set mode expand
@@ -301,18 +293,18 @@ proc tixDirTree:ChangeDir {w value {forced 0}} {
 	} else {
 	    set mode toggle
 	}
-	tixDirTree:LoadDir $w $value $mode
-	tixDirTree:CallCommand $w
+	tixDirTree::LoadDir $w $value $mode
+	tixDirTree::CallCommand $w
     }
-    tixDirTree:SetDir $w $value
+    tixDirTree::SetDir $w $value
 }
 
 
-proc tixDirTree:SetDir {w intName} {
+proc tixDirTree::SetDir {w intName} {
     upvar #0 $w data
 
     set data(i-directory) $intName
-    set data(-value)  [tixNativeName $intName]
+    set data(-directory)  [tixNativeName $intName]
 }
 
 #----------------------------------------------------------------------
@@ -320,42 +312,42 @@ proc tixDirTree:SetDir {w intName} {
 # Virtual Methods
 #
 #----------------------------------------------------------------------
-proc tixDirTree:OpenCmd {w ent} {
-    tixDirTree:ToggleDir $w $ent expand
-    tixDirTree:ChangeDir $w $ent
-    tixDirTree:CallBrowseCmd $w $ent
+proc tixDirTree::OpenCmd {w ent} {
+    tixDirTree::ToggleDir $w $ent expand
+    tixDirTree::ChangeDir $w $ent
+    tixDirTree::CallBrowseCmd $w $ent
 }
 
-proc tixDirTree:CloseCmd {w ent} {
-    tixDirTree:ToggleDir $w $ent flatten
-    tixDirTree:ChangeDir $w $ent
-    tixDirTree:CallBrowseCmd $w $ent
+proc tixDirTree::CloseCmd {w ent} {
+    tixDirTree::ToggleDir $w $ent flatten
+    tixDirTree::ChangeDir $w $ent
+    tixDirTree::CallBrowseCmd $w $ent
 }
 
-proc tixDirTree:Command {w B} {
+proc tixDirTree::Command {w B} {
     upvar #0 $w data
     upvar $B bind
 
     set ent [tixEvent flag V]
     tixChainMethod $w Command $B
 
-    if {$data(-command) != ""} {
+    if {$data(-command) != {}} {
 	tixEvalCmdBinding $w $data(-command) bind $ent
     }
 }
 
 # This is a virtual method
 #
-proc tixDirTree:BrowseCmd {w B} {
+proc tixDirTree::BrowseCmd {w B} {
     upvar #0 $w data
     upvar $B bind
     
     set ent [tixEvent flag V]
 
 #    if {[$data(w:hlist) indicator exist $ent] && 
-#	[$data(w:hlist) info children $ent] == ""} {
+#	[$data(w:hlist) info children $ent] == {}} {
 #	
-#	tixVTree:Activate $w $ent open
+#	tixVTree::Activate $w $ent open
 #   }
 
     if {[string index $ent 0] != "/"} {
@@ -363,8 +355,8 @@ proc tixDirTree:BrowseCmd {w B} {
 	# callbrowsecmd ....
         set ent [tixFileIntName $ent]
     } 
-    tixDirTree:ChangeDir $w $ent
-    tixDirTree:CallBrowseCmd $w $ent
+    tixDirTree::ChangeDir $w $ent
+    tixDirTree::CallBrowseCmd $w $ent
 }
 
 #----------------------------------------------------------------------
@@ -372,18 +364,18 @@ proc tixDirTree:BrowseCmd {w B} {
 # Public Methods
 #
 #----------------------------------------------------------------------
-proc tixDirTree:chdir {w value} {
-    tixDirTree:ChangeDir $w [tixFileIntName $value]
+proc tixDirTree::chdir {w value} {
+    tixDirTree::ChangeDir $w [tixFileIntName $value]
 }
 
-proc tixDirTree:refresh {w {dir ""}} {
+proc tixDirTree::refresh {w {dir {}}} {
     upvar #0 $w data
 
-    if {$dir == ""} {
-	set dir $data(-value)
+    if {$dir == {}} {
+	set dir $data(-directory)
     }
 
-    tixDirTree:ChangeDir $w [tixFileIntName $dir] 1
+    tixDirTree::ChangeDir $w [tixFileIntName $dir] 1
 
 
     # Delete any stale directories that no longer exist
@@ -395,6 +387,6 @@ proc tixDirTree:refresh {w {dir ""}} {
     }
 }
 
-proc tixDirTree:config-directory {w value} {
-    tixDirTree:ChangeDir $w [tixFileIntName $value]
+proc tixDirTree::config-directory {w value} {
+    tixDirTree::ChangeDir $w [tixFileIntName $value]
 }
