@@ -1,13 +1,8 @@
-# -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
-#
-#	$Id: FileBox.tcl,v 1.3.2.2 2002/01/24 10:08:58 idiscovery Exp $
-#
 # FileBox.tcl --
 #
 #	Implements the File Selection Box widget.
 #
-# Copyright (c) 1993-1999 Ioi Kim Lam.
-# Copyright (c) 2000-2001 Tix Project Group.
+# Copyright (c) 1996, Expert Interface Technologies
 #
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -29,13 +24,13 @@ tixWidgetClass tixFileSelectBox {
 	-grab -pattern -selection -value
     }
     -configspec {
-	{-browsecmd browseCmd BrowseCmd ""}
-	{-command command Command ""}
-	{-directory directory Directory ""}
+	{-browsecmd browseCmd BrowseCmd {}}
+	{-command command Command {}}
+	{-directory directory Directory {}}
 	{-disablecallback disableCallback DisableCallback 0 tixVerifyBoolean}
 	{-grab grab Grab global}
 	{-pattern pattern Pattern *}
-	{-value value Value ""}
+	{-value value Value {}}
     }
     -alias {
 	{-selection -value}
@@ -50,6 +45,7 @@ tixWidgetClass tixFileSelectBox {
 	{.borderWidth 			1}
 	{*Label.anchor			w}
 	{*Label.borderWidth		0}
+	{*Label.font                   -Adobe-Helvetica-Bold-R-Normal--*-120-*}
 	{*TixComboBox*scrollbar		auto}
 	{*TixComboBox*Label.anchor	w}
 	{*TixScrolledListBox.scrollbar	auto}
@@ -68,21 +64,21 @@ tixWidgetClass tixFileSelectBox {
 }
 
 
-proc tixFileSelectBox:InitWidgetRec {w} {
+proc tixFileSelectBox::InitWidgetRec {w} {
     upvar #0 $w data
     global env
 
     tixChainMethod $w InitWidgetRec
 
-    if {$data(-directory) == ""} {
+    if {$data(-directory) == {}} {
 	set data(-directory) [pwd]
     }
-    if {$data(-pattern) == ""} {
+    if {$data(-pattern) == {}} {
 	set data(-pattern) [tixFilePattern allFiles]
     }
 
-    tixFileSelectBox:SetPat $w [tixFileIntName $data(-pattern)]
-    tixFileSelectBox:SetDir $w [tixFileIntName $data(-directory)]
+    tixFileSelectBox::SetPat $w [tixFileIntName $data(-pattern)]
+    tixFileSelectBox::SetDir $w [tixFileIntName $data(-directory)]
 
     set data(flag)      0
     set data(fakeDir)   0
@@ -91,26 +87,26 @@ proc tixFileSelectBox:InitWidgetRec {w} {
 #----------------------------------------------------------------------
 #		Construct widget
 #----------------------------------------------------------------------
-proc tixFileSelectBox:ConstructWidget {w} {
+proc tixFileSelectBox::ConstructWidget {w} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructWidget
 
-    set frame1 [tixFileSelectBox:CreateFrame1 $w]
-    set frame2 [tixFileSelectBox:CreateFrame2 $w]
-    set frame3 [tixFileSelectBox:CreateFrame3 $w]
+    set frame1 [tixFileSelectBox::CreateFrame1 $w]
+    set frame2 [tixFileSelectBox::CreateFrame2 $w]
+    set frame3 [tixFileSelectBox::CreateFrame3 $w]
 
     pack $frame1 -in $w -side top -fill x
     pack $frame3 -in $w -side bottom -fill x
     pack $frame2 -in $w -side top -fill both -expand yes
 }
 
-proc tixFileSelectBox:CreateFrame1 {w} {
+proc tixFileSelectBox::CreateFrame1 {w} {
     upvar #0 $w data
 
     frame $w.f1 -border 10
     tixComboBox $w.f1.filter -editable 1\
-	-command [list $w filter] -anchor e \
+	-command "$w filter" -anchor e \
 	-options {
 	    slistbox.scrollbar auto
 	    listbox.height 5
@@ -122,7 +118,7 @@ proc tixFileSelectBox:CreateFrame1 {w} {
     return $w.f1
 }
 
-proc tixFileSelectBox:CreateFrame2 {w} {
+proc tixFileSelectBox::CreateFrame2 {w} {
     upvar #0 $w data
 
     tixPanedWindow $w.f2 -orientation horizontal
@@ -153,12 +149,12 @@ proc tixFileSelectBox:CreateFrame2 {w} {
     return $w.f2
 }
 
-proc tixFileSelectBox:CreateFrame3 {w} {
+proc tixFileSelectBox::CreateFrame3 {w} {
     upvar #0 $w data
 
     frame $w.f3 -border 10
     tixComboBox $w.f3.selection -editable 1\
-	-command [list tixFileSelectBox:SelInvoke $w] \
+	-command "tixFileSelectBox::SelInvoke $w" \
 	-anchor e \
 	-options {
 	    slistbox.scrollbar auto
@@ -173,7 +169,7 @@ proc tixFileSelectBox:CreateFrame3 {w} {
     return $w.f3
 }
 
-proc tixFileSelectBox:SelInvoke {w args} {
+proc tixFileSelectBox::SelInvoke {w args} {
     upvar #0 $w data
 
     set event [tixEvent type]
@@ -183,21 +179,21 @@ proc tixFileSelectBox:SelInvoke {w args} {
     }
 }
 
-proc tixFileSelectBox:SetValue {w value} {
+proc tixFileSelectBox::SetValue {w value} {
     upvar #0 $w data
 
     set data(i-value) $value
     set data(-value)  [tixNativeName $value 0]
 }
 
-proc tixFileSelectBox:SetDir {w value} {
+proc tixFileSelectBox::SetDir {w value} {
     upvar #0 $w data
 
     set data(i-directory) $value
     set data(-directory)  [tixNativeName $value]
 }
 
-proc tixFileSelectBox:SetPat {w value} {
+proc tixFileSelectBox::SetPat {w value} {
     upvar #0 $w data
 
     set data(i-pattern) $value
@@ -209,47 +205,47 @@ proc tixFileSelectBox:SetPat {w value} {
 #                           BINDINGS
 #----------------------------------------------------------------------
 
-proc tixFileSelectBox:SetBindings {w} {
+proc tixFileSelectBox::SetBindings {w} {
     upvar #0 $w data
 
     tixChainMethod $w SetBindings
 
-    tixDoWhenMapped $w "tixFileSelectBox:FirstMapped $w"
+    tixDoWhenMapped $w "tixFileSelectBox::FirstMapped $w"
 
     $data(w:dirlist) config \
-	-browsecmd [list tixFileSelectBox:SelectDir $w] \
-	-command   "tixFileSelectBox:InvokeDir $w"
+	-browsecmd "tixFileSelectBox::SelectDir $w" \
+	-command   "tixFileSelectBox::InvokeDir $w"
 
     $data(w:filelist) config \
-	-browsecmd [list tixFileSelectBox:SelectFile $w] \
-	-command   "tixFileSelectBox:InvokeFile $w"
+	-browsecmd "tixFileSelectBox::SelectFile $w" \
+	-command   "tixFileSelectBox::InvokeFile $w"
 }
 
 #----------------------------------------------------------------------
 #                           CONFIG OPTIONS
 #----------------------------------------------------------------------
-proc tixFileSelectBox:config-directory {w value} {
+proc tixFileSelectBox::config-directory {w value} {
     upvar #0 $w data
 
-    if {$value == ""} {
+    if {$value == {}} {
 	set value [pwd]
     }
-    tixFileSelectBox:SetDir $w [tixFileIntName $value]
-    tixFileSelectBox:SetFilter $w $data(i-directory) $data(i-pattern)
+    tixFileSelectBox::SetDir $w [tixFileIntName $value]
+    tixFileSelectBox::SetFilter $w $data(i-directory) $data(i-pattern)
     $w filter
 
     return $data(-directory)
 }
 
-proc tixFileSelectBox:config-pattern {w value} {
+proc tixFileSelectBox::config-pattern {w value} {
     upvar #0 $w data
 
-    if {$value == ""} {
+    if {$value == {}} {
 	set value [tixFilePattern allFiles]
     }
 
-    tixFileSelectBox:SetPat $w [tixFileIntName $value]
-    tixFileSelectBox:SetFilter $w $data(i-directory) $data(i-pattern)
+    tixFileSelectBox::SetPat $w [tixFileIntName $value]
+    tixFileSelectBox::SetFilter $w $data(i-directory) $data(i-pattern)
 
     # Returning a value means we have overridden the value and updated
     # the widget record ourselves.
@@ -257,10 +253,10 @@ proc tixFileSelectBox:config-pattern {w value} {
     return $data(-pattern)
 }
 
-proc tixFileSelectBox:config-value {w value} {
+proc tixFileSelectBox::config-value {w value} {
     upvar #0 $w data
 
-    tixFileSelectBox:SetValue $w [tixFileIntName $value]
+    tixFileSelectBox::SetValue $w [tixFileIntName $value]
     tixSetSilent $data(w:selection) $value
 
     return $data(-value)
@@ -269,15 +265,15 @@ proc tixFileSelectBox:config-value {w value} {
 #----------------------------------------------------------------------
 #                    PUBLIC METHODS
 #----------------------------------------------------------------------
-proc tixFileSelectBox:filter {w args} {
+proc tixFileSelectBox::filter {w args} {
     upvar #0 $w data
 
     $data(w:filter) popdown
-    tixFileSelectBox:InterpFilter $w
-    tixFileSelectBox:LoadDir $w
+    tixFileSelectBox::InterpFilter $w
+    tixFileSelectBox::LoadDir $w
 }
 
-proc tixFileSelectBox:invoke {w args} {
+proc tixFileSelectBox::invoke {w args} {
     upvar #0 $w data
 
     if {[$data(w:selection) cget -value] !=
@@ -290,20 +286,20 @@ proc tixFileSelectBox:invoke {w args} {
     
     # record the filter
     #
-    set filter [tixFileSelectBox:InterpFilter $w]
+    set filter [tixFileSelectBox::InterpFilter $w]
     $data(w:filter) addhistory $filter
 
     # record the selection
     #
     set userInput [string trim [$data(w:selection) cget -value]]
-    tixFileSelectBox:SetValue $w \
+    tixFileSelectBox::SetValue $w \
 	[tixFileIntName $userInput $data(i-directory)]
     $data(w:selection) addhistory $data(-value)
 
     $data(w:filter) align
     $data(w:selection)  align
 
-    if {$data(-command) != "" && !$data(-disablecallback)} {
+    if {$data(-command) != {} && !$data(-disablecallback)} {
 	set bind(specs) "%V"
 	set bind(%V) $data(-value)
 	tixEvalCmdBinding $w $data(-command) bind $data(-value)
@@ -319,44 +315,39 @@ proc tixFileSelectBox:invoke {w args} {
 # Side effects:
 #	Changes the fields data(-directory) and data(-pattenn) 
 #
-proc tixFileSelectBox:InterpFilter {w {filter ""}} {
+proc tixFileSelectBox::InterpFilter {w {filter {}}} {
     upvar #0 $w data
 
-    if {$filter == ""} {
+    if {$filter == {}} {
 	set filter [$data(w:filter) cget -selection]
-	if {$filter == ""} {
+	if {$filter == {}} {
 	    set filter [$data(w:filter) cget -value]
 	}
     }
 
-    set i_filter [tixFileIntName $filter]
-
-    if {[file isdir $filter]} {
-	tixFileSelectBox:SetDir $w $i_filter
-	tixFileSelectBox:SetPat $w [tixFilePattern allFiles]
+    set filter [tixFileIntName $filter]
+    
+    if [file isdir $filter] {
+	tixFileSelectBox::SetDir $w $filter
+	tixFileSelectBox::SetPat $w [tixFilePattern allFiles]
     } else {
-	set nDir [file dir $filter]
-	if {$nDir == "" || $nDir == "."} {
-	    tixFileSelectBox:SetDir $w [tixFileIntName $data(i-directory)]
-	} else {
-	    tixFileSelectBox:SetDir $w [tixFileIntName $nDir]
-	}
-	tixFileSelectBox:SetPat $w [tixFileIntName [file tail $filter]]
+	tixFileSelectBox::SetDir $w [file dir $filter]
+	tixFileSelectBox::SetPat $w [file tail $filter]
     }
 
-    tixFileSelectBox:SetFilter $w $data(i-directory) $data(i-pattern)
+    tixFileSelectBox::SetFilter $w $data(i-directory) $data(i-pattern)
 
     return $data(filter)
 }
 
-proc tixFileSelectBox:SetFilter {w dir pattern} {
+proc tixFileSelectBox::SetFilter {w dir pattern} {
     upvar #0 $w data
 
     set data(filter) [tixSubFolder $dir $pattern]
     tixSetSilent $data(w:filter) [tixNativeName $data(filter)]
 }
 
-proc tixFileSelectBox:LoadDirIntoLists {w} {
+proc tixFileSelectBox::LoadDirIntoLists {w} {
     upvar #0 $w data
 
     $data(w:dirlist)  subwidget listbox delete 0 end
@@ -366,19 +357,7 @@ proc tixFileSelectBox:LoadDirIntoLists {w} {
 
     # (1) List the directories
     #
-    set isDrive 0
-    catch {
-	set nDir [tixNativeName $dir]
-	if {[llength [file split $nDir]] == 1} {
-	    set isDrive 1
-	}
-    }
     foreach name [tixListDir $dir 1 0 1 1] {
-	if {![string compare ".." $name]} {
-	    if $isDrive {
-		continue
-	    }
-	}
 	$data(w:dirlist) subwidget listbox insert end $name
     }
 
@@ -390,12 +369,12 @@ proc tixFileSelectBox:LoadDirIntoLists {w} {
     # be interested in them, shift the listbox so that the "normal" files
     # are seen first
     #
-    # NOTE: if we pass $pat == "" but with $showHidden set to true,
+    # NOTE: if we pass $pat == {} but with $showHidden set to true,
     #       tixListDir will list "* .*" in Unix. See the comment on top of
     #	    the tixListDir code.
     #
     if {[string compare $data(i-pattern) *] == 0} {
-	set pat ""
+	set pat {}
     } else {
 	set pat $data(i-pattern)
     }
@@ -403,7 +382,7 @@ proc tixFileSelectBox:LoadDirIntoLists {w} {
     set top 0
     foreach name [tixListDir $dir 0 1 0 0 $pat] {
 	$data(w:filelist) subwidget listbox insert end $name
-	if {[string match .* $name]} {
+	if [string match .* $name] {
 	    incr top
 	}
     }
@@ -411,13 +390,13 @@ proc tixFileSelectBox:LoadDirIntoLists {w} {
     $data(w:filelist) subwidget listbox yview $top
 }
 
-proc tixFileSelectBox:LoadDir {w} {
+proc tixFileSelectBox::LoadDir {w} {
     upvar #0 $w data
 
     tixBusy $w on [$data(w:dirlist) subwidget listbox]
 
-    tixFileSelectBox:LoadDirIntoLists $w
-    tixFileSelectBox:MkDirMenu $w
+    tixFileSelectBox::LoadDirIntoLists $w
+    tixFileSelectBox::MkDirMenu $w
 
     if {[$data(w:dirlist) subwidget listbox size] == 0} {
 	# fail safe, just in case the user has inputed an errnoeuos
@@ -430,13 +409,13 @@ proc tixFileSelectBox:LoadDir {w} {
 
 # %% unimplemented
 #
-proc tixFileSelectBox:MkDirMenu {w} {
+proc tixFileSelectBox::MkDirMenu {w} {
     upvar #0 $w data
 }
 
 # User single clicks on the directory listbox
 #
-proc tixFileSelectBox:SelectDir {w} {
+proc tixFileSelectBox::SelectDir {w} {
     upvar #0 $w data
 
     if {$data(fakeDir) > 0} {
@@ -452,37 +431,38 @@ proc tixFileSelectBox:SelectDir {w} {
     set data(flag) 1
 
     set subdir [tixListboxGetCurrent [$data(w:dirlist) subwidget listbox]]
-    if {$subdir == ""} {
+    if {$subdir == {}} {
 	set subdir "."
     }
 
-    tixFileSelectBox:SetFilter $w \
+    tixFileSelectBox::SetFilter $w \
 	[tixFileIntName [tixSubFolder $data(i-directory) $subdir]] \
 	$data(i-pattern)
+
     set data(flag) 0
 }
 
-proc tixFileSelectBox:InvokeDir {w} {
+proc tixFileSelectBox::InvokeDir {w} {
     upvar #0 $w data
 
     set theDir [$data(w:dirlist) subwidget listbox get active]
 
-    tixFileSelectBox:SetDir $w [tixFileIntName \
+    tixFileSelectBox::SetDir $w [tixFileIntName \
 	[tixSubFolder $data(i-directory) $theDir]]
 
     $data(w:dirlist) subwidget listbox select clear 0 end
 
-    tixFileSelectBox:SetFilter $w $data(i-directory) $data(i-pattern)
-    tixFileSelectBox:InterpFilter $w [tixNativeName $data(filter)]
+    tixFileSelectBox::SetFilter $w $data(i-directory) $data(i-pattern)
+    tixFileSelectBox::InterpFilter $w $data(filter)
 
-    tixFileSelectBox:LoadDir $w
+    tixFileSelectBox::LoadDir $w
 
     if {![tixEvent match <Return>]} {
 	incr data(fakeDir) 1
     }
 }
 
-proc tixFileSelectBox:SelectFile {w} {
+proc tixFileSelectBox::SelectFile {w} {
     upvar #0 $w data
 
     if {$data(flag)} {
@@ -493,45 +473,45 @@ proc tixFileSelectBox:SelectFile {w} {
     # Reset the "Filter:" box to the current directory:
     #	
     $data(w:dirlist) subwidget listbox select clear 0 end
-    tixFileSelectBox:SetFilter $w $data(i-directory) $data(i-pattern)
+    tixFileSelectBox::SetFilter $w $data(i-directory) $data(i-pattern)
 
     # Now select the file
     #
     set selected [tixListboxGetCurrent [$data(w:filelist) subwidget listbox]]
-    if {$selected != ""} {
+    if {$selected != {}} {
 	# Make sure that the selection is not empty!
 	#
-	tixFileSelectBox:SetValue $w \
+	tixFileSelectBox::SetValue $w \
 	    [tixFileIntName [tixSubFolder $data(i-directory) $selected]]
 	tixSetSilent $data(w:selection) $data(-value)
 
-	if {$data(-browsecmd) != ""} {
-	    tixEvalCmdBinding $w $data(-browsecmd) "" $data(-value)
+	if {$data(-browsecmd) != {}} {
+	    tixEvalCmdBinding $w $data(-browsecmd) {} $data(-value)
 	}
     }
     set data(flag) 0
 }
 
-proc tixFileSelectBox:InvokeFile {w} {
+proc tixFileSelectBox::InvokeFile {w} {
     upvar #0 $w data
 
     set selected [tixListboxGetCurrent [$data(w:filelist) subwidget listbox]]
-    if {$selected  != ""} {
+    if {$selected  != {}} {
 	$w invoke
     }
 }
 
 # This is only called the first this fileBox is mapped -- load the directory
 #
-proc tixFileSelectBox:FirstMapped {w} {
+proc tixFileSelectBox::FirstMapped {w} {
     if {![winfo exists $w]} {
 	return
     }
 
     upvar #0 $w data
 
-    tixFileSelectBox:SetFilter $w $data(i-directory) $data(i-pattern)
-    tixFileSelectBox:LoadDir $w
+    tixFileSelectBox::SetFilter $w $data(i-directory) $data(i-pattern)
+    tixFileSelectBox::LoadDir $w
     $data(w:filter) align
 }
 
@@ -548,8 +528,8 @@ proc tixFileSelectBox:FirstMapped {w} {
 #
 #
 proc tixMkFileDialog {w args} {
-    set option(-okcmd)    ""
-    set option(-helpcmd)  ""
+    set option(-okcmd)    {}
+    set option(-helpcmd)  {}
 
     tixHandleOptions option {-okcmd -helpcmd} $args
 
@@ -558,7 +538,7 @@ proc tixMkFileDialog {w args} {
 
     tixStdDlgBtns $w.btns
     
-    if {$option(-okcmd) != ""} {
+    if {$option(-okcmd) != {}} {
 	tixFileSelectBox $w.fsb -command "wm withdraw $w; $option(-okcmd)"
     } else {
 	tixFileSelectBox $w.fsb -command "wm withdraw $w"
@@ -568,7 +548,7 @@ proc tixMkFileDialog {w args} {
     $w.btns button apply  config -command "$w.fsb filter" -text Filter
     $w.btns button cancel config -command "wm withdraw $w"
 
-    if {$option(-helpcmd) == ""} {
+    if {$option(-helpcmd) == {}} {
 	$w.btns button help config -state disabled
     } else {
 	$w.btns button help config -command $option(-helpcmd)
