@@ -1,13 +1,8 @@
-# -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
-#
-#	$Id: FileEnt.tcl,v 1.3.2.3 2002/01/24 10:08:58 idiscovery Exp $
-#
 # FileEnt.tcl --
 #
 # 	TixFileEntry Widget: an entry box for entering filenames.
 #
-# Copyright (c) 1993-1999 Ioi Kim Lam.
-# Copyright (c) 2000-2001 Tix Project Group.
+# Copyright (c) 1996, Expert Interface Technologies
 #
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -30,39 +25,41 @@ tixWidgetClass tixFileEntry {
 	-filebitmap
     }
     -configspec {
-	{-activatecmd activateCmd ActivateCmd ""}
-	{-command command Command ""}
-	{-dialogtype dialogType DialogType ""}
+	{-activatecmd activateCmd ActivateCmd {}}
+	{-command command Command {}}
+	{-dialogtype dialogType DialogType {}}
 	{-disablecallback disableCallback DisableCallback 0 tixVerifyBoolean}
 	{-disabledforeground disabledForeground DisabledForeground #303030}
-	{-filebitmap fileBitmap FileBitmap ""}
+	{-filebitmap fileBitmap FileBitmap {}}
 	{-selectmode selectMode SelectMode normal}
 	{-state state State normal}
-	{-validatecmd validateCmd ValidateCmd ""}
-	{-value value Value ""}
-	{-variable variable Variable ""}
+	{-validatecmd validateCmd ValidateCmd {}}
+	{-value value Value {}}
+	{-variable variable Variable {}}
     }
     -default {
 	{*frame.borderWidth		2}
 	{*frame.relief			sunken}
+	{*Label.font                   -Adobe-Helvetica-Bold-R-Normal--*-120-*}
 	{*Button.highlightThickness	0}
 	{*Entry.highlightThickness	0}
 	{*Entry.borderWidth 		0}
+	{*Entry.background 		#c3c3c3}
     }
 }
 
-proc tixFileEntry:InitWidgetRec {w} {
+proc tixFileEntry::InitWidgetRec {w} {
     upvar #0 $w data
 
     tixChainMethod $w InitWidgetRec
     set data(varInited)	  0
 
-	if {$data(-filebitmap) == ""} {
+	if {$data(-filebitmap) == {}} {
 	    set data(-filebitmap) [tix getbitmap openfile]
 	}
 }
 
-proc tixFileEntry:ConstructFramedWidget {w frame} {
+proc tixFileEntry::ConstructFramedWidget {w frame} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructFramedWidget $frame
@@ -76,25 +73,25 @@ proc tixFileEntry:ConstructFramedWidget {w frame} {
     pack $data(w:entry)  -side left  -expand yes -fill both
 }
 
-proc tixFileEntry:SetBindings {w} {
+proc tixFileEntry::SetBindings {w} {
     upvar #0 $w data
 
     tixChainMethod $w SetBindings
 
-    $data(w:button) config -command [list tixFileEntry:OpenFile $w]
+    $data(w:button) config -command "tixFileEntry::OpenFile $w"
     tixSetMegaWidget $data(w:entry) $w
 
     # If user press <return>, verify the value and call the -command
     #
-    bind $data(w:entry) <Return> "tixFileEntry:invoke $w"
+    bind $data(w:entry) <Return> "tixFileEntry::invoke $w"
     bind $data(w:entry) <KeyPress> {
 	if {[set [tixGetMegaWidget %W](-selectmode)] == "immediate"} {
-	    tixFileEntry:invoke [tixGetMegaWidget %W]
+	    tixFileEntry::invoke [tixGetMegaWidget %W]
 	}
     }
     bind $data(w:entry) <FocusOut>  {
         if {"%d" == "NotifyNonlinear" || "%d" == "NotifyNonlinearVirtual"} {
-	    tixFileEntry:invoke [tixGetMegaWidget %W]
+	    tixFileEntry::invoke [tixGetMegaWidget %W]
         }
     }
     bind $w <FocusIn> "focus $data(w:entry)"
@@ -103,7 +100,7 @@ proc tixFileEntry:SetBindings {w} {
 #----------------------------------------------------------------------
 #                           CONFIG OPTIONS
 #----------------------------------------------------------------------
-proc tixFileEntry:config-state {w value} {
+proc tixFileEntry::config-state {w value} {
     upvar #0 $w data
 
     if {$value == "normal"} {
@@ -119,21 +116,19 @@ proc tixFileEntry:config-state {w value} {
 	    $data(w:label)  config -fg $data(-disabledforeground)
 	}
     }
-
-    return ""
 }
 
-proc tixFileEntry:config-value {w value} {
-    tixFileEntry:SetValue $w $value
+proc tixFileEntry::config-value {w value} {
+    tixFileEntry::SetValue $w $value
 }
 
-proc tixFileEntry:config-variable {w arg} {
+proc tixFileEntry::config-variable {w arg} {
     upvar #0 $w data
 
-    if {[tixVariable:ConfigVariable $w $arg]} {
+    if [tixVariable:ConfigVariable $w $arg] {
        # The value of data(-value) is changed if tixVariable:ConfigVariable 
        # returns true
-       tixFileEntry:SetValue $w $data(-value)
+       tixFileEntry::SetValue $w $data(-value)
     }
     catch {
 	unset data(varInited)
@@ -144,7 +139,7 @@ proc tixFileEntry:config-variable {w arg} {
 #----------------------------------------------------------------------
 #                         User Commands
 #----------------------------------------------------------------------
-proc tixFileEntry:invoke {w} {
+proc tixFileEntry::invoke {w} {
     upvar #0 $w data
 
     if {[catch {$data(w:entry) index sel.first}] == 0} {
@@ -154,93 +149,58 @@ proc tixFileEntry:invoke {w} {
 	$data(w:entry) select to   end
     }
 
-    tixFileEntry:SetValue $w [$data(w:entry) get]
+    tixFileEntry::SetValue $w [$data(w:entry) get]
 }
 
-proc tixFileEntry:filedialog {w args} {
+proc tixFileEntry::filedialog {w args} {
     upvar #0 $w data
 
-    if {$args == ""} {
+    if {$args == {}} {
 	return [tix filedialog $data(-dialogtype)]
     } else {
 	return [eval [tix filedialog $data(-dialogtype)] $args]
     }
 }
 
-proc tixFileEntry:update {w} {
+proc tixFileEntry::update {w} {
     upvar #0 $w data
 
     if {"x[$data(w:entry) get]" != "x$data(-value)"} {
-	tixFileEntry:invoke $w
+	tixFileEntry::invoke $w
     }
 }
 #----------------------------------------------------------------------
 #                       Internal Commands
 #----------------------------------------------------------------------
-proc tixFileEntry:OpenFile {w} {
+proc tixFileEntry::OpenFile {w} {
      upvar #0 $w data
 
-     if {$data(-activatecmd) != ""} {
+     if {$data(-activatecmd) != {}} {
 	 uplevel #0 $data(-activatecmd)
      }
 
-     switch -- $data(-dialogtype) tk_chooseDirectory {
-	 set args [list -parent [winfo toplevel $w]]
-	 if {[set initial $data(-value)] != ""} {
-	     lappend args -initialdir $data(value)
-	 }
-	 set retval [eval tk_chooseDirectory $args]
+     set filedlg [tix filedialog $data(-dialogtype)]
 
-	 if {$retval != ""} {tixFileEntry:SetValue $w [file native $retval]}
-     } tk_getOpenFile - tk_getSaveFile {
-	 set args [list -parent [winfo toplevel $w]]
 
-	 if {[set initial [$data(w:entry) get]] != ""} {
-	     switch -glob -- $initial *.py {
-		 set types [list {"Python Files" {.py .pyw}} {"All Files" *}]
-	     } *.txt {
-		 set types [list {"Text Files" .txt} {"All Files" *}]
-	     } *.tcl {
-		 set types [list {"Tcl Files" .tcl} {"All Files" *}]
-	     } * - default {
-		 set types [list {"All Files" *}]
-	     }
-	     if {[file isfile $initial]} {
-		 lappend args -initialdir [file dir $initial] \
-			 -initialfile $initial
-	     } elseif {[file isdir $initial]} {
-		 lappend args -initialdir $initial
-	     }
-	 } else {
-	     set types [list {"All Files" *}]
-	 }
-	 lappend args -filetypes $types
+     $filedlg config -parent [winfo toplevel $w] \
+	 -command "tixFileEntry::FileDlgCallback $w"
 
-	 set retval [eval $data(-dialogtype) $args]
-	 if {$retval != ""} {tixFileEntry:SetValue $w [file native $retval]}
-     } default {
-	 set filedlg [tix filedialog $data(-dialogtype)]
+     focus $data(w:entry)
 
-	 $filedlg config -parent [winfo toplevel $w] \
-		 -command [list tixFileEntry:FileDlgCallback $w]
-
-	 focus $data(w:entry)
-
-	 $filedlg popup
-     }
+     $filedlg popup
 }
 
-proc tixFileEntry:FileDlgCallback {w args} {
+proc tixFileEntry::FileDlgCallback {w args} {
     set filename [tixEvent flag V]
 
-    tixFileEntry:SetValue $w $filename
+    tixFileEntry::SetValue $w $filename
 }
 
-proc tixFileEntry:SetValue {w value} {
+proc tixFileEntry::SetValue {w value} {
     upvar #0 $w data
 
-    if {$data(-validatecmd) != ""} {
-	set value [tixEvalCmdBinding $w $data(-validatecmd) "" $value]
+    if {$data(-validatecmd) != {}} {
+	set value [tixEvalCmdBinding $w $data(-validatecmd) {} $value]
     }
 
     if {$data(-state) == "normal"} {
@@ -253,7 +213,7 @@ proc tixFileEntry:SetValue {w value} {
 
     tixVariable:UpdateVariable $w
 
-    if {$data(-command) != "" && !$data(-disablecallback)} {
+    if {$data(-command) != {} && !$data(-disablecallback)} {
 	if {![info exists data(varInited)]} {
 	    set bind(specs) ""
 	    tixEvalCmdBinding $w $data(-command) bind $value
@@ -261,7 +221,7 @@ proc tixFileEntry:SetValue {w value} {
     }
 }
 
-proc tixFileEntry:Destructor {w} {
+proc tixFileEntry::Destructor {w} {
     upvar #0 $w data
 
     tixUnsetMegaWidget $data(w:entry)
