@@ -1,13 +1,8 @@
-# -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
-#
-#	$Id: PanedWin.tcl,v 1.4.2.1 2001/11/03 07:48:00 idiscovery Exp $
-#
 # PanedWin.tcl --
 #
 #	This file implements the TixPanedWindow widget
 #
-# Copyright (c) 1993-1999 Ioi Kim Lam.
-# Copyright (c) 2000-2001 Tix Project Group.
+# Copyright (c) 1996, Expert Interface Technologies
 #
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -21,16 +16,15 @@ tixWidgetClass tixPanedWindow {
 	add delete forget manage panecget paneconfigure panes setsize
     }
     -flag {
-	-command -dynamicgeometry -handleactivebg -handlebg -orient
-	-orientation -panebd -paneborderwidth -panerelief
-	-separatoractivebg -separatorbg
+	-command -handleactivebg -handlebg -orient -orientation
+	-panebd -paneborderwidth -panerelief -separatoractivebg
+	-separatorbg
     }
     -static {
 	-orientation
     }
     -configspec {
-	{-command command Command ""}
-	{-dynamicgeometry dynamicGeometry DynamicGeometry 1 tixVerifyBoolean}
+	{-command command Command {}}
 	{-handleactivebg handleActiveBg HandleActiveBg #ececec}
 	{-handlebg handleBg Background #d9d9d9}
 	{-orientation orientation Orientation vertical}
@@ -49,42 +43,39 @@ tixWidgetClass tixPanedWindow {
 # ClassInitialization:
 #----------------------------------------------------------------------
 
-proc tixPanedWindow:InitWidgetRec {w} {
+proc tixPanedWindow::InitWidgetRec {w} {
     upvar #0 $w data
 
     tixChainMethod $w InitWidgetRec
 
-    set data(items)       ""
+    set data(items)       {}
     set data(nItems)      0
     set data(totalsize)   0
     set data(movePending) 0
 
     set data(repack)      0
-    set data(counter)     0
-
-    set data(maxReqW)     1
-    set data(maxReqH)     1
+    set data(counter) 0
 }
 
-proc tixPanedWindow:ConstructWidget {w} {
+proc tixPanedWindow::ConstructWidget {w} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructWidget
     # Do nothing
 }
 
-proc tixPanedWindow:SetBindings {w} {
+proc tixPanedWindow::SetBindings {w} {
     upvar #0 $w data
 
     tixChainMethod $w SetBindings
 
-    bind $w <Configure> [list tixPanedWindow:MasterGeomProc $w ""]
+    bind $w <Configure> "tixPanedWindow::MasterGeomProc $w {}"
 }
 
 #----------------------------------------------------------------------
 # ConfigOptions:
 #----------------------------------------------------------------------
-proc tixPanedWindow:config-handlebg {w arg} {
+proc tixPanedWindow::config-handlebg {w arg} {
     upvar #0 $w data
 
     for {set i 1} {$i < $data(nItems)} {incr i} {
@@ -103,7 +94,7 @@ proc tixPanedWindow:config-handlebg {w arg} {
 #
 # options -size -max -min -allowresize
 #
-proc tixPanedWindow:add {w name args} {
+proc tixPanedWindow::add {w name args} {
     upvar #0 $w data
 
     if {[winfo exists $w.$name] && !$data($name,forgotten)} {
@@ -113,7 +104,7 @@ proc tixPanedWindow:add {w name args} {
 
     # The default values
     #
-    if {[info exists data($name,forgotten)]} {
+    if [info exists data($name,forgotten)] {
 	set option(-size)        $data($name,size)
 	set option(-min)         $data($name,min)
 	set option(-max)         $data($name,max)
@@ -127,9 +118,9 @@ proc tixPanedWindow:add {w name args} {
 	set option(-expand)      0
     }
 
-    set option(-before)      ""
-    set option(-after)       ""
-    set option(-at)          ""
+    set option(-before)      {}
+    set option(-after)       {}
+    set option(-at)          {}
     set validOpts {-after -allowresize -at -before -expand -max -min -size}
 
     tixHandleOptions option $validOpts $args
@@ -154,19 +145,19 @@ proc tixPanedWindow:add {w name args} {
 	frame $w.$name -bd $data(-paneborderwidth) -relief $data(-panerelief)
     }
 
-    if {$option(-at) != ""} {
+    if {$option(-at) != {}} {
 	set at [tixGetInt $option(-at)]
 	if {$at < 0} {
 	    set at 0
 	}
-    } elseif {$option(-after) != ""} {
+    } elseif {$option(-after) != {}} {
 	set index [lsearch -exact $data(items) $option(-after)]
 	if {$index == -1} {
 	    error "Pane $option(-after) doesn't exists"
 	} else {
 	    set at [incr index]
 	}
-    } elseif {$option(-before) != ""} {
+    } elseif {$option(-before) != {}} {
 	set index [lsearch -exact $data(items) $option(-before)]
 	if {$index == -1} {
 	    error "Pane $option(-before) doesn't exists"
@@ -180,22 +171,21 @@ proc tixPanedWindow:add {w name args} {
     incr data(nItems)
 
     if {$data(nItems) > 1} {
-	tixPanedWindow:AddSeparator $w
+	tixPanedWindow::AddSeparator $w
     }
     set data(w:$name) $w.$name
 
     # Step 3: Add the new frame. Adjust the window later (do when idle)
     #
-    tixManageGeometry $w.$name "tixPanedWindow:ClientGeomProc $w"
-    bind $w.$name <Configure> \
-	[list tixPanedWindow:ClientGeomProc $w "" $w.$name]
+    tixManageGeometry $w.$name "tixPanedWindow::ClientGeomProc $w"
+    bind $w.$name <Configure> "tixPanedWindow::ClientGeomProc $w {} $w.$name"
 
-    tixPanedWindow:RepackWhenIdle $w
+    tixPanedWindow::RepackWhenIdle $w
 
     return $w.$name
 }
 
-proc tixPanedWindow:manage {w name args} {
+proc tixPanedWindow::manage {w name args} {
     upvar #0 $w data
 
     if {![winfo exists $w.$name]} {
@@ -205,10 +195,10 @@ proc tixPanedWindow:manage {w name args} {
 	error "Pane $name is already managed"
     }
     tixMapWindow $data(w:$name)
-    eval tixPanedWindow:add $w [list $name] $args
+    eval tixPanedWindow::add $w [list $name] $args
 }
 
-proc tixPanedWindow:forget {w name} {
+proc tixPanedWindow::forget {w name} {
     upvar #0 $w data
 
     if {![winfo exists $w.$name]} {
@@ -220,7 +210,7 @@ proc tixPanedWindow:forget {w name} {
 	return
     }
 
-    set items ""
+    set items {}
     foreach item $data(items) {
 	if {$item != $name} {
 	    lappend items $item
@@ -240,10 +230,10 @@ proc tixPanedWindow:forget {w name} {
 
     tixUnmapWindow $w.$name
 
-    tixPanedWindow:RepackWhenIdle $w
+    tixPanedWindow::RepackWhenIdle $w
 }
 
-proc tixPanedWindow:delete {w name} {
+proc tixPanedWindow::delete {w name} {
     upvar #0 $w data
 
     if {![winfo exists $w.$name]} {
@@ -252,7 +242,7 @@ proc tixPanedWindow:delete {w name} {
 
 
     if {!$data($name,forgotten)} {
-	set items ""
+	set items {}
 	foreach item $data(items) {
 	    if {$item != $name} {
 		lappend items $item
@@ -279,10 +269,10 @@ proc tixPanedWindow:delete {w name} {
     unset data(w:$name)
     destroy $w.$name
 
-    tixPanedWindow:RepackWhenIdle $w
+    tixPanedWindow::RepackWhenIdle $w
 }
 
-proc tixPanedWindow:paneconfigure {w name args} {
+proc tixPanedWindow::paneconfigure {w name args} {
     upvar #0 $w data
 
     if {![info exists data($name,size)]} {
@@ -293,30 +283,30 @@ proc tixPanedWindow:paneconfigure {w name args} {
 
     if {$len == 0} {
 	set value [$data(w:$name) configure]
-	lappend value [list -allowresize "" "" "" $data($name,allowresize)]
-	lappend value [list -expand "" "" "" $data($name,expand)]
-	lappend value [list -max "" "" "" $data($name,max)]
-	lappend value [list -min "" "" "" $data($name,min)]
-	lappend value [list -size "" "" "" $data($name,size)]
+	lappend value "-allowresize {} {} {} $data($name,allowresize)"
+	lappend value "-expand {} {} {} $data($name,expand)"
+	lappend value "-max {} {} {} $data($name,max)"
+	lappend value "-min {} {} {} $data($name,min)"
+	lappend value "-size {} {} {} $data($name,size)"
 	return $value
     }
 
     if {$len == 1} {
 	case [lindex $args 0] {
 	    -allowresize {
-		return [list -allowresize "" "" "" $data($name,allowresize)]
+		return "-allowresize {} {} {} $data($name,allowresize)"
 	    }
 	    -expand {
-		return [list -expand "" "" "" $data($name,expand)]
+		return "-expand {} {} {} $data($name,expand)"
 	    }
 	    -min {
-		return [list -min "" "" "" $data($name,min)]
+		return "-min {} {} {} $data($name,min)"
 	    }
 	    -max {
-		return [list -max "" "" "" $data($name,max)]
+		return "-max {} {} {} $data($name,max)"
 	    }
 	    -size {
-		return [list -size "" "" "" $data($name,size)]
+		return "-size {} {} {} $data($name,size)"
 	    }
 	    default {
 		return [$data(w:$name) configure [lindex $args 0]]
@@ -337,7 +327,7 @@ proc tixPanedWindow:paneconfigure {w name args} {
 
     #
     # the widget options
-    set new_args ""
+    set new_args {}
     tixForEach {flag value} $args {
 	case $flag {
 	    {-expand -min -max -allowresize -size} {
@@ -375,11 +365,11 @@ proc tixPanedWindow:paneconfigure {w name args} {
 	set data($name,size) $data($name,max)
     }
 
-    tixPanedWindow:RepackWhenIdle $w
-    return ""
+    tixPanedWindow::RepackWhenIdle $w
+    return {}
 }
 
-proc tixPanedWindow:panecget {w name option} {
+proc tixPanedWindow::panecget {w name option} {
     upvar #0 $w data
 
     if {![info exists data($name,size)]} {
@@ -398,7 +388,7 @@ proc tixPanedWindow:panecget {w name option} {
 }
 
 # return the name of all panes
-proc tixPanedWindow:panes {w} {
+proc tixPanedWindow::panes {w} {
     upvar #0 $w data
 
     return $data(items)
@@ -406,7 +396,7 @@ proc tixPanedWindow:panes {w} {
 
 # set the size of a pane, specifying which direction it should
 # grow/shrink
-proc tixPanedWindow:setsize {w item size {direction next}} {
+proc tixPanedWindow::setsize {w item size {direction next}} {
     upvar #0 $w data
 
     set posn [lsearch $data(items) $item]
@@ -426,16 +416,9 @@ proc tixPanedWindow:setsize {w item size {direction next}} {
 	set direction prev
     }
 
-    if {$data(-orientation) == "vertical"} {
-        set rx [winfo rooty $data(w:$item)]
-    } else {
-        set rx [winfo rootx $data(w:$item)]
-    }
+    set rx [winfo rootx $data(w:$item)]
     if {$direction == "prev"} {
 	set rx [expr $rx - $diff]
-    } elseif {$data(-orientation) == "vertical"} {
-	set rx [expr $rx + [winfo height $data(w:$item)] + $diff]
-	incr posn
     } else {
 	set rx [expr $rx + [winfo width $data(w:$item)] + $diff]
 	incr posn
@@ -443,9 +426,9 @@ proc tixPanedWindow:setsize {w item size {direction next}} {
 
     # Set up the panedwin in a proper state
     #
-    tixPanedWindow:BtnDown $w $posn 1
-    tixPanedWindow:BtnMove $w $posn $rx 1
-    tixPanedWindow:BtnUp $w $posn 1
+    tixPanedWindow::BtnDown $w $posn 1
+    tixPanedWindow::BtnMove $w $posn $rx 1
+    tixPanedWindow::BtnUp $w $posn 1
 
     return $data(items)
 }
@@ -454,27 +437,17 @@ proc tixPanedWindow:setsize {w item size {direction next}} {
 # PrivateMethods:
 #----------------------------------------------------------------------
 
-proc tixPanedWindow:AddSeparator {w} {
-    global tcl_platform
-
+proc tixPanedWindow::AddSeparator {w} {
     upvar #0 $w data
 
     set n [expr $data(nItems)-1]
 
-    # CYGNUS: On Windows, use relief ridge and a thicker line.
-    if {$tcl_platform(platform) == "windows"} then {
-      set relief "ridge"
-      set thickness 4
-    } else {
-      set relief "sunken"
-      set thickness 2
-    }
     if {$data(-orientation) == "vertical"} {
-	set data(sep,$n) [frame $w.sep$n -relief $relief \
-	    -bd 1 -height $thickness -width 10000 -bg $data(-separatorbg)]
+	set data(sep,$n) [frame $w.sep$n -relief sunken \
+			  -bd 1 -height 2 -width 10000 -bg $data(-separatorbg)]
     } else {
-	set data(sep,$n) [frame $w.sep$n -relief $relief \
-	    -bd 1 -width $thickness -height 10000 -bg $data(-separatorbg)]
+	set data(sep,$n) [frame $w.sep$n -relief sunken \
+			  -bd 1 -width 2 -height 10000 -bg $data(-separatorbg)]
     }
 
     set data(btn,$n) [frame $w.btn$n -relief raised \
@@ -491,21 +464,21 @@ proc tixPanedWindow:AddSeparator {w} {
 
     foreach wid "$data(btn,$n) $data(sep,$n)" {
 	bind $wid \
-	    <ButtonPress-1>   "tixPanedWindow:BtnDown $w $n"
+	    <ButtonPress-1>   "tixPanedWindow::BtnDown $w $n"
 	bind $wid \
-	    <ButtonRelease-1> "tixPanedWindow:BtnUp   $w $n"
+	    <ButtonRelease-1> "tixPanedWindow::BtnUp   $w $n"
 	bind $wid \
-	    <Any-Enter>       "tixPanedWindow:HighlightBtn $w $n"
+	    <Any-Enter>       "tixPanedWindow::HighlightBtn $w $n"
 	bind $wid \
-	    <Any-Leave>       "tixPanedWindow:DeHighlightBtn $w $n"
+	    <Any-Leave>       "tixPanedWindow::DeHighlightBtn $w $n"
     }
 
     if {$data(-orientation) == "vertical"} {
 	bind  $data(btn,$n) <B1-Motion> \
-	    "tixPanedWindow:BtnMove $w $n %Y"
+	    "tixPanedWindow::BtnMove $w $n %Y"
     } else {
 	bind  $data(btn,$n) <B1-Motion> \
-	    "tixPanedWindow:BtnMove $w $n %X"
+	    "tixPanedWindow::BtnMove $w $n %X"
     }
 
     if {$data(-orientation) == "vertical"} {
@@ -517,7 +490,7 @@ proc tixPanedWindow:AddSeparator {w} {
     }
 }
 
-proc tixPanedWindow:BtnDown {w item {fake 0}} {
+proc tixPanedWindow::BtnDown {w item {fake 0}} {
     upvar #0 $w data
 
     if {$data(-orientation) == "vertical"} {
@@ -534,7 +507,7 @@ proc tixPanedWindow:BtnDown {w item {fake 0}} {
 	$data(btn,$item) config -relief sunken
     }
 
-    tixPanedWindow:GetMotionLimit $w $item $fake
+    tixPanedWindow::GetMotionLimit $w $item $fake
 
     if {!$fake} {
 	grab -global $data(btn,$item)
@@ -542,7 +515,7 @@ proc tixPanedWindow:BtnDown {w item {fake 0}} {
     set data(movePending) 0
 }
 
-proc tixPanedWindow:Min2 {a b} {
+proc tixPanedWindow::Min2 {a b} {
     if {$a < $b} {
 	return $a
     } else {
@@ -550,7 +523,7 @@ proc tixPanedWindow:Min2 {a b} {
     }
 }
 
-proc tixPanedWindow:GetMotionLimit {w item fake} {
+proc tixPanedWindow::GetMotionLimit {w item fake} {
     upvar #0 $w data
 
     set curBefore 0
@@ -575,10 +548,10 @@ proc tixPanedWindow:GetMotionLimit {w item fake} {
 	incr i
     }
 
-    set beforeToGo [tixPanedWindow:Min2 \
+    set beforeToGo [tixPanedWindow::Min2 \
         [expr "$curBefore-$minBefore"] [expr "$maxAfter-$curAfter"]]
 
-    set afterToGo [tixPanedWindow:Min2 \
+    set afterToGo [tixPanedWindow::Min2 \
         [expr "$curAfter-$minAfter"] [expr "$maxBefore-$curBefore"]]
 
     set data(beforeLimit) [expr "$curBefore-$beforeToGo"]
@@ -586,29 +559,29 @@ proc tixPanedWindow:GetMotionLimit {w item fake} {
     set data(curSize)     $curBefore
 
     if {!$fake} {
-	tixPanedWindow:PlotHandles $w 1
+	tixPanedWindow::PlotHandles $w 1
     }
 }
 
 # Compress the motion so that update is quick even on slow machines
 #
 # rootp = root position (either rootx or rooty)
-proc tixPanedWindow:BtnMove {w item rootp {fake 0}} {
+proc tixPanedWindow::BtnMove {w item rootp {fake 0}} {
     upvar #0 $w data
 
     set data(rootp) $rootp
 
     if {$fake} {
-	tixPanedWindow:BtnMoveCompressed $w $item $fake
+	tixPanedWindow::BtnMoveCompressed $w $item $fake
     } else {
 	if {$data(movePending) == 0} {
-	    after 2 tixPanedWindow:BtnMoveCompressed $w $item
+	    after 2 tixPanedWindow::BtnMoveCompressed $w $item
 	    set data(movePending) 1
 	}
     } 
 }
 
-proc tixPanedWindow:BtnMoveCompressed {w item {fake 0}} {
+proc tixPanedWindow::BtnMoveCompressed {w item {fake 0}} {
     if {![winfo exists $w]} {
 	return
     }
@@ -632,7 +605,7 @@ proc tixPanedWindow:BtnMoveCompressed {w item {fake 0}} {
     if {$p >= $data(afterLimit)} {
 	set p $data(afterLimit)
     }
-    tixPanedWindow:CalculateChange $w $item $p $fake
+    tixPanedWindow::CalculateChange $w $item $p $fake
 
     if {!$fake} {
 	# Force the redraw to happen
@@ -644,21 +617,21 @@ proc tixPanedWindow:BtnMoveCompressed {w item {fake 0}} {
 
 # Calculate the change in response to mouse motions
 #
-proc tixPanedWindow:CalculateChange {w item p {fake 0}} {
+proc tixPanedWindow::CalculateChange {w item p {fake 0}} {
     upvar #0 $w data
 
     if {$p < $data(curSize)} {
-	tixPanedWindow:MoveBefore $w $item $p
+	tixPanedWindow::MoveBefore $w $item $p
     } elseif {$p > $data(curSize)} {
-	tixPanedWindow:MoveAfter $w $item $p
+	tixPanedWindow::MoveAfter $w $item $p
     }
 
     if {!$fake} {
-	tixPanedWindow:PlotHandles $w 1
+	tixPanedWindow::PlotHandles $w 1
     }
 }
 
-proc tixPanedWindow:MoveBefore {w item p} {
+proc tixPanedWindow::MoveBefore {w item p} {
     upvar #0 $w data
 
     set n [expr "$data(curSize)-$p"]
@@ -667,18 +640,18 @@ proc tixPanedWindow:MoveBefore {w item p} {
     #
     set from [expr $item-1]
     set to   0
-    tixPanedWindow:Iterate $w $from $to tixPanedWindow:Shrink $n
+    tixPanedWindow::Iterate $w $from $to tixPanedWindow::Shrink $n
 
     # Adjust the frames after
     #
     set from $item
     set to   [expr "$data(nItems)-1"]
-    tixPanedWindow:Iterate $w $from $to tixPanedWindow:Grow $n
+    tixPanedWindow::Iterate $w $from $to tixPanedWindow::Grow $n
 
     set data(curSize) $p
 }
 
-proc tixPanedWindow:MoveAfter {w item p} {
+proc tixPanedWindow::MoveAfter {w item p} {
     upvar #0 $w data
 
     set n    [expr "$p-$data(curSize)"]
@@ -687,37 +660,35 @@ proc tixPanedWindow:MoveAfter {w item p} {
     #
     set from $item
     set to   [expr "$data(nItems)-1"]
-    tixPanedWindow:Iterate $w $from $to tixPanedWindow:Shrink $n
+    tixPanedWindow::Iterate $w $from $to tixPanedWindow::Shrink $n
 
     # Graw the frame before
     #
     set from [expr $item-1]
     set to   0
-    tixPanedWindow:Iterate $w $from $to tixPanedWindow:Grow $n
+    tixPanedWindow::Iterate $w $from $to tixPanedWindow::Grow $n
 
     set data(curSize) $p
 }
 
-proc tixPanedWindow:CancleLines {w} {
+proc tixPanedWindow::CancleLines {w} {
     upvar #0 $w data
 
-    if {[info exists data(lines)]} {
+    if [info exists data(lines)] {
 	foreach line $data(lines) {
 	    set x1 [lindex $line 0]
 	    set y1 [lindex $line 1]
 	    set x2 [lindex $line 2]
 	    set y2 [lindex $line 3]
 
-	    tixTmpLine $x1 $y1 $x2 $y2 $w
+	    tixTmpLine $x1 $y1 $x2 $y2
 	}
 
 	catch {unset data(lines)}
     }
 }
 
-proc tixPanedWindow:PlotHandles {w transient} {
-    global tcl_platform
-
+proc tixPanedWindow::PlotHandles {w transient} {
     upvar #0 $w data
 
     set totalsize 0
@@ -738,8 +709,8 @@ proc tixPanedWindow:PlotHandles {w transient} {
     set totalsize $data($firstpane,size)
 
     if {$transient} {
-	tixPanedWindow:CancleLines $w
-	set data(lines) ""
+	tixPanedWindow::CancleLines $w
+	set data(lines) {}
     }
 
     for {set i 1} {$i < $data(nItems)} {incr i} {
@@ -757,14 +728,14 @@ proc tixPanedWindow:PlotHandles {w transient} {
 		set x2 [expr $x1 + [winfo width $w]]
 		set y  [expr $totalsize-1+[winfo rooty $w]]
 
-		tixTmpLine $x1 $y $x2 $y $w
+		tixTmpLine $x1 $y $x2 $y
 		lappend data(lines) [list $x1 $y $x2 $y]
 	    } else {
 		set y1 [winfo rooty $w]
 		set y2 [expr $y1 + [winfo height $w]]
 		set x  [expr $totalsize-1+[winfo rootx $w]]
 
-		tixTmpLine $x $y1 $x $y2 $w
+		tixTmpLine $x $y1 $x $y2
 		lappend data(lines) [list $x $y1 $x $y2]
 	    }
 	}
@@ -774,14 +745,14 @@ proc tixPanedWindow:PlotHandles {w transient} {
     }
 }
 
-proc tixPanedWindow:BtnUp {w item {fake 0}} {
+proc tixPanedWindow::BtnUp {w item {fake 0}} {
     upvar #0 $w data
 
     if {!$fake} {
-	tixPanedWindow:CancleLines $w
+	tixPanedWindow::CancleLines $w
     }
 
-    tixPanedWindow:UpdateSizes $w
+    tixPanedWindow::UpdateSizes $w
 
     if {!$fake} {
 	$data(btn,$item) config -relief raised
@@ -790,13 +761,13 @@ proc tixPanedWindow:BtnUp {w item {fake 0}} {
 }
 
 
-proc tixPanedWindow:HighlightBtn {w item} {
+proc tixPanedWindow::HighlightBtn {w item} {
     upvar #0 $w data
 
     $data(btn,$item) config -background $data(-handleactivebg)
 }
 
-proc tixPanedWindow:DeHighlightBtn {w item} {
+proc tixPanedWindow::DeHighlightBtn {w item} {
     upvar #0 $w data
 
     $data(btn,$item) config -background $data(-handlebg)
@@ -812,9 +783,7 @@ proc tixPanedWindow:DeHighlightBtn {w item} {
 
 # update the sizes of each pane according to the data($name,size) variables
 #
-proc tixPanedWindow:UpdateSizes {w} {
-    global tcl_platform
-
+proc tixPanedWindow::UpdateSizes {w} {
     upvar #0 $w data
 
     set data(totalsize) 0
@@ -851,15 +820,8 @@ proc tixPanedWindow:UpdateSizes {w} {
 	set spec -width
     }
 
-    # CYGNUS: On Windows, use a thicker line.
-    if {$tcl_platform(platform) == "windows"} then {
-	set thickness 4
-    } else {
-	set thickness 2
-    }
-
     for {set i 1} {$i < $data(nItems)} {incr i} {
-	$data(sep,$i) config -bg $data(-separatorbg) $spec $thickness
+	$data(sep,$i) config -bg $data(-separatorbg) $spec 2
 	raise $data(sep,$i)
 	raise $data(btn,$i)
     }
@@ -867,8 +829,8 @@ proc tixPanedWindow:UpdateSizes {w} {
 
     # Invoke the callback command
     #
-    if {$data(-command) != ""} {
-	set sizes ""
+    if {$data(-command) != {}} {
+	set sizes {}
 	foreach item $data(items) {
 	    lappend sizes $data($item,size)
 	}
@@ -877,7 +839,7 @@ proc tixPanedWindow:UpdateSizes {w} {
     }
 }
 
-proc tixPanedWindow:GetNaturalSizes {w} {
+proc tixPanedWindow::GetNaturalSizes {w} {
     upvar #0 $w data
 
     set data(totalsize) 0
@@ -956,34 +918,34 @@ proc tixPanedWindow:GetNaturalSizes {w} {
     }
 
     if {$data(-orientation) == "vertical"} {
-	return [list $minorsize $totalreq]
+	return "$minorsize $totalreq"
     } else {
-	return [list $totalreq $minorsize]
+	return "$totalreq $minorsize"
     }
 }
 
 #--------------------------------------------------
 # Handling resize
 #--------------------------------------------------
-proc tixPanedWindow:ClientGeomProc {w type client} {
-    tixPanedWindow:RepackWhenIdle $w
+proc tixPanedWindow::ClientGeomProc {w type client} {
+    tixPanedWindow::RepackWhenIdle $w
 }
 
 #
 # This monitor the sizes of the master window
 #
-proc tixPanedWindow:MasterGeomProc {w master} {
-    tixPanedWindow:RepackWhenIdle $w
+proc tixPanedWindow::MasterGeomProc {w master} {
+    tixPanedWindow::RepackWhenIdle $w
 }
 
-proc tixPanedWindow:RepackWhenIdle {w} {
+proc tixPanedWindow::RepackWhenIdle {w} {
     if {![winfo exist $w]} {
 	return
     }
     upvar #0 $w data
 
     if {$data(repack) == 0} {
-	tixWidgetDoWhenIdle tixPanedWindow:Repack $w
+	tixWidgetDoWhenIdle tixPanedWindow::Repack $w
 	set data(repack) 1
     }
 }
@@ -991,12 +953,12 @@ proc tixPanedWindow:RepackWhenIdle {w} {
 #
 # This monitor the sizes of the master window
 #
-proc tixPanedWindow:Repack {w} {
+proc tixPanedWindow::Repack {w} {
     upvar #0 $w data
 
     # Calculate the desired size of the master
     #
-    set dim [tixPanedWindow:GetNaturalSizes $w]
+    set dim [tixPanedWindow::GetNaturalSizes $w]
 
     if {$data(-width) != 0} {
 	set mreqw $data(-width)
@@ -1010,16 +972,6 @@ proc tixPanedWindow:Repack {w} {
 	set mreqh [lindex $dim 1]
     }
 
-    if !$data(-dynamicgeometry) {
-	if {$mreqw < $data(maxReqW)} {
-	    set mreqw $data(maxReqW)
-	}
-	if {$mreqh < $data(maxReqH)} {
-	    set mreqh $data(maxReqH)
-	}
-	set data(maxReqW) $mreqw
-	set data(maxReqH) $mreqh
-    }
     if {$mreqw != [winfo reqwidth $w] || $mreqh != [winfo reqheight $w] } {
 	if {![info exists data(counter)]} {
 	    set data(counter) 0
@@ -1027,7 +979,7 @@ proc tixPanedWindow:Repack {w} {
 	if {$data(counter) < 50} {
 	    incr data(counter)
 	    tixGeometryRequest $w $mreqw $mreqh
-	    tixWidgetDoWhenIdle tixPanedWindow:Repack $w
+	    tixWidgetDoWhenIdle tixPanedWindow::Repack $w
 	    set data(repack) 1
 	    return
 	}
@@ -1040,10 +992,10 @@ proc tixPanedWindow:Repack {w} {
 	return
     }
 
-    tixWidgetDoWhenIdle tixPanedWindow:DoRepack $w
+    tixWidgetDoWhenIdle tixPanedWindow::DoRepack $w
 }
 
-proc tixPanedWindow:DoRepack {w} {
+proc tixPanedWindow::DoRepack {w} {
     upvar #0 $w data
 
     if {$data(-orientation) == "vertical"} {
@@ -1062,7 +1014,7 @@ proc tixPanedWindow:DoRepack {w} {
 
     set totalExp 0
     foreach name $data(items) {
-	set totalExp [expr $totalExp + $data($name,expand)]
+	incr totalExp $data($name,expand)
     }
 
     if {$newSize > $data(totalsize)} {
@@ -1072,9 +1024,9 @@ proc tixPanedWindow:DoRepack {w} {
 
 	set p [llength $data(items)]
 	foreach name $data(items) {
-	    set toGrow [tixPanedWindow:xGrow $w $name $toGrow $totalExp $p]
+	    set toGrow [tixPanedWindow::xGrow $w $name $toGrow $totalExp $p]
 	    if {$toGrow > 0} {
-		set totalExp [expr $totalExp-$data($name,expand)]
+		incr totalExp -$data($name,expand)
 		incr p -1
 	    } else {
 		break
@@ -1087,10 +1039,10 @@ proc tixPanedWindow:DoRepack {w} {
 
 	set usedSize 0
 	foreach name $data(items) {
-	    set toShrink [tixPanedWindow:xShrink $w $name $toShrink \
+	    set toShrink [tixPanedWindow::xShrink $w $name $toShrink \
 		$totalExp $newSize $usedSize]
 	    if {$toShrink > 0} {
-		set totalExp [expr $totalExp-$data($name,expand)]
+		incr totalExp -$data($name,expand)
 		incr usedSize $data($name,size)
 	    } else {
 		break
@@ -1098,8 +1050,8 @@ proc tixPanedWindow:DoRepack {w} {
 	}
     }
 
-    tixPanedWindow:UpdateSizes $w
-    tixPanedWindow:PlotHandles $w 0
+    tixPanedWindow::UpdateSizes $w
+    tixPanedWindow::PlotHandles $w 0
 
     set data(repack) 0
 }
@@ -1113,7 +1065,7 @@ proc tixPanedWindow:DoRepack {w} {
 # totalExp: used to calculate the amount of the free area that this
 #	    window can grow into
 #
-proc tixPanedWindow:xGrow {w name toGrow totalExp p} {
+proc tixPanedWindow::xGrow {w name toGrow totalExp p} {
     upvar #0 $w data
 
     if {$p == 1} {
@@ -1122,7 +1074,7 @@ proc tixPanedWindow:xGrow {w name toGrow totalExp p} {
 	if {$totalExp == 0} {
 	    set canGrow 0
 	} else {
-	    set canGrow [expr int($toGrow * $data($name,expand) / $totalExp)]
+	    set canGrow [expr $toGrow * $data($name,expand) / $totalExp]
 	}
     }
 
@@ -1136,13 +1088,13 @@ proc tixPanedWindow:xGrow {w name toGrow totalExp p} {
     return $toGrow
 }
 
-proc tixPanedWindow:xShrink {w name toShrink totalExp newSize usedSize} {
+proc tixPanedWindow::xShrink {w name toShrink totalExp newSize usedSize} {
     upvar #0 $w data
 
     if {$totalExp == 0} {
 	set canShrink 0
     } else {
-	set canShrink [expr int($toShrink * $data($name,expand) / $totalExp)]
+	set canShrink [expr $toShrink * $data($name,expand) / $totalExp]
     }
 
     if {[expr $data($name,size) - $canShrink] < $data($name,min)} {
@@ -1162,7 +1114,7 @@ proc tixPanedWindow:xShrink {w name toShrink totalExp newSize usedSize} {
 #--------------------------------------------------
 # Shrink and grow items
 #--------------------------------------------------
-proc tixPanedWindow:Shrink {w name n} {
+proc tixPanedWindow::Shrink {w name n} {
     upvar #0 $w data
 
     set canShrink [expr "$data($name,size) - $data($name,min)"]
@@ -1177,7 +1129,7 @@ proc tixPanedWindow:Shrink {w name n} {
     return $n
 }
 
-proc tixPanedWindow:Grow {w name n} {
+proc tixPanedWindow::Grow {w name n} {
     upvar #0 $w data
 
     set canGrow [expr "$data($name,max) - $data($name,size)"]
@@ -1193,7 +1145,7 @@ proc tixPanedWindow:Grow {w name n} {
     return $n
 }
 
-proc tixPanedWindow:Iterate {w from to proc n} {
+proc tixPanedWindow::Iterate {w from to proc n} {
     upvar #0 $w data
 
     if {$from <= $to} {
