@@ -1,35 +1,3 @@
-# -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
-#
-#	$Id: PopMenu.tcl,v 1.4.2.2 2002/09/21 08:02:11 idiscovery Exp $
-#
-# PopMenu.tcl --
-#
-#	This file implements the TixPopupMenu widget
-#
-# Copyright (c) 1993-1999 Ioi Kim Lam.
-# Copyright (c) 2000-2001 Tix Project Group.
-#
-# See the file "license.terms" for information on usage and redistribution
-# of this file, and for a DISCLAIMER OF ALL WARRANTIES.
-#
-
-global tkPriv
-if {![llength [info globals tkPriv]]} {
-    tk::unsupported::ExposePrivateVariable tkPriv
-}
-#--------------------------------------------------------------------------
-# tkPriv elements used in this file:
-#
-# inMenubutton -	
-#--------------------------------------------------------------------------
-#
-foreach fun {tkMenuUnpost tkMbButtonUp tkMbEnter tkMbPost} {
-    if {![llength [info commands $fun]]} {
-	tk::unsupported::ExposePrivateCommand $fun
-    }
-}
-unset fun
-
 tixWidgetClass tixPopupMenu {
     -classname TixPopupMenu
     -superclass tixShell
@@ -42,10 +10,11 @@ tixWidgetClass tixPopupMenu {
     -configspec {
 	{-buttons buttons Buttons {{3 {Any}}}}
 	{-installcolormap installColormap InstallColormap false}
-	{-postcmd postCmd PostCmd ""}
+	{-postcmd postCmd PostCmd {}}
 	{-spring spring Spring 1 tixVerifyBoolean}
 	{-state state State normal}
-	{-cursor corsor Cursor arrow}
+
+	{-cursor corsor Cursur arrow}
     }
     -static {
 	-buttons
@@ -55,15 +24,15 @@ tixWidgetClass tixPopupMenu {
     }
 }
 
-proc tixPopupMenu:InitWidgetRec {w} {
+proc tixPopupMenu::InitWidgetRec {w} {
     upvar #0 $w data
 
     tixChainMethod $w InitWidgetRec
 
-    set data(g:clients)   ""
+    set data(g:clients)   {}
 }
 
-proc tixPopupMenu:ConstructWidget {w} {
+proc tixPopupMenu::ConstructWidget {w} {
     upvar #0 $w data
 
     tixChainMethod $w ConstructWidget
@@ -78,7 +47,7 @@ proc tixPopupMenu:ConstructWidget {w} {
     pack $data(w:menubutton) -expand yes -fill both
 }
 
-proc tixPopupMenu:SetBindings {w} {
+proc tixPopupMenu::SetBindings {w} {
     upvar #0 $w data
 
     tixChainMethod $w SetBindings
@@ -87,19 +56,19 @@ proc tixPopupMenu:SetBindings {w} {
 	set btn [lindex $elm 0]
 	foreach mod [lindex $elm 1] {
 	    tixBind TixPopupMenu:MB:$w <$mod-ButtonPress-$btn> \
-		"tixPopupMenu:Unpost $w"
+		"tixPopupMenu::Unpost $w"
 	
 	    tixBind TixPopupMenu:$w <$mod-ButtonPress-$btn> \
-		"tixPopupMenu:post $w %W %x %y"
+		"tixPopupMenu::post $w %W %x %y"
 	}
 
 	tixBind TixPopupMenu:MB:$w <ButtonRelease-$btn> \
-	    "tixPopupMenu:BtnRelease $w %X %Y"
+	    "tixPopupMenu::BtnRelease $w %X %Y"
 
 	tixBind TixPopupMenu:M:$w <Unmap> \
-	    "tixPopupMenu:Unmap $w"
+	    "tixPopupMenu::Unmap $w"
 	tixBind TixPopupMenu:$w <ButtonRelease-$btn> \
-	    "tixPopupMenu:BtnRelease $w %X %Y"
+	    "tixPopupMenu::BtnRelease $w %X %Y"
 
 	tixAddBindTag $data(w:menubutton) TixPopupMenu:MB:$w
 	tixAddBindTag $data(w:menu)       TixPopupMenu:M:$w
@@ -110,35 +79,35 @@ proc tixPopupMenu:SetBindings {w} {
 #----------------------------------------------------------------------
 # PrivateMethods:
 #----------------------------------------------------------------------
-proc tixPopupMenu:Unpost {w} {
+proc tixPopupMenu::Unpost {w} {
     upvar #0 $w data
 
     catch {
-	tkMenuUnpost ""
+	tkMenuUnpost {}
     }
 #   tkMbButtonUp $data(w:menubutton)
 }
 
-proc tixPopupMenu:BtnRelease {w rootX rootY} {
+proc tixPopupMenu::BtnRelease {w rootX rootY} {
     upvar #0 $w data
 
-    set cW [winfo containing -displayof $w $rootX $rootY]
+    set cW [winfo containing $rootX $rootY]
 
     if {$data(-spring)} {
-	tixPopupMenu:Unpost $w
+	tixPopupMenu::Unpost $w
     }
 }
 
-proc tixPopupMenu:Unmap {w} {
+proc tixPopupMenu::Unmap {w} {
     upvar #0 $w data
     wm withdraw $w
 }
 
-proc tixPopupMenu:Destructor {w} {
+proc tixPopupMenu::Destructor {w} {
     upvar #0 $w data
 
     foreach client $data(g:clients) {
-	if {[winfo exists $client]} {
+	if [winfo exists $client] {
 	    tixDeleteBindTag $client TixPopupMenu:$w
 	}
     }
@@ -154,7 +123,7 @@ proc tixPopupMenu:Destructor {w} {
     tixChainMethod $w Destructor
 }
 
-proc tixPopupMenu:config-title {w value} {
+proc tixPopupMenu::config-title {w value} {
     upvar #0 $w data
 
     $data(w:menubutton) config -text $value
@@ -163,7 +132,7 @@ proc tixPopupMenu:config-title {w value} {
 #----------------------------------------------------------------------
 # PublicMethods:
 #----------------------------------------------------------------------
-proc tixPopupMenu:bind {w args} {
+proc tixPopupMenu::bind {w args} {
     upvar #0 $w data
 
     foreach client $args {
@@ -174,11 +143,11 @@ proc tixPopupMenu:bind {w args} {
     }
 }
 
-proc tixPopupMenu:unbind {w args} {
+proc tixPopupMenu::unbind {w args} {
     upvar #0 $w data
 
     foreach client $args {
-	if {[winfo exists $client]} {
+	if [winfo exists $client] {
 	    set index [lsearch $data(g:clients) $client]
 	    if {$index != -1} {
 		tixDeleteBindTag $client TixPopupMenu:$w
@@ -188,7 +157,7 @@ proc tixPopupMenu:unbind {w args} {
     }
 }
 
-proc tixPopupMenu:post {w client x y} {
+proc tixPopupMenu::post {w client x y} {
     upvar #0 $w data
     global tkPriv
 
@@ -199,14 +168,14 @@ proc tixPopupMenu:post {w client x y} {
     set rootx [expr $x + [winfo rootx $client]]
     set rooty [expr $y + [winfo rooty $client]]
 
-    if {$data(-postcmd) != ""} {
-	set ret [tixEvalCmdBinding $w $data(-postcmd) "" $rootx $rooty]
-	if {![tixGetBoolean $ret]} {
+    if {$data(-postcmd) != {}} {
+	set ret [tixEvalCmdBinding $w $data(-postcmd) {} $rootx $rooty]
+	if ![tixGetBoolean $ret] {
 	    return
 	}
     }
 
-    if {[tixGetBoolean -nocomplain $data(-installcolormap)]} {
+    if [tixGetBoolean -nocomplain $data(-installcolormap)] {
 	wm colormapwindows . "$w"
     }
 
