@@ -1,13 +1,8 @@
-# -*- mode: TCL; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
-#
-#	$Id: SimpDlg.tcl,v 1.1.1.1.2.1 2001/11/03 07:23:17 idiscovery Exp $
-#
 # SimpDlg.tcl --
 #
 #	This file implements Simple Dialog widgets
 #
-# Copyright (c) 1993-1999 Ioi Kim Lam.
-# Copyright (c) 2000-2001 Tix Project Group.
+# Copyright (c) 1996, Expert Interface Technologies
 #
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -21,17 +16,15 @@ tixWidgetClass tixSimpleDialog {
 	-buttons -message -type
     }
     -configspec {
-	{-buttons buttons Buttons ""}
-	{-message message Message ""}
+	{-buttons buttons Buttons {}}
+	{-message message Message {}}
 	{-type type Type info}
     }
 }
 
-proc tixSimpleDialog:ConstructWidget {w} {
+proc tixSimpleDialog::ConstructWidget {w} {
     upvar #0 $w data
 
-    tixChainMethod $w ConstructWidget
-
     frame $w.top
 
     label $w.top.icon -image [tix getimage $data(-type)]
